@@ -1,4 +1,4 @@
-<?
+<?php
 /* (c) 2001 Marco Pratesi <pratesi@telug.it> */
 /* (c) 2000, 2001 Fabio Molinari <fabio.m@mclink.it> */
 /* with contribution for the script structure 
@@ -8,12 +8,14 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 require_login();
 require_priv("admin");
 
+$qid = new PGM_Sql;
+
 $DOC_TITLE = "Brands_Management";
-include("header.php");
+include ("header.php");
 
 switch (nvl($mode)) {
 	case "add" :
@@ -39,11 +41,10 @@ switch (nvl($mode)) {
 			insert_brand($HTTP_POST_VARS);
 		} else {
 			/* set default values for the reset of the fields */
+			$frm = $HTTP_POST_VARS;
 			$frm["newmode"] = "insert";
-			$frm["name"] = $HTTP_POST_VARS["name"];
-			$frm["description"] = $HTTP_POST_VARS["description"];
 			$frm["submit_caption"] = "Add_Brand";
-			include("$CFG->dirroot"."/form_header.php");
+			include ("$CFG->dirroot" . "/form_header.php");
 			load_brand_form_template($frm, $id, $errors);
 		}
 		break;
@@ -59,11 +60,10 @@ switch (nvl($mode)) {
 			update_brand($id, $HTTP_POST_VARS);
 		} else {
 			/* set default values for the reset of the fields */
+			$frm = $HTTP_POST_VARS;
 			$frm["newmode"] = "update";
-			$frm["name"] = $HTTP_POST_VARS["name"];
-			$frm["description"] = $HTTP_POST_VARS["description"];
 			$frm["submit_caption"] = "Save_Changes";
-			include("$CFG->dirroot"."/form_header.php");
+			include ("$CFG->dirroot" . "/form_header.php");
 			load_brand_form_template($frm, $id, $errors);
 		}
 		break;
@@ -73,20 +73,20 @@ switch (nvl($mode)) {
 		break;
 
 	case "update_imp" :
-		if ($userfile == 'none')
+		if ($HTTP_POST_FILES['userfile']['tmp_name'] == "none")
 			print_import_brand_form();
 		else
-			import_brands($userfile);
+			import_brands($HTTP_POST_FILES);
 		break;
 
 	default :
 		$SESSION["goback"]["request_uri"] = $REQUEST_URI;
 		$SESSION["goback"]["query_string"] = $QUERY_STRING;
-		print_brands_list();
+		print_brand_list();
 		break;
 }
 
-include("footer.php");
+include ("footer.php");
 
 /******************************************************************************
  * FUNCTIONS
@@ -100,20 +100,19 @@ function load_brand_form_template($frm, $id, $errors) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/brand_form.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
-			"frm_newmode"		=> $frm["newmode"],
-			"brand_id"		=> $id,
-			"frm_name"		=> ov($frm["name"]),
-			"errors_name"		=> errmsg($errors->brand_name),
-			"frm_description"	=> ov($frm["description"]),
-			"errors_description"	=> errmsg($errors->brand_description),
-			"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
+		"frm_newmode"		=> $frm["newmode"],
+		"brand_id"		=> $id,
+		"frm_name"		=> ov($frm["name"]),
+		"errors_name"		=> errmsg($errors->brand_name),
+		"frm_description"	=> ov($frm["description"]),
+		"errors_description"	=> errmsg($errors->brand_description),
+		"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
 	));
 	$t->pparse("out", "page");
-//	include("templates/brand_form.ihtml");
 }
 
 function print_add_brand_form() {
@@ -137,12 +136,11 @@ function print_edit_brand_form($id) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	/* load up the information for the brand */
-	$qid = new DB_Sql;
-//	$qid = db_query("
+//	$qid = new PGM_Sql;
 	$qid->Query("SELECT name, description FROM brands WHERE id = '$id'");
-//	$frm = db_fetch_array($qid, 0);
 	$qid->next_record();
 	$frm["name"] = $qid->f("name");
 	$frm["description"] = $qid->f("description");
@@ -160,27 +158,22 @@ function delete_brand($id) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
-	$qid = new DB_Sql;
-//	$qid = db_begin();
+//	$qid = new PGM_Sql;
 	$qid->begin();
 
 	/* find out the brand name */
-//	$qid = db_query("
 	$qid->Query("SELECT name from brands WHERE id = '$id'");
-//	$frm = db_fetch_array($qid, 0);
 	$qid->next_record();
 	$frm["name"] = $qid->f("name");
 
 	/* delete this brand */
-//	$qid = db_query("
 	$qid->Query("DELETE FROM brands WHERE id = '$id'");
 
 	// reset to 0 the brand_id for all products of this brand
-//	$qid = db_query("
 	$qid->Query("UPDATE products SET brand_id = 0 WHERE brand_id = '$id'");
 
-//	$qid = db_commit();
 	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
@@ -190,14 +183,13 @@ function delete_brand($id) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/brand_deleted.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var(array(
-			"frm_name"	=> ov($frm[name]),
-			"backurl"	=> $backurl
+		"frm_name"	=> ov($frm[name]),
+		"backurl"	=> $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/brand_deleted.ihtml");
 }
 
 function insert_brand($frm) {
@@ -207,12 +199,12 @@ function insert_brand($frm) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-	$qid = new DB_Sql;
-//	$qid = db_query("
+//	$qid = new PGM_Sql;
 	$qid->Query("
 		INSERT INTO brands (name, description)
 		VALUES ('$frm[name]', '$frm[description]')
@@ -225,13 +217,12 @@ function insert_brand($frm) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/brand_added.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
 	$t->set_var(array(
-			"frm_name"	=> ov($frm[name]),
-			"backurl"	=> $backurl
+		"frm_name"	=> ov($frm[name]),
+		"backurl"	=> $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/brand_added.ihtml");
 }
 
 function update_brand($id, $frm) {
@@ -241,12 +232,12 @@ function update_brand($id, $frm) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-	$qid = new DB_Sql;
-//	$qid = db_query("
+//	$qid = new PGM_Sql;
 	$qid->Query("
 		UPDATE brands SET
 			name = '$frm[name]'
@@ -261,17 +252,16 @@ function update_brand($id, $frm) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/brand_updated.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var(array(
-			"http_post_vars_name"	=> ov($frm[name]),
-			"backurl"		=> $backurl
+		"http_post_vars_name"	=> ov($frm[name]),
+		"backurl"		=> $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/brand_updated.ihtml");
 }
 
-function print_brands_list() {
+function print_brand_list() {
 /* read all the brands from the database and print them into a table.  we
  * will use a template to display the listings to keep this main script clean */
 
@@ -279,10 +269,10 @@ function print_brands_list() {
 	global $SESSION;
 	global $page_number, $dbchanged;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	if (!isset($page_number) || $dbchanged) {
-		$qid = new DB_Sql;
-//		$qid = db_query("
+//		$qid = new PGM_Sql;
 		$qid->Query("
 			SELECT id, name, description
 			FROM brands
@@ -290,11 +280,9 @@ function print_brands_list() {
 			ORDER BY name
 		");
 
-//		$SESSION["numr"] = db_num_rows($qid);
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$SESSION["brands"][$i] = db_fetch_array($qid, $i);
-			$qid->seek($i);
+//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["brands"][$i]["id"] = $qid->f("id");
 			$SESSION["brands"][$i]["name"] = $qid->f("name");
@@ -319,15 +307,15 @@ function print_brands_list() {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/brand_list.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_block("page", "pages_links_top", "pages_links_top_blck");
 	$t->set_var("pages_links_top_blck", "");
 	$t->set_block("page", "pages_links_bottom", "pages_links_bottom_blck");
 	$t->set_var("pages_links_bottom_blck", "");
 	if ($num_pages > 1) {
-		require("pages_links.php");
+		include ("pages_links.php");
 		$t->set_var("pages_links", $pages_links);
 		$t->parse("pages_links_top_blck", "pages_links_top", true);
 		$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
@@ -336,14 +324,13 @@ function print_brands_list() {
 	$t->set_var("brand_rows", "");
 	for ($i=$first; $i<=$last; $i++) {
 		$t->set_var(array(
-				"session_brands_name"		=> ov($SESSION["brands"][$i]["name"]),
-				"session_brands_id"		=> $SESSION["brands"][$i]["id"],
-				"session_brands_description"	=> ovwbr($SESSION["brands"][$i]["description"])
+			"session_brands_name"		=> ov($SESSION["brands"][$i]["name"]),
+			"session_brands_id"		=> $SESSION["brands"][$i]["id"],
+			"session_brands_description"	=> ovwbr($SESSION["brands"][$i]["description"])
 		));
 		$t->parse("brand_rows", "brand_row", true);
 	}
 	$t->pparse("out", "page");
-//	include("templates/brand_list.ihtml");
 }
 
 function print_import_brands_form() {
@@ -357,28 +344,27 @@ function print_import_brands_form() {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_form.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
-			"frm_newmode"			=> $frm["newmode"],
-			"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
-			"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
+		"frm_newmode"			=> $frm["newmode"],
+		"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
+		"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
 	));
 	$t->pparse("out", "page");
-//	include("templates/data_import_form.ihtml");
 }
 
-function import_brands($userfile) {
+function import_brands($HTTP_POST_FILES) {
 /* Import brands from a text file */
 	global $CFG, $ME, $SESSION;
 //	include ($CFG->globalerror);
 	$errors = new Object;
+	global $qid;
 
-	$qid = new DB_Sql;
-//	$qid = db_begin();
+//	$qid = new PGM_Sql;
 	$qid->begin();
 
-	$fcontents = file ($userfile);
+	$fcontents = file ($HTTP_POST_FILES['userfile']['tmp_name']);
 	/* Traverse the file */
 	while (list ($line_num, $line) = each ($fcontents)) {
 		// Microsoft Stupidity Suppression
@@ -390,24 +376,18 @@ function import_brands($userfile) {
 			$fldarr[$i] = addslashes($fldarr[$i]);
 
 		/* ... and let's see if the brand already exists ... */
-//		$qid = db_query("
 		$qid->Query("SELECT id FROM brands WHERE name = '$fldarr[0]'");
-//		if (db_num_rows($qid) == 0) {
 		if ($qid->num_rows() == 0) {
 			/* ... if it doesn't exist let's create it ... */
-//			$qid = db_query("
 			$qid->Query("
 				INSERT INTO brands (name, description)
 				VALUES ('$fldarr[0]', '$fldarr[1]')
 			");
 		} else {
 			/* ... otherwise let's save its ID ... */
-//			$arr = db_fetch_array($qid,0);
-//			$sid = $arr[0];
 			$qid->next_record();
 			$qid = $qid->f("id");
 			/* ... and update ... */
-//			$qid = db_query("
 			$qid->Query("
 				UPDATE brands SET description = '$fldarr[1]'
 				WHERE id = '$sid'
@@ -416,7 +396,6 @@ function import_brands($userfile) {
 	}
 
 	/* Let's close the transaction */
-//	$qid = db_commit();
 	$qid->commit();
 	
 	/* The End */
@@ -426,13 +405,11 @@ function import_brands($userfile) {
 		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var("backurl", $backurl);
 	$t->pparse("out", "page");
-//	include("templates/data_import_end.ihtml");
-
 }
 
 ?>
