@@ -1,4 +1,4 @@
-<?
+<?php
 /* categories.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -19,12 +19,14 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 require_login();
 require_priv("admin");
 
+$qid = new PGM_Sql;
+
 $DOC_TITLE = "Categories_Management";
-include("header.php");
+include ("header.php");
 
 switch (nvl($mode)) {
 	case "add" :
@@ -44,7 +46,7 @@ switch (nvl($mode)) {
 			parent.categories.location.reload();
 			// -->
 			</script>
-			<? }
+			<?php }
 		}
 		break;
 
@@ -55,27 +57,28 @@ switch (nvl($mode)) {
 		validate_special_level($HTTP_POST_VARS["special_level"], &$errors, &$errormsg);
 		validate_category_description($HTTP_POST_VARS["description"], &$errors, &$errormsg);
 		if (empty($errormsg)) {
-			insert_subcategory($id, $HTTP_POST_VARS);
+			insert_category($id, $HTTP_POST_VARS);
 			if ($SESSION["frames_used"]) { ?>
 			<script language="JavaScript">
 			<!--
 			parent.categories.location.reload();
 			// -->
 			</script>
-			<? }
+			<?php }
 //			print_category_list();
 		} else {
 			/* set default values for the reset of the fields */
+			$frm = $HTTP_POST_VARS;
 			$frm["parent"] = array($HTTP_POST_VARS["parent"]);
-			$frm["categories"] = $HTTP_POST_VARS["categories"];
 			$frm["newmode"] = "insert";
-			$frm["name"] = $HTTP_POST_VARS["name"];
-			$frm["special_level"] = $HTTP_POST_VARS["special_level"];
-			$frm["description"] = $HTTP_POST_VARS["description"];
 			$frm["submit_caption"] = "Add_Subcategory";
 			/* build the categories listbox options, preselect the selected item */
-			build_category_tree($category_options, $frm["parent"]);
-			include("$CFG->dirroot"."/form_header.php");
+//			$qid = new PGM_Sql;
+			$qid->begin();
+			build_category_tree(&$qid, &$category_options, $frm["parent"]);
+			$qid->commit();
+//			$qid->close();
+			include ("$CFG->dirroot" . "/form_header.php");
 			load_category_form_template($frm, $id, $category_options, $errors);
 		}
 		break;
@@ -94,32 +97,33 @@ switch (nvl($mode)) {
 			parent.categories.location.reload();
 			// -->
 			</script>
-			<? }
+			<?php }
 		} else {
 			/* set default values for the reset of the fields */
+			$frm = $HTTP_POST_VARS;
 			$frm["parent"] = array($HTTP_POST_VARS["parent"]);
-			$frm["categories"] = $HTTP_POST_VARS["categories"];
 			$frm["newmode"] = "update";
-			$frm["name"] = $HTTP_POST_VARS["name"];
-			$frm["special_level"] = $HTTP_POST_VARS["special_level"];
-			$frm["description"] = $HTTP_POST_VARS["description"];
 			$frm["submit_caption"] = "Save_Changes";
 			/* build the categories listbox options, preselect the selected item */
-			build_category_tree($category_options, $frm["parent"]);
-			include("$CFG->dirroot"."/form_header.php");
+//			$qid = new PGM_Sql;
+			$qid->begin();
+			build_category_tree(&$qid, &$category_options, $frm["parent"]);
+			$qid->commit();
+//			$qid->close();
+			include ("$CFG->dirroot" . "/form_header.php");
 			load_category_form_template($frm, $id, $category_options, $errors);
 		}
 		break;
 
 	case "import" :
-		print_import_category_form();
+		print_import_categories_form();
 		break;
 
 	case "update_imp" :
-		if ($userfile == 'none')
-			print_import_category_form();
+		if ($HTTP_POST_FILES['userfile']['tmp_name'] == "none")
+			print_import_categories_form();
 		else
-			import_category($userfile);
+			import_categories($HTTP_POST_FILES);
 		break;
 
 	default :
@@ -129,7 +133,7 @@ switch (nvl($mode)) {
 		break;
 }
 
-include("footer.php");
+include ("footer.php");
 
 /******************************************************************************
  * FUNCTIONS
@@ -143,23 +147,22 @@ function load_category_form_template($frm, $id, $category_options, $errors) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/category_form.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
-			"frm_newmode"		=> $frm["newmode"],
-			"category_id"		=> $id,
-			"category_options"	=> $category_options,
-			"frm_name"		=> ov($frm["name"]),
-			"errors_name"		=> errmsg($errors->category_name),
-			"frm_special_level"	=> $frm["special_level"],
-			"errors_special_level"	=> errmsg($errors->special_level),
-			"frm_description"	=> ov($frm["description"]),
-			"errors_description"	=> errmsg($errors->category_description),
-			"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
+		"frm_newmode"		=> $frm["newmode"],
+		"category_id"		=> $id,
+		"category_options"	=> $category_options,
+		"frm_name"		=> ov($frm["name"]),
+		"errors_name"		=> errmsg($errors->category_name),
+		"frm_special_level"	=> $frm["special_level"],
+		"errors_special_level"	=> errmsg($errors->special_level),
+		"frm_description"	=> ov($frm["description"]),
+		"errors_description"	=> errmsg($errors->category_description),
+		"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
 	));
 	$t->pparse("out", "page");
-//	include("templates/category_form.ihtml");
 }
 
 function print_add_category_form($id) {
@@ -168,6 +171,7 @@ function print_add_category_form($id) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	/* set default values for the reset of the fields */
 	$frm["parent"] = array($id);
@@ -178,7 +182,11 @@ function print_add_category_form($id) {
 	$frm["submit_caption"] = "Add_Subcategory";
 
 	/* build the categories listbox options, preselect the selected item */
-	build_category_tree($category_options, $frm["parent"]);
+//	$qid = new PGM_Sql;
+	$qid->begin();
+	build_category_tree(&$qid, &$category_options, $frm["parent"]);
+	$qid->commit();
+//	$qid->close();
 
 	load_category_form_template($frm, $id, $category_options, $errors);
 }
@@ -189,16 +197,15 @@ function print_edit_category_form($id) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	/* load up the information for the category */
-	$qid = new DB_Sql;
-//	$qid = db_query("
+//	$qid = new PGM_Sql;
 	$qid->Query("
 		SELECT name, special_level, description, parent_id
 		FROM categories
 		WHERE id = '$id'
 	");
-//	$frm = db_fetch_array($qid, 0);
 	$qid->next_record();
 	$frm["name"] = $qid->f("name");
 	$frm["special_level"] = $qid->f("special_level");
@@ -211,7 +218,11 @@ function print_edit_category_form($id) {
 	$frm["submit_caption"] = "Save_Changes";
 
 	/* build the categories listbox options, preselect the selected item */
-	build_category_tree($category_options, $frm["parent"]);
+//	$qid = new PGM_Sql;
+	$qid->begin();
+	build_category_tree(&$qid, &$category_options, $frm["parent"]);
+	$qid->commit();
+//	$qid->close();
 
 	load_category_form_template($frm, $id, $category_options, $errors);
 }
@@ -224,27 +235,24 @@ function delete_category($id) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
-	$qid = new DB_Sql;
-//	$qid = db_begin();
+//	$qid = new PGM_Sql;
 	$qid->begin();
 
 	/* find the parent of this category */
-//	$qid = db_query("
 	$qid->Query("
 		SELECT cat.name, cat.parent_id, parent.name AS parent
 		FROM categories cat, categories parent
 		WHERE parent.id = cat.parent_id
 			AND cat.id = '$id'
 	");
-//	$cat = db_fetch_object($qid, 0);
 	$qid->next_record();
 	$cat->name = $qid->f("name");
 	$cat->parent_id = $qid->f("parent_id");
 	$cat->parent = $qid->f("parent");
 
 	/* delete this category */
-//	$qid = db_query("
 	$qid->Query("DELETE FROM categories WHERE id = '$id'");
 
 	// delete products in this category that also belong
@@ -263,7 +271,6 @@ function delete_category($id) {
  *		)
  *	");
  * a workaround in the following */
-//	$qid = db_query("
 	$qid->Query("
 		SELECT pc1.product_id
 		FROM products_categories pc1 , products_categories pc2
@@ -275,15 +282,12 @@ function delete_category($id) {
 	if (($numr = $qid->num_rows()) > 0) {
 		$toberemoved = "";
 		for ($i=0; $i<$numr-1; $i++) {
-//			$appoggio = db_fetch_object($qid, $i);
-			$qid->seek($i);
+//			$qid->seek($i);
 			$qid->next_record();
 			$toberemoved .= "'" . $qid->f("product_id") . "', ";
 		}
-//		$appoggio = db_fetch_object($qid, $numr-1);
 		$qid->next_record();
 		$toberemoved .= "'" . $qid->f("product_id") . "'";
-//		$qid = db_query("
 		$qid->Query("
 			DELETE FROM products_categories
 			WHERE category_id = '$id' AND product_id IN ($toberemoved)
@@ -291,7 +295,6 @@ function delete_category($id) {
 	}
 
 	/* re-assign all the products in this category to the parent category */
-//	$qid = db_query("
 	$qid->Query("
 		UPDATE products_categories
 		SET category_id = $cat->parent_id
@@ -299,14 +302,12 @@ function delete_category($id) {
 	");
 
 	/* re-assign all sub categories of this category to the parent category */
-//	$qid = db_query("
 	$qid->Query("
 		UPDATE categories
 		SET parent_id = $cat->parent_id
 		WHERE parent_id = '$id'
 	");
 
-//	$qid = db_commit();
 	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
@@ -316,30 +317,29 @@ function delete_category($id) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/category_deleted.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var(array(
-			"cat_name"	=> ov($cat->name),
-			"cat_parent"	=> ov($cat->parent),
-			"backurl"	=> $backurl
+		"cat_name"	=> ov($cat->name),
+		"cat_parent"	=> ov($cat->parent),
+		"backurl"	=> $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/category_deleted.ihtml");
 }
 
-function insert_subcategory($id, $frm) {
+function insert_category($id, $frm) {
 /* add a new subcategory under the parent $id.  all the fields that we want are
  * going to in the variable $frm */
 
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-	$qid = new DB_Sql;
-//	$qid = db_query("
+//	$qid = new PGM_Sql;
 	$qid->Query("
 		INSERT INTO categories (parent_id, name, special_level, description)
 		VALUES ('$frm[parent]', '$frm[name]', '$frm[special_level]', '$frm[description]')
@@ -352,13 +352,12 @@ function insert_subcategory($id, $frm) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/category_added.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
 	$t->set_var(array(
-			"frm_name"	=> ov($frm[name]),
-			"backurl"	=> $backurl
+		"frm_name"	=> ov($frm[name]),
+		"backurl"	=> $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/category_added.ihtml");
 }
 
 function update_category($id, $frm) {
@@ -368,12 +367,12 @@ function update_category($id, $frm) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-	$qid = new DB_Sql;
-//	$qid = db_query("
+//	$qid = new PGM_Sql;
 	$qid->Query("
 		UPDATE categories SET
 			 parent_id = '$frm[parent]'
@@ -390,14 +389,13 @@ function update_category($id, $frm) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/category_updated.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var(array(
-			"frm_name"	=> ov($frm[name]),
-			"backurl"	=> $backurl
+		"frm_name"	=> ov($frm[name]),
+		"backurl"	=> $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/category_updated.ihtml");
 }
 
 function print_category_list() {
@@ -408,21 +406,18 @@ function print_category_list() {
 	global $SESSION;
 	global $page_number, $dbchanged;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	if (!isset($page_number) || $dbchanged) {
-		$qid = new DB_Sql;
-//		$qid = db_query("
+		$qid = new PGM_Sql;
 		$qid->Query("
 			SELECT cat.id, cat.name, cat.special_level, cat.description, parent.name AS parent
 			FROM categories cat, categories parent
 			WHERE parent.id = cat.parent_id AND cat.id > 1 ORDER BY cat.name
 		");
-
-//		$SESSION["numr"] = db_num_rows($qid);
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$SESSION["categories"][$i] = db_fetch_array($qid, $i);
-			$qid->seek($i);
+//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["categories"][$i]["id"] = $qid->f("id");
 			$SESSION["categories"][$i]["name"] = $qid->f("name");
@@ -449,15 +444,15 @@ function print_category_list() {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/category_list.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_block("page", "pages_links_top", "pages_links_top_blck");
 	$t->set_var("pages_links_top_blck", "");
 	$t->set_block("page", "pages_links_bottom", "pages_links_bottom_blck");
 	$t->set_var("pages_links_bottom_blck", "");
 	if ($num_pages > 1) {
-		require("pages_links.php");
+		include ("pages_links.php");
 		$t->set_var("pages_links", $pages_links);
 		$t->parse("pages_links_top_blck", "pages_links_top", true);
 		$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
@@ -466,19 +461,18 @@ function print_category_list() {
 	$t->set_var("category_rows", "");
 	for ($i=$first; $i<=$last; $i++) {
 		$t->set_var(array(
-				"session_categories_name"		=> ov($SESSION["categories"][$i]["name"]),
-				"session_categories_id"			=> $SESSION["categories"][$i]["id"],
-				"session_categories_special_level"	=> $SESSION["categories"][$i]["special_level"],
-				"session_categories_parent"		=> ov($SESSION["categories"][$i]["parent"]),
-				"session_categories_description"	=> ovwbr($SESSION["categories"][$i]["description"])
+			"session_categories_name"		=> ov($SESSION["categories"][$i]["name"]),
+			"session_categories_id"			=> $SESSION["categories"][$i]["id"],
+			"session_categories_special_level"	=> $SESSION["categories"][$i]["special_level"],
+			"session_categories_parent"		=> ov($SESSION["categories"][$i]["parent"]),
+			"session_categories_description"	=> ovwbr($SESSION["categories"][$i]["description"])
 		));
 		$t->parse("category_rows", "category_row", true);
 	}
 	$t->pparse("out", "page");
-//	include("templates/category_list.ihtml");
 }
 
-function print_import_category_form() {
+function print_import_categories_form() {
 /* print the import category form so we can add/update categories from a text file */
 	global $CFG, $ME, $SESSION;
 //	include ($CFG->globalerror);
@@ -489,29 +483,28 @@ function print_import_category_form() {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_form.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
-			"frm_newmode"			=> $frm["newmode"],
-			"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
-			"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
+		"frm_newmode"			=> $frm["newmode"],
+		"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
+		"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
 	));
 	$t->pparse("out", "page");
-//	include("templates/data_import_form.ihtml");
 }
 
-function import_category($userfile) {
+function import_categories($HTTP_POST_FILES) {
 /* Import categories from a text file */
 	global $CFG, $ME, $SESSION;
 	include ($CFG->globalerror);
 	$errors = new Object;
+	global $qid;
 
-//	/* Let's open a transaction */
-	$qid = new DB_Sql;
-//	$qid = db_begin();
+	/* Let's open a transaction */
+//	$qid = new PGM_Sql;
 	$qid->begin();
 
-	$fcontents = file ($userfile);
+	$fcontents = file ($HTTP_POST_FILES['userfile']['tmp_name']);
 	/* Traverse the file */
 	while (list ($line_num, $line) = each ($fcontents)) {
 		// Microsoft Stupidity Suppression
@@ -526,40 +519,30 @@ function import_category($userfile) {
 			$fldarr[$i] = addslashes($fldarr[$i]);
 
 		/* Let's see if the parent category exists ... */
-//		$qid = db_query("
 		$qid->Query("
 			SELECT id FROM categories WHERE name = '$fldarr[0]'
 		");
-//		if (db_num_rows($qid) == 0) {
 		if ($qid->num_rows() == 0) {
 			/* ... if it doesn't exist let's return an error ... */
 			echo $line_num . $Err_ImpCat . $fldarr[0] . "'.<br>";
 		} else {
 			/* ... otherwise let's save its ID ... */
-//			$arr = db_fetch_array($qid,0);
-//			$pid = $arr[0];
 			$qid->next_record();
 			$pid = $qid->f("id");
 
 			/* ... and let's see if the category already exists ... */
-//			$qid = db_query("
 			$qid->Query("SELECT id FROM categories WHERE name = '$fldarr[1]'");
-//			if (db_num_rows($qid) == 0) {
 			if ($qid->num_rows() == 0) {
 				/* ... if it doesn't exist let's create it ... */
-//				$qid = db_query("
 				$qid->Query("
 					INSERT INTO categories (parent_id, name, special_level, description)
 					VALUES ('$pid', '$fldarr[1]', '$fldarr[2]', '$fldarr[3]')
 				");
 			} else {
 				/* ... otherwise let's save its ID ... */
-//				$arr = db_fetch_array($qid,0);
-//				$sid = $arr[0];
 				$qid->next_record();
 				$sid = $qid->f("id");
 				/* ... and update ... */
-//				$qid = db_query("
 				$qid->Query("
 					UPDATE categories SET
 						parent_id = '$pid'
@@ -572,7 +555,6 @@ function import_category($userfile) {
 	}
 
 	/* Let's close the transaction */
-//	$qid = db_commit();
 	$qid->commit();
 	
 	/* The End */
@@ -582,13 +564,11 @@ function import_category($userfile) {
 		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var("backurl", $backurl);
 	$t->pparse("out", "page");
-//	include("templates/data_import_end.ihtml");
-
 }
 
 ?>
