@@ -1,4 +1,4 @@
-<?
+<?php
 /* change_password.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -18,48 +18,49 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 require_login();
 require_priv("admin");
 
-$qid = new DB_Sql;
+$qid = new PGM_Sql;
 
 /* form has been submitted, check if it the user login information is correct */
 if (match_referer() && isset($HTTP_POST_VARS)) {
 	$frm = $HTTP_POST_VARS;
-	$errormsg = validate_form(&$qid, $frm, $errors);
+	$errormsg = validate_form($frm, $errors);
 
 	if (empty($errormsg)) {
-		update_user_password(&$qid, $frm["newpassword"], $frm["username"]);
+		update_user_password($frm["newpassword"], $frm["username"]);
 		$noticemsg = "Password_Change_Successful";
 	}
 }
 
+$qid->close();
+
 $DOC_TITLE = "Change_Password";
-include("$CFG->dirroot"."/header.php");
-include("$CFG->dirroot"."/form_header.php");
+include ("$CFG->dirroot" . "/header.php");
+include ("$CFG->dirroot" . "/form_header.php");
 
 $t = new Template();
 $t->set_file(array("page" => "templates/change_password_form.ihtml"));
-require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+include ("$CFG->localelangdir" . "/global-common.inc.php");
 $t->set_var("ME", $ME);
 $t->set_var("md5dotjs", $CFG->libwww . "/md5.js");
 $t->set_var(array(
-		"username"		=> $username,
-		"errors_oldpassword"    => errmsg($errors->oldpassword),
-		"errors_newpassword"    => errmsg($errors->newpassword),
-		"errors_newpassword2"   => errmsg($errors->newpassword2)
+	"username"		=> $username,
+	"errors_oldpassword"    => errmsg($errors->oldpassword),
+	"errors_newpassword"    => errmsg($errors->newpassword),
+	"errors_newpassword2"   => errmsg($errors->newpassword2)
 ));
 $t->pparse("out", "page");
-//include("templates/change_password_form.ihtml");
 
-include("$CFG->dirroot"."/footer.php");
+include ("$CFG->dirroot" . "/footer.php");
 
 /******************************************************************************
  * FUNCTIONS
  *****************************************************************************/
 
-function validate_form(&$qid, &$frm, &$errors) {
+function validate_form(&$frm, &$errors) {
 
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
@@ -72,7 +73,7 @@ function validate_form(&$qid, &$frm, &$errors) {
 		$errors->oldpassword = true;
 		$msg .= $no_old_password;
 
-	} elseif (! password_valid(&$qid, $frm["oldpassword"], $frm["username"])) {
+	} elseif (! password_valid($frm["oldpassword"], $frm["username"])) {
 		$errors->oldpassword = true;
 		$msg .= $old_password_not_valid;
 
@@ -93,36 +94,40 @@ function validate_form(&$qid, &$frm, &$errors) {
 	return $msg;
 }
 
-function password_valid(&$qid, $password, $username) {
+function password_valid($password, $username) {
 /* return true if the user's password is valid */
 
 	global $SESSION;
 	
-//	$qid = new DB_Sql;
-//	$qid = db_query("
+	global $qid;
+//	$qid = new PGM_Sql;
 	$qid->Query("
 		SELECT 1
 		FROM users
 		WHERE username = '$username' AND password = '$password'
 	");
-//	return db_num_rows($qid);
+//	$qid->close();
 	return $qid->num_rows();
 }
 
-function update_user_password(&$qid, $newpassword, $username) {
+function update_user_password($newpassword, $username) {
 /* set the user's password to the new one */
 
 	global $SESSION, $CFG;
-	
-//	$qid = new DB_Sql;
-//	$qid = db_query("
+	global $qid;
+
+//	$qid = new PGM_Sql;
 	$qid->Query("
 		UPDATE users
 		SET password = '$newpassword'
 		WHERE username = '$username'
 	");
+	$qid->Query("SELECT priv FROM users WHERE username = '$username'");
+	$qid->next_record();
+//	$qid->close();
 
-	if (has_priv("admin")) {
+	$appoggio = $qid->f("priv");
+	if ($appoggio == "admin") {
 		mail(
 			"$CFG->seller_fullname <$CFG->seller_email>",
 			"PgMarket root password changed",
