@@ -1,4 +1,4 @@
-<?
+<?php
 /* (c) 2001 Marco Pratesi <pratesi@telug.it> */
 /* (c) 2000, 2001 Fabio Molinari <fabio.m@mclink.it> */
 /* with contribution for the script structure 
@@ -8,12 +8,14 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 require_login();
 require_priv("admin");
 
+$qid = new PGM_Sql;
+
 $DOC_TITLE = "IVA_Management";
-include("header.php");
+include ("header.php");
 
 switch (nvl($mode)) {
 	case "add" :
@@ -38,10 +40,10 @@ switch (nvl($mode)) {
 			insert_iva($HTTP_POST_VARS);
 		} else {
 			/* set default values for the reset of the fields */
-			$frm["newmode"] = "insert";
 			$frm["iva"] = $HTTP_POST_VARS["iva"];
+			$frm["newmode"] = "insert";
 			$frm["submit_caption"] = "Add_IVA";
-			include("$CFG->dirroot"."/form_header.php");
+			include ("$CFG->dirroot" . "/form_header.php");
 			load_iva_form_template($frm, $id, $errors);
 		}
 		break;
@@ -56,10 +58,10 @@ switch (nvl($mode)) {
 			update_iva($id, $HTTP_POST_VARS);
 		} else {
 			/* set default values for the reset of the fields */
-			$frm["newmode"] = "update";
 			$frm["iva"] = $HTTP_POST_VARS["iva"];
+			$frm["newmode"] = "update";
 			$frm["submit_caption"] = "Save_Changes";
-			include("$CFG->dirroot"."/form_header.php");
+			include ("$CFG->dirroot" . "/form_header.php");
 			load_iva_form_template($frm, $id, $errors);
 		}
 		break;
@@ -69,10 +71,10 @@ switch (nvl($mode)) {
 		break;
 
 	case "update_imp" :
-		if ($userfile == 'none')
+		if ($HTTP_POST_FILES['userfile']['tmp_name'] == "none")
 			print_import_iva_form();
 		else
-			import_iva($userfile);
+			import_iva($HTTP_POST_FILES);
 		break;
 
 	default :
@@ -82,7 +84,7 @@ switch (nvl($mode)) {
 		break;
 }
 
-include("footer.php");
+include ("footer.php");
 
 /******************************************************************************
  * FUNCTIONS
@@ -96,18 +98,17 @@ function load_iva_form_template($frm, $id, $errors) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/iva_form.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
-			"frm_newmode"		=> $frm["newmode"],
-			"iva_id"		=> $id,
-			"frm_iva"		=> $frm["iva"],
-			"errors_iva"		=> errmsg($errors->iva),
-			"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
+		"frm_newmode"		=> $frm["newmode"],
+		"iva_id"		=> $id,
+		"frm_iva"		=> $frm["iva"],
+		"errors_iva"		=> errmsg($errors->iva),
+		"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
 	));
 	$t->pparse("out", "page");
-//	include("templates/iva_form.ihtml");
 }
 
 function print_add_iva_form() {
@@ -131,12 +132,11 @@ function print_edit_iva_form($id) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	/* load up the information for the iva percentage */
-	$qid = new DB_Sql;
-//	$qid = db_query("SELECT iva FROM iva WHERE id = '$id'");
+//	$qid = new PGM_Sql;
 	$qid->Query("SELECT iva FROM iva WHERE id = '$id'");
-//	$frm = db_fetch_array($qid, 0);
 	$qid->next_record();
 	$frm["iva"] = $qid->f("iva");
 
@@ -154,27 +154,22 @@ function delete_iva($id) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
-	$qid = new DB_Sql;
-//	$qid = db_begin();
+//	$qid = new PGM_Sql;
 	$qid->begin();
 
 	/* select the iva percentage to be deleted */
-//	$qid = db_query("SELECT iva from iva WHERE id = '$id'");
 	$qid->Query("SELECT iva FROM iva WHERE id = '$id'");
-//	$frm = db_fetch_array($qid, 0);
 	$qid->next_record();
 	$frm["iva"] = $qid->f("iva");
 
 	/* delete this iva percentage */
-//	$qid = db_query("DELETE FROM iva WHERE id = '$id'");
 	$qid->Query("DELETE FROM iva WHERE id = '$id'");
 
 	// reset to 0 the iva_id for all products with this iva_id
-//	$qid = db_query("
 	$qid->Query(" UPDATE products SET iva_id = 0 WHERE iva_id = '$id'");
 
-//	$qid = db_commit();
 	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
@@ -184,14 +179,13 @@ function delete_iva($id) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/iva_deleted.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var(array(
-			"frm_iva"      => ov($frm[iva]),
-			"backurl"       => $backurl
+		"frm_iva"      => ov($frm[iva]),
+		"backurl"       => $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/iva_deleted.ihtml");
 }
 
 function insert_iva($frm) {
@@ -201,9 +195,9 @@ function insert_iva($frm) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
-	$qid = new DB_Sql;
-//	$qid = db_query("INSERT INTO iva (iva) VALUES ('$frm[iva]')");
+//	$qid = new PGM_Sql;
 	$qid->Query("INSERT INTO iva (iva) VALUES ('$frm[iva]')");
 
 	if (empty($SESSION["goback"]["query_string"]))
@@ -213,14 +207,13 @@ function insert_iva($frm) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/iva_added.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var(array(
-			"frm_iva"      => ov($frm[iva]),
-			"backurl"       => $backurl
+		"frm_iva"      => ov($frm[iva]),
+		"backurl"       => $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/iva_added.ihtml");
 }
 
 function update_iva($id, $frm) {
@@ -230,9 +223,9 @@ function update_iva($id, $frm) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
-	$qid = new DB_Sql;
-//	$qid = db_query("UPDATE iva SET iva = '$frm[iva]' WHERE id = '$id'");
+//	$qid = new PGM_Sql;
 	$qid->Query("UPDATE iva SET iva = '$frm[iva]' WHERE id = '$id'");
 
 	if (empty($SESSION["goback"]["query_string"]))
@@ -242,14 +235,13 @@ function update_iva($id, $frm) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/iva_updated.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var(array(
-			"frm_iva"      => ov($frm[iva]),
-			"backurl"       => $backurl
+		"frm_iva"      => ov($frm[iva]),
+		"backurl"       => $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/iva_updated.ihtml");
 }
 
 function print_iva_list() {
@@ -260,19 +252,16 @@ function print_iva_list() {
 	global $SESSION;
 	global $page_number, $dbchanged;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	if (!isset($page_number) || $dbchanged) {
-		$qid = new DB_Sql;
-//		$qid = db_query("
+//		$qid = new PGM_Sql;
 		$qid->Query("
 			SELECT id, iva FROM iva WHERE id > 0 ORDER BY iva
 		");
-
-//		$SESSION["numr"] = db_num_rows($qid);
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$SESSION["iva"][$i] = db_fetch_array($qid, $i);
-			$qid->seek($i);
+//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["iva"][$i]["id"] = $qid->f("id");
 			$SESSION["iva"][$i]["iva"] = $qid->f("iva");
@@ -296,15 +285,15 @@ function print_iva_list() {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/iva_list.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_block("page", "pages_links_top", "pages_links_top_blck");
 	$t->set_var("pages_links_top_blck", "");
 	$t->set_block("page", "pages_links_bottom", "pages_links_bottom_blck");
 	$t->set_var("pages_links_bottom_blck", "");
 	if ($num_pages > 1) {
-		require("pages_links.php");
+		include ("pages_links.php");
 		$t->set_var("pages_links", $pages_links);
 		$t->parse("pages_links_top_blck", "pages_links_top", true);
 		$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
@@ -313,13 +302,12 @@ function print_iva_list() {
 	$t->set_var("iva_rows", "");
 	for ($i=$first; $i<=$last; $i++) {
 		$t->set_var(array(
-				"session_iva_id"	=> $SESSION["iva"][$i]["id"],
-				"session_iva_iva"	=> $SESSION["iva"][$i]["iva"]
+			"session_iva_id"	=> $SESSION["iva"][$i]["id"],
+			"session_iva_iva"	=> $SESSION["iva"][$i]["iva"]
 		));
 		$t->parse("iva_rows", "iva_row", true);
 	}
 	$t->pparse("out", "page");
-//	include("templates/iva_list.ihtml");
 }
 
 function print_import_iva_form() {
@@ -333,28 +321,27 @@ function print_import_iva_form() {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_form.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
-			"frm_newmode"			=> $frm["newmode"],
-			"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
-			"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
+		"frm_newmode"			=> $frm["newmode"],
+		"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
+		"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
 	));
 	$t->pparse("out", "page");
-//	include("templates/data_import_form.ihtml");
 }
 
-function import_iva($userfile) {
+function import_iva($HTTP_POST_FILES) {
 /* Import iva percentages from a text file */
 	global $CFG, $ME, $SESSION;
 //	include ($CFG->globalerror);
 	$errors = new Object;
+	global $qid;
 
-	$qid = new DB_Sql;
-//	$qid = db_begin();
+//	$qid = new PGM_Sql;
 	$qid->begin();
 
-	$fcontents = file ($userfile);
+	$fcontents = file ($HTTP_POST_FILES['userfile']['tmp_name']);
 	/* Traverse the file */
 	while (list ($line_num, $line) = each ($fcontents)) {
 		// Microsoft Stupidity Suppression
@@ -365,18 +352,14 @@ function import_iva($userfile) {
 		$fldarr[0] = addslashes($fldarr[0]);
 
 		/* ... and let's see if the iva percentage already exists ... */
-//		$qid = db_query("SELECT id FROM iva WHERE iva = '$fldarr[0]'");
 		$qid->Query("SELECT id FROM iva WHERE iva = '$fldarr[0]'");
-//		if (db_num_rows($qid) == 0) {
 		if ($qid->num_rows() == 0) {
 			/* ... if it doesn't exist let's create it */
-//			$qid = db_query("
 			$qid->Query("INSERT INTO iva (iva) VALUES ('$fldarr[0]')");
 		}
 	}
 
 	/* Let's close the transaction */
-//	$qid = db_commit();
 	$qid->commit();
 	
 	/* The End */
@@ -386,13 +369,11 @@ function import_iva($userfile) {
 		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var("backurl", $backurl);
 	$t->pparse("out", "page");
-//	include("templates/data_import_end.ihtml");
-
 }
 
 ?>
