@@ -1,4 +1,4 @@
-<?
+<?php
 /* (c) 2001 Marco Pratesi <pratesi@telug.it> */
 /* (c) 2000, 2001 Fabio Molinari <fabio.m@mclink.it> */
 /* with contribution for the script structure 
@@ -8,12 +8,14 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 require_login();
 require_priv("admin");
 
+$qid = new PGM_Sql;
+
 $DOC_TITLE = "Orders_States_Management";
-include("header.php");
+include ("header.php");
 
 switch (nvl($mode)) {
 	case "add" :
@@ -39,11 +41,11 @@ switch (nvl($mode)) {
 			insert_order_state($HTTP_POST_VARS);
 		} else {
 			/* set default values for the reset of the fields */
-			$frm["newmode"] = "insert";
 			$frm["name"] = $HTTP_POST_VARS["name"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
+			$frm["newmode"] = "insert";
 			$frm["submit_caption"] = "Add_Order_State";
-			include("$CFG->dirroot"."/form_header.php");
+			include ("$CFG->dirroot" . "/form_header.php");
 			load_order_state_form_template($frm, $id, $errors);
 		}
 		break;
@@ -59,11 +61,11 @@ switch (nvl($mode)) {
 			update_order_state($id, $HTTP_POST_VARS);
 		} else {
 			/* set default values for the reset of the fields */
-			$frm["newmode"] = "update";
 			$frm["name"] = $HTTP_POST_VARS["name"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
+			$frm["newmode"] = "update";
 			$frm["submit_caption"] = "Save_Changes";
-			include("$CFG->dirroot"."/form_header.php");
+			include ("$CFG->dirroot" . "/form_header.php");
 			load_order_state_form_template($frm, $id, $errors);
 		}
 		break;
@@ -73,20 +75,20 @@ switch (nvl($mode)) {
 		break;
 
 	case "update_imp" :
-		if ($userfile == 'none')
+		if ($HTTP_POST_FILES['userfile']['tmp_name'] == "none")
 			print_import_orders_states_form();
 		else
-			import_orders_states($userfile);
+			import_orders_states($HTTP_POST_FILES);
 		break;
 
 	default :
 		$SESSION["goback"]["request_uri"] = $REQUEST_URI;
 		$SESSION["goback"]["query_string"] = $QUERY_STRING;
-		print_orders_states_list();
+		print_order_state_list();
 		break;
 }
 
-include("footer.php");
+include ("footer.php");
 
 /******************************************************************************
  * FUNCTIONS
@@ -100,20 +102,19 @@ function load_order_state_form_template($frm, $id, $errors) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_state_form.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
-			"frm_newmode"		=> $frm["newmode"],
-			"order_id"		=> $id,
-			"frm_name"		=> ov($frm["name"]),
-			"errors_name"		=> errmsg($errors->order_state_name),
-			"frm_description"	=> ov($frm["description"]),
-			"errors_description"	=> errmsg($errors->order_state_description),
-			"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
+		"frm_newmode"		=> $frm["newmode"],
+		"order_id"		=> $id,
+		"frm_name"		=> ov($frm["name"]),
+		"errors_name"		=> errmsg($errors->order_state_name),
+		"frm_description"	=> ov($frm["description"]),
+		"errors_description"	=> errmsg($errors->order_state_description),
+		"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
 	));
 	$t->pparse("out", "page");
-//	include("templates/order_state_form.ihtml");
 }
 
 function print_add_order_state_form() {
@@ -138,16 +139,15 @@ function print_edit_order_state_form($id) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	/* load up the information for the order state */
-	$qid = new DB_Sql;
-//	$qid = db_query("
+//	$qid = new PGM_Sql;
 	$qid->Query("
 		SELECT name, description
 		FROM orders_states
 		WHERE id = '$id'
 	");
-//	$frm = db_fetch_array($qid, 0);
 	$qid->next_record();
 	$frm["name"] = $qid->f("name");
 	$frm["description"] = $qid->f("description");
@@ -166,36 +166,30 @@ function delete_order_state($id) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	if ($id > 0) {
-		$qid = new DB_Sql;
-//		$qid = db_begin();
+//		$qid = new PGM_Sql;
 		$qid->begin();
 
 		/* find out this order state name */
-//		$qid = db_query("
 		$qid->Query("
 			SELECT name FROM orders_states
 			WHERE id = '$id'
 		");
-//		$frm = db_fetch_array($qid, 0);
 		$qid->next_record();
 		$frm["name"] = $qid->f("name");
 
 		/* delete this order state */
-//		$qid = db_query("
 		$qid->Query("
 			DELETE FROM orders_states
 			WHERE id = '$id'
 		");
 
 		// reset to 0 the state_id for all orders in this state
-//		$qid = db_query("
 		$qid->Query("UPDATE ordersca SET state_id = 0 WHERE state_id = '$id'");
-//		$qid = db_query("
 		$qid->Query("UPDATE orderscc SET state_id = 0 WHERE state_id = '$id'");
 
-//		$qid = db_commit();
 		$qid->commit();
 
 		if (empty($SESSION["goback"]["query_string"]))
@@ -205,16 +199,15 @@ function delete_order_state($id) {
 
 		$t = new Template();
 		$t->set_file(array("page" => "templates/order_state_deleted.ihtml"));
-		require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-		require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+		include ("$CFG->localelangdir" . "/global-common.inc.php");
+		include ("$CFG->localelangdir" . "/global-admin.inc.php");
 		$t->set_var(array(
-				"frm_name"	=> ov($frm[name]),
-				"backurl"	=> $backurl
+			"frm_name"	=> ov($frm[name]),
+			"backurl"	=> $backurl
 		));
 		$t->pparse("out", "page");
-//		include("templates/order_state_deleted.ihtml");
 	} else
-		print_orders_states_list();
+		print_order_state_list();
 }
 
 function insert_order_state($frm) {
@@ -224,12 +217,12 @@ function insert_order_state($frm) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-	$qid = new DB_Sql;
-//	$qid = db_query("
+//	$qid = new PGM_Sql;
 	$qid->Query("
 		INSERT INTO orders_states (name, description)
 		VALUES ('$frm[name]', '$frm[description]')
@@ -242,14 +235,13 @@ function insert_order_state($frm) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_state_added.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var(array(
-			"frm_name"	=> ov($frm[name]),
-			"backurl"	=> $backurl
+		"frm_name"	=> ov($frm[name]),
+		"backurl"	=> $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/order_state_added.ihtml");
 }
 
 function update_order_state($id, $frm) {
@@ -259,12 +251,12 @@ function update_order_state($id, $frm) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-	$qid = new DB_Sql;
-//	$qid = db_query("
+//	$qid = new PGM_Sql;
 	$qid->Query("
 		UPDATE orders_states SET
 			name = '$frm[name]'
@@ -279,17 +271,16 @@ function update_order_state($id, $frm) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_state_updated.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var(array(
-			"frm_name"	=> ov($frm[name]),
-			"backurl"	=> $backurl
+		"frm_name"	=> ov($frm[name]),
+		"backurl"	=> $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/order_state_updated.ihtml");
 }
 
-function print_orders_states_list() {
+function print_order_state_list() {
 /* read all the order states from the database and print them into a table.  we
  * will use a template to display the listings to keep this main script clean */
 
@@ -297,22 +288,19 @@ function print_orders_states_list() {
 	global $SESSION;
 	global $page_number, $dbchanged;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	if (!isset($page_number) || $dbchanged) {
-		$qid = new DB_Sql;
-//		$qid = db_query("
+//		$qid = new PGM_Sql;
 		$qid->Query("
 			SELECT id, name, description
 			FROM orders_states
 			WHERE id > 0
 			ORDER BY name
 		");
-
-//		$SESSION["numr"] = db_num_rows($qid);
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$SESSION["order_state"][$i] = db_fetch_array($qid, $i);
-			$qid->seek($i);
+//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["order_state"][$i]["id"] = $qid->f("id");
 			$SESSION["order_state"][$i]["name"] = $qid->f("name");
@@ -337,15 +325,15 @@ function print_orders_states_list() {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_state_list.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_block("page", "pages_links_top", "pages_links_top_blck");
 	$t->set_var("pages_links_top_blck", "");
 	$t->set_block("page", "pages_links_bottom", "pages_links_bottom_blck");
 	$t->set_var("pages_links_bottom_blck", "");
 	if ($num_pages > 1) {
-		require("pages_links.php");
+		include ("pages_links.php");
 		$t->set_var("pages_links", $pages_links);
 		$t->parse("pages_links_top_blck", "pages_links_top", true);
 		$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
@@ -354,14 +342,13 @@ function print_orders_states_list() {
 	$t->set_var("order_state_rows", "");
 	for ($i=$first; $i<=$last; $i++) {
 		$t->set_var(array(
-				"session_order_state_name"		=> ov($SESSION["order_state"][$i]["name"]),
-				"session_order_state_id"		=> ov($SESSION["order_state"][$i]["id"]),
-				"session_order_state_description"	=> ovwbr($SESSION["order_state"][$i]["description"])
+			"session_order_state_name"		=> ov($SESSION["order_state"][$i]["name"]),
+			"session_order_state_id"		=> ov($SESSION["order_state"][$i]["id"]),
+			"session_order_state_description"	=> ovwbr($SESSION["order_state"][$i]["description"])
 		));
 		$t->parse("order_state_rows", "order_state_row", true);
 	}
 	$t->pparse("out", "page");
-//	include("templates/order_state_list.ihtml");
 }
 
 function print_import_orders_states_form() {
@@ -375,28 +362,27 @@ function print_import_orders_states_form() {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_form.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
-			"frm_newmode"			=> $frm["newmode"],
-			"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
-			"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
+		"frm_newmode"			=> $frm["newmode"],
+		"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
+		"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
 	));
 	$t->pparse("out", "page");
-//	include("templates/data_import_form.ihtml");
 }
 
-function import_orders_states($userfile) {
+function import_orders_states($HTTP_POST_FILES) {
 /* Import order states from a text file */
 	global $CFG, $ME, $SESSION;
 //	include ($CFG->globalerror);
 	$errors = new Object;
+	global $qid;
 
-	$qid = new DB_Sql;
-//	$qid = db_begin();
+//	$qid = new PGM_Sql;
 	$qid->begin();
 
-	$fcontents = file ($userfile);
+	$fcontents = file ($HTTP_POST_FILES['userfile']['tmp_name']);
 	/* Traverse the file */
 	while (list ($line_num, $line) = each ($fcontents)) {
 		// Microsoft Stupidity Suppression
@@ -408,24 +394,18 @@ function import_orders_states($userfile) {
 			$fldarr[$i] = addslashes($fldarr[$i]);
 
 		/* ... and let's see if the state already exists ... */
-//		$qid = db_query("
 		$qid->Query("SELECT id FROM orders_states WHERE name = '$fldarr[0]'");
-//		if (db_num_rows($qid) == 0) {
 		if ($qid->num_rows() == 0) {
 			/* ... if it doesn't exist let's create it ... */
-//			$qid = db_query("
 			$qid->Query("
 				INSERT INTO orders_states (name, description)
 				VALUES ('$fldarr[0]', '$fldarr[1]')
 			");
 		} else {
 			/* ... otherwise let's save its ID ... */
-//			$arr = db_fetch_array($qid,0);
-//			$sid = $arr[0];
 			$qid->next_record();
 			$sid = $qid->f("id");
 			/* ... and update ... */
-//			$qid = db_query("
 			$qid->Query("
 				UPDATE orders_states SET description = '$fldarr[1]'
 				WHERE id = '$sid'
@@ -434,7 +414,6 @@ function import_orders_states($userfile) {
 	}
 
 	/* Let's close the transaction */
-//	$qid = db_commit();
 	$qid->commit();
 
 	/* The End */
@@ -444,13 +423,11 @@ function import_orders_states($userfile) {
 		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var("backurl", $backurl);
 	$t->pparse("out", "page");
-//	include("templates/data_import_end.ihtml");
-
 }
 
 ?>
