@@ -1,5 +1,4 @@
-<?
-
+<?php
 /* orders.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -19,16 +18,16 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 require_login();
 require_priv("admin");
 
 $DOC_TITLE = "Orders_Log_cc";
-include("header.php");
+include ("header.php");
 
 switch (nvl($mode)) {
 	case "details" :
-		show_order_details($id);
+		print_order_details($id);
 		break;
 
 	case "edit" :
@@ -52,13 +51,13 @@ switch (nvl($mode)) {
 		break;
 }
 
-include("footer.php");
+include ("footer.php");
 
 /******************************************************************************
  * FUNCTIONS
  *****************************************************************************/
 
-function show_order_details($id) {
+function print_order_details($id) {
 /* loads up the details for an order and displays it */
 
 	global $CFG, $ME;
@@ -66,9 +65,9 @@ function show_order_details($id) {
 	global $weightunity;
 	global $page_number;
 //	include ($CFG->globalerror);
+	include ("$CFG->localedir" . $SESSION["lang"] . "/global-names.inc.php");
 
-	$qid_order = new DB_Sql;
-//	$qid_order = db_query("
+	$qid_order = new PGM_Sql;
 	$qid_order->Query("
 		SELECT o.*, os.name AS state_name
 		FROM orderscc o, orders_states os
@@ -76,13 +75,10 @@ function show_order_details($id) {
 	");
 	$qid_order->next_record();
 
-	$qid_items = new DB_Sql;
+	$qid_items = new PGM_Sql;
 	get_order_items(&$qid_items, $id);
 
-//	$order = db_fetch_object($qid_order, 0);
-
-	$qid_user= new DB_Sql;
-//	$qid_user = db_query("
+	$qid_user= new PGM_Sql;
 	$order_username = $qid_order->f("username");
 	$qid_user->Query("
 		SELECT usertype, fiscalcode, email
@@ -90,26 +86,25 @@ function show_order_details($id) {
 		WHERE username = '$order_username'
 	");
 	$qid_user->next_record();
-//	$user = db_fetch_object($qid_user, 0);
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_details.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
-			"order_id"		=> ov($id),
-			"page_number"		=> $page_number,
-			"order_state_name"	=> $qid_order->f("state_name"),
-			"order_date"		=> ov($qid_order->f("date")),
-			"order_username"	=> $qid_order->f("username"),
-			"order_amount"		=> $qid_order->f("amount"),
-			"order_famount"		=> formatted_price($qid_order->f("amount")),
-			"order_custinfo"	=> nl2br(ov($qid_order->f("custinfo"))),
-			"user_fiscalcode"	=> $qid_user->f("fiscalcode"),
-			"user_email"		=> $qid_user->f("email"),
-			"order_notes"		=> nl2br(ov($qid_order->f("notes"))),
-			"order_ournotes"	=> nl2br(ov($qid_order->f("ournotes")))
+		"order_id"		=> ov($id),
+		"page_number"		=> $page_number,
+		"order_state_name"	=> $qid_order->f("state_name"),
+		"order_date"		=> $userday[$qid_order->f("weekday")] . " " . $qid_order->f("day") . " " . $usermonth[$qid_order->f("month")] . " " . $qid_order->f("year"),
+		"order_username"	=> $qid_order->f("username"),
+		"order_amount"		=> $qid_order->f("amount"),
+		"order_famount"		=> formatted_price($qid_order->f("amount")),
+		"order_custinfo"	=> nl2br(ov($qid_order->f("custinfo"))),
+		"user_fiscalcode"	=> $qid_user->f("fiscalcode"),
+		"user_email"		=> $qid_user->f("email"),
+		"order_notes"		=> nl2br(ov($qid_order->f("notes"))),
+		"order_ournotes"	=> nl2br(ov($qid_order->f("ournotes")))
 	));
 	$t->set_block("page", "usertype_pf", "usertype_pf_blck");
 	$t->set_var("usertype_pf_blck", "");
@@ -131,27 +126,28 @@ function show_order_details($id) {
 	$t->set_var("item_rows", "");
 		$t->set_block("item_row", "weight_used_tr", "weight_used_tr_blck");
 		$t->set_block("item_row", "iva_used_tr", "iva_used_tr_blck");
-//	$numr = db_num_rows($qid_items);
-//	for ($i=0; $i<$numr; $i++) {
 	while ($qid_items->next_record()) {
 		$t->set_var("weight_used_tr_blck", "");
 		$t->set_var("iva_used_tr_blck", "");
-//		$prod = db_fetch_object($qid_items, $i);
 		$t->set_var(array(
-				"prod_product_id"	=> ov($qid_items->f("product_id")),
-				"prod_name"		=> ov($qid_items->f("name")),
-				"prod_curr_price"	=> $qid_items->f("curr_price"),
-				"prod_curr_fprice"	=> formatted_price($qid_items->f("curr_price")),
-				"prod_purchase_price"	=> $qid_items->f("purchase_price"),
-				"prod_purchase_fprice"	=> formatted_price($qid_items->f("purchase_price")),
-				"prod_qty"		=> $qid_items->f("qty"),
-				"prod_total"		=> $qid_items->f("total"),
-				"prod_ftotal"		=> formatted_price($qid_items->f("total"))
+			"prod_curr_price"	=> $qid_items->f("curr_price"),
+			"prod_curr_fprice"	=> formatted_price($qid_items->f("curr_price")),
+			"prod_purchase_price"	=> $qid_items->f("purchase_price"),
+			"prod_purchase_fprice"	=> formatted_price($qid_items->f("purchase_price")),
+			"prod_qty"		=> $qid_items->f("qty"),
+			"prod_total"		=> $qid_items->f("total"),
+			"prod_ftotal"		=> formatted_price($qid_items->f("total"))
 		));
+		$appoggio = ov($qid_items->f("oiname"));
+		if ($qid_items->f("name") != $appoggio)
+			$appoggio = "<div class=\"warning\">" . $appoggio . "</div>";
+		if ($qid_items->f("name") != "")
+			$appoggio = "<a href=\"" . "$CFG->wwwroot" . "/admin/products.php?mode=details&product_id=" . $qid_items->f("product_id") . "\">" . $appoggio . "</a>";
+		$t->set_var("prod_name", $appoggio);
 		if($SESSION["weight_used"]) {
 			$t->set_var(array(
-					"prod_purchase_weight"	=> $qid_items->f("purchase_weight"),
-					"prod_purchase_fweight"	=> formatted_weight($qid_items->f("purchase_weight"))
+				"prod_purchase_weight"	=> $qid_items->f("purchase_weight"),
+				"prod_purchase_fweight"	=> formatted_weight($qid_items->f("purchase_weight"))
 			));
 			$t->parse("weight_used_tr_blck", "weight_used_tr", true);
 		}
@@ -165,13 +161,12 @@ function show_order_details($id) {
 	$t->set_var("delivery_used_blck", "");
 	if ($SESSION["delivery_used"]) {
 		$t->set_var(array(
-				"order_delivery"	=> $qid_order->f("delivery"),
-				"order_fdelivery"	=> formatted_price($qid_order->f("delivery"))
+			"order_delivery"	=> $qid_order->f("delivery"),
+			"order_fdelivery"	=> formatted_price($qid_order->f("delivery"))
 		));
 		$t->parse("delivery_used_blck", "delivery_used", true);
 	}
 	$t->pparse("out", "page");
-//	include("templates/order_details.ihtml");
 }
 
 function print_edit_order_form($id) {
@@ -182,15 +177,14 @@ function print_edit_order_form($id) {
 	global $weightunity;
 	global $page_number;
 //	include ($CFG->globalerror);
+	include ("$CFG->localedir" . $SESSION["lang"] . "/global-names.inc.php");
 
-	$qid_order = new DB_Sql;
-//	$qid_order = db_query("
+	$qid_order = new PGM_Sql;
 	$qid_order->Query("SELECT * FROM orderscc WHERE id = '$id'");
 	$qid_order->next_record();
-//	$frm = db_fetch_array($qid_order, 0);
 	$frm["id"] = $qid_order->f("id");
 	$frm["username"] = $qid_order->f("username");
-	$frm["date"] = $qid_order->f("date");
+	$frm["date"] = $userday[$qid_order->f("weekday")] . " " . $qid_order->f("day") . " " . $usermonth[$qid_order->f("month")] . " " . $qid_order->f("year");
 	$frm["fromip"] = $qid_order->f("fromip");
 	$frm["custinfo"] = $qid_order->f("custinfo");
 	$frm["notes"] = $qid_order->f("notes");
@@ -198,28 +192,22 @@ function print_edit_order_form($id) {
 	$frm["amount"] = $qid_order->f("amount");
 	$frm["delivery"] = $qid_order->f("delivery");
 	$frm["state_id"] = $qid_order->f("state_id");
-	$qid_orders_states = new DB_Sql;
-//	$qid_orders_states = db_query("
+	$qid_orders_states = new PGM_Sql;
 	$qid_orders_states->Query("SELECT * FROM orders_states ORDER BY name");
 	$frm["order_state"] = array();
-//	$numr = db_num_rows($qid_orders_states);
 	$numr = $qid_orders_states->num_rows();
 	$frm["num_orders_states"] = $numr;
 	for ($i=0; $i<$numr; $i++) {
-//		$order_state = db_fetch_object($qid_orders_states, $i);
-//		$frm["order_state"][$i]["id"] = $order_state->id;
-//		$frm["order_state"][$i]["name"] = $order_state->name;
-		$qid_orders_states->seek($i);
+//		$qid_orders_states->seek($i);
 		$qid_orders_states->next_record();
 		$frm["order_state"][$i]["id"] = $qid_orders_states->f("id");
 		$frm["order_state"][$i]["name"] = $qid_orders_states->f("name");
 	}
 
-	$qid_items = new DB_Sql;
+	$qid_items = new PGM_Sql;
 	get_order_items(&$qid_items, $id);
 
-	$qid_user = new DB_Sql;
-//	$qid_user = db_query("
+	$qid_user = new PGM_Sql;
 	$qid_user->Query("
 		SELECT usertype, fiscalcode, email
 		FROM users
@@ -227,39 +215,40 @@ function print_edit_order_form($id) {
 	");
 	$qid_user->next_record();
 
-//	$order = db_fetch_object($qid_order, 0);
-//	$user = db_fetch_object($qid_user, 0);
-
 	$frm["newmode"] = "update";
 	$frm["submit_caption"] = "Save_Changes";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_form.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
-			"page_number"		=> $page_number,
-			"frm_newmode"		=> $frm["newmode"],
-			"order_id"		=> ov($id),
-			"frm_date"		=> ov($frm["date"]),
-			"frm_username"		=> ov($frm["username"]),
-			"frm_amount"		=> $frm["amount"],
-			"frm_famount"		=> formatted_price($frm["amount"]),
-			"order_custinfo"	=> $qid_order->f("custinfo"),
-			"user_fiscalcode"	=> $qid_user->f("fiscalcode"),
-			"user_email"		=> $qid_user->f("email"),
-			"order_notes"		=> $frm["notes"],
-			"order_ournotes"	=> $frm["ournotes"],
-			"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
+		"page_number"		=> $page_number,
+		"frm_newmode"		=> $frm["newmode"],
+		"order_id"		=> ov($id),
+		"frm_date"		=> ov($frm["date"]),
+		"frm_year"		=> ov($frm["year"]),
+		"frm_month"		=> ov($frm["month"]),
+		"frm_day"		=> ov($frm["day"]),
+		"frm_weekday"		=> ov($frm["weekday"]),
+		"frm_username"		=> ov($frm["username"]),
+		"frm_amount"		=> $frm["amount"],
+		"frm_famount"		=> formatted_price($frm["amount"]),
+		"order_custinfo"	=> $qid_order->f("custinfo"),
+		"user_fiscalcode"	=> $qid_user->f("fiscalcode"),
+		"user_email"		=> $qid_user->f("email"),
+		"order_notes"		=> $frm["notes"],
+		"order_ournotes"	=> $frm["ournotes"],
+		"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
 	));
 	$t->set_block("page", "order_state_option", "order_state_options");
 	$t->set_var("order_state_options", "");
 	for ($i=0; $i<$frm["num_orders_states"]; $i++) {
 		$t->set_var(array(
-				"frm_order_state_id"		=> $frm["order_state"][$i]["id"],
-				"frm_order_state_selected"	=> $frm["state_id"] == $frm["order_state"][$i]["id"] ? "selected" : "",
-				"frm_order_state_name"		=> $frm["order_state"][$i]["name"]
+			"frm_order_state_id"		=> $frm["order_state"][$i]["id"],
+			"frm_order_state_selected"	=> $frm["state_id"] == $frm["order_state"][$i]["id"] ? "selected" : "",
+			"frm_order_state_name"		=> $frm["order_state"][$i]["name"]
 		));
 		$t->parse("order_state_options", "order_state_option", true);
 	}
@@ -283,27 +272,28 @@ function print_edit_order_form($id) {
 	$t->set_var("item_rows", "");
 		$t->set_block("item_row", "weight_used_tr", "weight_used_tr_blck");
 		$t->set_block("item_row", "iva_used_tr", "iva_used_tr_blck");
-//	$numr = db_num_rows($qid_items);
-//	for ($i=0; $i<$numr; $i++) {
 	while ($qid_items->next_record()) {
 		$t->set_var("weight_used_tr_blck", "");
 		$t->set_var("iva_used_tr_blck", "");
-//		$prod = db_fetch_object($qid_items, $i);
 		$t->set_var(array(
-				"prod_product_id"	=> ov($qid_items->f("product_id")),
-				"prod_name"		=> ov($qid_items->f("name")),
-				"prod_curr_price"	=> $qid_items->f("curr_price"),
-				"prod_curr_fprice"	=> formatted_price($qid_items->f("curr_price")),
-				"prod_purchase_price"	=> $qid_items->f("purchase_price"),
-				"prod_purchase_fprice"	=> formatted_price($qid_items->f("purchase_price")),
-				"prod_qty"		=> $qid_items->f("qty"),
-				"prod_total"		=> $qid_items->f("total"),
-				"prod_ftotal"		=> formatted_price($qid_items->f("total"))
+			"prod_curr_price"	=> $qid_items->f("curr_price"),
+			"prod_curr_fprice"	=> formatted_price($qid_items->f("curr_price")),
+			"prod_purchase_price"	=> $qid_items->f("purchase_price"),
+			"prod_purchase_fprice"	=> formatted_price($qid_items->f("purchase_price")),
+			"prod_qty"		=> $qid_items->f("qty"),
+			"prod_total"		=> $qid_items->f("total"),
+			"prod_ftotal"		=> formatted_price($qid_items->f("total"))
 		));
+		$appoggio = ov($qid_items->f("oiname"));
+		if ($qid_items->f("name") != $appoggio)
+			$appoggio = "<div class=\"warning\">" . $appoggio . "</div>";
+		if ($qid_items->f("name") != "")
+			$appoggio = "<a href=\"" . "$CFG->wwwroot" . "/admin/products.php?mode=details&product_id=" . $qid_items->f("product_id") . "\">" . $appoggio . "</a>";
+		$t->set_var("prod_name", $appoggio);
 		if($SESSION["weight_used"]) {
 			$t->set_var(array(
-					"prod_purchase_weight"	=> $qid_items->f("purchase_weight"),
-					"prod_purchase_fweight"	=> formatted_weight($qid_items->f("purchase_weight"))
+				"prod_purchase_weight"	=> $qid_items->f("purchase_weight"),
+				"prod_purchase_fweight"	=> formatted_weight($qid_items->f("purchase_weight"))
 			));
 			$t->parse("weight_used_tr_blck", "weight_used_tr", true);
 		}
@@ -317,13 +307,12 @@ function print_edit_order_form($id) {
 	$t->set_var("delivery_used_blck", "");
 	if ($SESSION["delivery_used"]) {
 		$t->set_var(array(
-				"order_delivery"	=> $qid_order->f("delivery"),
-				"order_fdelivery"	=> formatted_price($qid_order->f("delivery"))
+			"order_delivery"	=> $qid_order->f("delivery"),
+			"order_fdelivery"	=> formatted_price($qid_order->f("delivery"))
 		));
 		$t->parse("delivery_used_blck", "delivery_used", true);
 	}
 	$t->pparse("out", "page");
-//	include("templates/order_form.ihtml");
 }
 
 function delete_order($id) {
@@ -333,11 +322,7 @@ function delete_order($id) {
 	global $SESSION;
 //	include ($CFG->globalerror);
 
-//	$qid = db_begin();
-//	$qid = db_query("DELETE FROM orderscc WHERE id = '$id'");
-//	$qid = db_query("DELETE FROM order_items WHERE order_id = '$id'");
-//	$qid = db_commit();
-	$qid = new DB_Sql;
+	$qid = new PGM_Sql;
 	$qid->begin();
 	$qid->Query("DELETE FROM orderscc WHERE id = '$id'");
 	$qid->Query("DELETE FROM order_items WHERE order_id = '$id'");
@@ -350,13 +335,12 @@ function delete_order($id) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_deleted.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
 	$t->set_var(array(
-			"order_id"	=> ov($id),
-			"backurl"	=> $backurl
+		"order_id"	=> ov($id),
+		"backurl"	=> $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/order_deleted.ihtml");
 }
 
 function update_order($frm) {
@@ -364,8 +348,7 @@ function update_order($frm) {
 
 	global $CFG, $SESSION;
 
-	$qid = new DB_Sql;
-//	$qid = db_query("
+	$qid = new PGM_Sql;
 	$qid->Query("
 		UPDATE orderscc SET
 			 custinfo = '$frm[custinfo]'
@@ -382,10 +365,10 @@ function update_order($frm) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_updated.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
 	$t->set_var(array(
-			"order_id"	=> ov($frm["id"]),
-			"backurl"	=> $backurl
+		"order_id"	=> ov($frm["id"]),
+		"backurl"	=> $backurl
 	));
 	$t->pparse("out", "page");
 }
@@ -397,37 +380,35 @@ function print_order_list() {
 	global $CFG, $ME;
 	global $SESSION;
 	global $weightunity;
-	global $page_number, $dbchanged;
+//	global $page_number, $dbchanged;
+	global $HTTP_GET_VARS;
 //	include ($CFG->globalerror);
+	include ("$CFG->localedir" . $SESSION["lang"] . "/global-names.inc.php");
 
-	if (!isset($page_number) || $dbchanged) {
-		$qid = new DB_Sql;
-//		$qid = db_query("
+	if (!isset($HTTP_GET_VARS["page_number"]) || $HTTP_GET_VARS["dbchanged"]) {
+		$qid = new PGM_Sql;
 		$qid->Query("
-			SELECT o.id, o.username, o.date, o.custinfo, o.amount, o.notes, os.name AS state_name
+			SELECT o.*, os.name AS state_name
 			FROM orderscc o, orders_states os
 			WHERE o.state_id = os.id
 			ORDER BY os.name, o.id ASC
   		");
-
-//		$SESSION["numr"] = db_num_rows($qid);
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$SESSION["orderscc"][$i] = db_fetch_array($qid, $i);
-			$qid->seek($i);
+//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["orderscc"][$i]["id"] = $qid->f("id");
 			$SESSION["orderscc"][$i]["username"] = $qid->f("username");
-			$SESSION["orderscc"][$i]["date"] = $qid->f("date");
+			$SESSION["orderscc"][$i]["date"] = $userday[$qid->f("weekday")] . " " . $qid->f("day") . " " . $usermonth[$qid->f("month")] . " " . $qid->f("year");
 			$SESSION["orderscc"][$i]["custinfo"] = $qid->f("custinfo");
 			$SESSION["orderscc"][$i]["amount"] = $qid->f("amount");
 			$SESSION["orderscc"][$i]["notes"] = $qid->f("notes");
 			$SESSION["orderscc"][$i]["state_name"] = $qid->f("state_name");
 		}
-		if (!isset($page_number)) {
+		if (!isset($HTTP_GET_VARS["page_number"])) {
 			$page_number = 1;
-		}
-	}
+		} else $page_number = $HTTP_GET_VARS["page_number"];
+	} else $page_number = $HTTP_GET_VARS["page_number"];
 
 	if ($SESSION["numr"] > $SESSION["orders_per_page"]) {
 		$first = ($page_number-1)*$SESSION["orders_per_page"];
@@ -443,15 +424,15 @@ function print_order_list() {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/ordercc_list.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_block("page", "pages_links_top", "pages_links_top_blck");
 	$t->set_var("pages_links_top_blck", "");
 	$t->set_block("page", "pages_links_bottom", "pages_links_bottom_blck");
 	$t->set_var("pages_links_bottom_blck", "");
 	if ($num_pages > 1) {
-		require("pages_links.php");
+		include ("pages_links.php");
 		$t->set_var("pages_links", $pages_links);
 		$t->parse("pages_links_top_blck", "pages_links_top", true);
 		$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
@@ -460,19 +441,18 @@ function print_order_list() {
 	$t->set_var("order_rows", "");
 	for ($i=$first; $i<=$last; $i++) {
 		$t->set_var(array(
-				"page_number"			=> $page_number,
-				"session_order_id"		=> ov($SESSION["orderscc"][$i]["id"]),
-				"session_order_state_name"	=> ov($SESSION["orderscc"][$i]["state_name"]),
-				"session_order_username"	=> ov($SESSION["orderscc"][$i]["username"]),
-				"session_order_date"		=> ov($SESSION["orderscc"][$i]["date"]),
-				"session_order_custinfo"	=> ovwbr($SESSION["orderscc"][$i]["custinfo"]),
-				"session_order_amount"		=> $SESSION["orderscc"][$i]["amount"],
-				"session_order_famount"		=> formatted_price($SESSION["orderscc"][$i]["amount"])
+			"page_number"			=> $page_number,
+			"session_order_id"		=> ov($SESSION["orderscc"][$i]["id"]),
+			"session_order_state_name"	=> ov($SESSION["orderscc"][$i]["state_name"]),
+			"session_order_username"	=> ov($SESSION["orderscc"][$i]["username"]),
+			"session_order_date"		=> ov($SESSION["orderscc"][$i]["date"]),
+			"session_order_custinfo"	=> ovwbr($SESSION["orderscc"][$i]["custinfo"]),
+			"session_order_amount"		=> $SESSION["orderscc"][$i]["amount"],
+			"session_order_famount"		=> formatted_price($SESSION["orderscc"][$i]["amount"])
 		));
 		$t->parse("order_rows", "order_row", true);
 	}
 	$t->pparse("out", "page");
-//	include("templates/ordercc_list.ihtml");
 }
 
 ?>
