@@ -1,4 +1,4 @@
-<?
+<?php
 /* users.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -19,18 +19,20 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 require_login();
 require_priv("admin");
 
 if (!isset($usertype)) { $usertype = "pf"; }
 
+$qid = new PGM_Sql;
+
 $DOC_TITLE = "Users_Management";
-include("header.php");
+include ("header.php");
 
 switch (nvl($mode)) {
 	case "details" :
-		show_user_details($username);
+		print_user_details($username);
 		break;
 
 	case "add" :
@@ -50,29 +52,7 @@ switch (nvl($mode)) {
 		$errors = new Object;
 		$errormsg = "";
 		validate_username($HTTP_POST_VARS["username"], &$errors, &$errormsg);
-		validate_priv($HTTP_POST_VARS["priv"], &$errors, &$errormsg);
-		if ($HTTP_POST_VARS["usertype"] == "pf") {
-			validate_firstname($HTTP_POST_VARS["firstname"], &$errors, &$errormsg);
-			validate_lastname($HTTP_POST_VARS["lastname"], &$errors, &$errormsg);
-			if (!empty($HTTP_POST_VARS["fiscalcode"])) {
-				validate_fiscalcode($HTTP_POST_VARS["fiscalcode"], &$errors, &$errormsg);
-			}
-		} else if ($HTTP_POST_VARS["usertype"] == "az") {
-			validate_ragionesociale($HTTP_POST_VARS["firstname"], &$errors, &$errormsg);
-			validate_partitaiva($HTTP_POST_VARS["fiscalcode"], &$errors, &$errormsg);
-		}
-		validate_address($HTTP_POST_VARS["address"], &$errors, &$errormsg);
-		validate_number($HTTP_POST_VARS["number"], &$errors, &$errormsg);
-		validate_city($HTTP_POST_VARS["city"], &$errors, &$errormsg);
-		validate_country($HTTP_POST_VARS["country"], &$errors, &$errormsg);
-		validate_zip_code($HTTP_POST_VARS["zip_code"], &$errors, &$errormsg);
-		validate_phone($HTTP_POST_VARS["phone"], &$errors, &$errormsg);
-		validate_fax($HTTP_POST_VARS["fax"], &$errors, &$errormsg);
-		validate_mobilephone($HTTP_POST_VARS["mobilephone"], &$errors, &$errormsg);
-		validate_email($HTTP_POST_VARS["email"], &$errors, &$errormsg);
-		validate_notes($HTTP_POST_VARS["notes"], &$errors, &$errormsg);
-		validate_ournotes($HTTP_POST_VARS["ournotes"], &$errors, &$errormsg);
-		if (username_exists($HTTP_POST_VARS["username"])) {
+		if (username_exists(&$qid, $HTTP_POST_VARS["username"])) {
 			$errors->username = true;
 			$errormsg = "<li>" . $the_username . " <b>" . ov($HTTP_POST_VARS["username"]) ."</b> " . $already_exists . $errormsg;
 		}
@@ -82,32 +62,16 @@ switch (nvl($mode)) {
 			$errormsg .= "<li>" . $the_email_address . " <b>" . ov($HTTP_POST_VARS["email"]) ."</b> " . $already_exists;
 		}
 */
+		validate_user_form(&$HTTP_POST_VARS, &$errors, &$errormsg);
 		if (empty($errormsg)) {
 			insert_user($HTTP_POST_VARS);
 //			print_user_list();
 		} else {
-			$frm["username"] = $HTTP_POST_VARS["username"];
-			$frm["usertype"] = $HTTP_POST_VARS["usertype"];
-			$frm["priv"] = $HTTP_POST_VARS["priv"];
-			$frm["firstname"] = $HTTP_POST_VARS["firstname"];
-			$frm["lastname"] = $HTTP_POST_VARS["lastname"];
-			$frm["fiscalcode"] = $HTTP_POST_VARS["fiscalcode"];
-			$frm["address"] = $HTTP_POST_VARS["address"];
-			$frm["number"] = $HTTP_POST_VARS["number"];
-			$frm["city"] = $HTTP_POST_VARS["city"];
-			$frm["country"] = $HTTP_POST_VARS["country"];
-			$frm["zip_code"] = $HTTP_POST_VARS["zip_code"];
-			$frm["phone"] = $HTTP_POST_VARS["phone"];
-			$frm["fax"] = $HTTP_POST_VARS["fax"];
-			$frm["mobilephone"] = $HTTP_POST_VARS["mobilephone"];
-			$frm["email"] = $HTTP_POST_VARS["email"];
-			$frm["authdata"] = $HTTP_POST_VARS["authdata"];
-			$frm["acceptadvert"] = $HTTP_POST_VARS["acceptadvert"];
-			$frm["notes"] = $HTTP_POST_VARS["notes"];
-			$frm["ournotes"] = $HTTP_POST_VARS["ournotes"];
+			/* set default values for the reset of the fields */
+			$frm = $HTTP_POST_VARS;
 			$frm["newmode"] = "insert";
 			$frm["submit_caption"] = "Add_User";
-			include("$CFG->dirroot"."/form_header.php");
+			include ("$CFG->dirroot" . "/form_header.php");
 			load_user_form_template($frm, $HTTP_POST_VARS["usertype"], $page_number, $errors);
 		}
 		break;
@@ -115,28 +79,6 @@ switch (nvl($mode)) {
 	case "update" :
 		$errors = new Object;
 		$errormsg = "";
-		validate_priv($HTTP_POST_VARS["priv"], &$errors, &$errormsg);
-		if ($HTTP_POST_VARS["usertype"] == "pf") {
-			validate_firstname($HTTP_POST_VARS["firstname"], &$errors, &$errormsg);
-			validate_lastname($HTTP_POST_VARS["lastname"], &$errors, &$errormsg);
-			if (!empty($HTTP_POST_VARS["fiscalcode"])) {
-				validate_fiscalcode($HTTP_POST_VARS["fiscalcode"], &$errors, &$errormsg);
-			}
-		} else if ($HTTP_POST_VARS["usertype"] == "az") {
-			validate_ragionesociale($HTTP_POST_VARS["firstname"], &$errors, &$errormsg);
-			validate_partitaiva($HTTP_POST_VARS["fiscalcode"], &$errors, &$errormsg);
-		}
-		validate_address($HTTP_POST_VARS["address"], &$errors, &$errormsg);
-		validate_number($HTTP_POST_VARS["number"], &$errors, &$errormsg);
-		validate_city($HTTP_POST_VARS["city"], &$errors, &$errormsg);
-		validate_country($HTTP_POST_VARS["country"], &$errors, &$errormsg);
-		validate_zip_code($HTTP_POST_VARS["zip_code"], &$errors, &$errormsg);
-		validate_phone($HTTP_POST_VARS["phone"], &$errors, &$errormsg);
-		validate_fax($HTTP_POST_VARS["fax"], &$errors, &$errormsg);
-		validate_mobilephone($HTTP_POST_VARS["mobilephone"], &$errors, &$errormsg);
-		validate_email($HTTP_POST_VARS["email"], &$errors, &$errormsg);
-		validate_notes($HTTP_POST_VARS["notes"], &$errors, &$errormsg);
-		validate_ournotes($HTTP_POST_VARS["ournotes"], &$errors, &$errormsg);
 /*
 		if ($HTTP_POST_VARS["old_email"] != $HTTP_POST_VARS["email"]
 		     && email_exists($HTTP_POST_VARS["email"])) {
@@ -144,47 +86,31 @@ switch (nvl($mode)) {
 			$errormsg .= "<li>" . $the_email_address . " <b>" . ov($HTTP_POST_VARS["email"]) ."</b> " . $already_exists;
 		}
 */
+		validate_user_form(&$HTTP_POST_VARS, &$errors, &$errormsg);
 		if (empty($errormsg)) {
 			update_user($HTTP_POST_VARS);
 //			print_user_list();
 		} else {
-			$frm["username"] = $HTTP_POST_VARS["username"];
-			$frm["usertype"] = $HTTP_POST_VARS["usertype"];
-			$frm["priv"] = $HTTP_POST_VARS["priv"];
-			$frm["firstname"] = $HTTP_POST_VARS["firstname"];
-			$frm["lastname"] = $HTTP_POST_VARS["lastname"];
-			$frm["fiscalcode"] = $HTTP_POST_VARS["fiscalcode"];
-			$frm["address"] = $HTTP_POST_VARS["address"];
-			$frm["number"] = $HTTP_POST_VARS["number"];
-			$frm["city"] = $HTTP_POST_VARS["city"];
-			$frm["country"] = $HTTP_POST_VARS["country"];
-			$frm["zip_code"] = $HTTP_POST_VARS["zip_code"];
-			$frm["phone"] = $HTTP_POST_VARS["phone"];
-			$frm["fax"] = $HTTP_POST_VARS["fax"];
-			$frm["mobilephone"] = $HTTP_POST_VARS["mobilephone"];
-			$frm["email"] = $HTTP_POST_VARS["email"];
-			$frm["old_email"] = $HTTP_POST_VARS["old_email"];
-			$frm["authdata"] = $HTTP_POST_VARS["authdata"];
-			$frm["acceptadvert"] = $HTTP_POST_VARS["acceptadvert"];
-			$frm["notes"] = $HTTP_POST_VARS["notes"];
-			$frm["ournotes"] = $HTTP_POST_VARS["ournotes"];
+			/* set default values for the reset of the fields */
+			$frm = $HTTP_POST_VARS;
 			$frm["newmode"] = "update";
 			$frm["submit_caption"] = "Save_Changes";
-			include("$CFG->dirroot"."/form_header.php");
+			include ("$CFG->dirroot" . "/form_header.php");
 			load_user_form_template($frm, $HTTP_POST_VARS["usertype"], $page_number, $errors);
 		}
 		break;
 
 	case "resetpw" :
-		$return = reset_user_password($username);
+		$qid->begin();
+		$return = reset_user_password(&$qid, $username);
+		$qid->commit();
 		if ($return == 0) {
 			$t = new Template();
-			$t->set_file(array("page" => "templates/".$SESSION["lang"]."/user_password_reset.ihtml"));
+			$t->set_file(array("page" => "templates/" . $SESSION["lang"] . "/user_password_reset.ihtml"));
 			$t->set_var("username", ov($username));
 			$t->pparse("out", "page");
-//			include("templates/".$SESSION["lang"]."/user_password_reset.ihtml");
 		} else {
-			include("templates/".$SESSION["lang"]."/password_not_reset.ihtml");
+			include ("templates/" . $SESSION["lang"] . "/password_not_reset.ihtml");
 		}
 		print_user_list();
 		break;
@@ -194,10 +120,10 @@ switch (nvl($mode)) {
 		break;
 
 	case "update_imp" :
-		if ($userfile == 'none')
+		if ($HTTP_POST_FILES['userfile']['tmp_name'] == "none")
 			print_import_users_form();
 		else
-			import_users($userfile);
+			import_users($HTTP_POST_FILES);
 		break;
 
 	default :
@@ -207,12 +133,38 @@ switch (nvl($mode)) {
 		break;
 }
 
-include("footer.php");
+include ("footer.php");
 
 /******************************************************************************
  * FUNCTIONS
  *****************************************************************************/
 
+function validate_user_form(&$frm, &$errors, &$errormsg) {
+
+	validate_priv($frm["priv"], &$errors, &$errormsg);
+	if ($frm["usertype"] == "pf") {
+		validate_firstname($frm["firstname"], &$errors, &$errormsg);
+		validate_lastname($frm["lastname"], &$errors, &$errormsg);
+		if (!empty($frm["fiscalcode"])) {
+			validate_fiscalcode($frm["fiscalcode"], &$errors, &$errormsg);
+		}
+	} else if ($frm["usertype"] == "az") {
+		validate_ragionesociale($frm["firstname"], &$errors, &$errormsg);
+		validate_partitaiva($frm["fiscalcode"], &$errors, &$errormsg);
+	}
+	validate_address($frm["address"], &$errors, &$errormsg);
+	validate_number($frm["number"], &$errors, &$errormsg);
+	validate_city($frm["city"], &$errors, &$errormsg);
+	validate_country($frm["country"], &$errors, &$errormsg);
+	validate_zip_code($frm["zip_code"], &$errors, &$errormsg);
+	validate_phone($frm["phone"], &$errors, &$errormsg);
+	validate_fax($frm["fax"], &$errors, &$errormsg);
+	validate_mobilephone($frm["mobilephone"], &$errors, &$errormsg);
+	validate_email($frm["email"], &$errors, &$errormsg);
+	validate_notes($frm["notes"], &$errors, &$errormsg);
+	validate_ournotes($frm["ournotes"], &$errors, &$errormsg);
+}
+
 function load_user_form_template($frm, $usertype, $page_number, $errors) {
 
 	global $CFG, $ME;
@@ -221,50 +173,50 @@ function load_user_form_template($frm, $usertype, $page_number, $errors) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/user_form-".$usertype.".ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
-			"page_number"		=> $page_number,
-			"frm_newmode"		=> $frm["newmode"],
-			"frm_old_email"		=> $frm["old_email"],
-			"frm_username"		=> ov($frm["username"]),
-			"errors_username"	=> errmsg($errors->username),
-			"frm_priv"		=> ov($frm["priv"]),
-			"errors_priv"		=> errmsg($errors->priv),
-			"frm_firstname"		=> ov($frm["firstname"]),
-			"errors_firstname"	=> errmsg($errors->firstname),
-			"frm_lastname"		=> ov($frm["lastname"]),
-			"errors_lastname"	=> errmsg($errors->lastname),
-			"frm_fiscalcode"	=> ov($frm["fiscalcode"]),
-			"errors_fiscalcode"	=> errmsg($errors->fiscalcode),
-			"frm_address"		=> ov($frm["address"]),
-			"errors_address"	=> errmsg($errors->address),
-			"frm_number"		=> ov($frm["number"]),
-			"errors_number"		=> errmsg($errors->number),
-			"frm_city"		=> ov($frm["city"]),
-			"errors_city"		=> errmsg($errors->city),
-			"frm_country"		=> ov($frm["country"]),
-			"errors_country"	=> errmsg($errors->country),
-			"frm_zip_code"		=> ov($frm["zip_code"]),
-			"errors_zip_code"	=> errmsg($errors->zip_code),
-			"frm_phone"		=> ov($frm["phone"]),
-			"errors_phone"		=> errmsg($errors->phone),
-			"frm_fax"		=> ov($frm["fax"]),
-			"errors_fax"		=> errmsg($errors->fax),
-			"frm_mobilephone"	=> ov($frm["mobilephone"]),
-			"errors_mobilephone"	=> errmsg($errors->mobilephone),
-			"frm_email"		=> ov($frm["email"]),
-			"errors_email"		=> errmsg($errors->email),
-			"frm_authdata"		=> $frm["authdata"] ? "checked" : "" ,
-			"frm_acceptadvert"	=> $frm["acceptadvert"] ? "checked" : "" ,
-			"frm_notes"		=> ov($frm["notes"]),
-			"errors_notes"		=> errmsg($errors->notes),
-			"frm_ournotes"		=> ov($frm["ournotes"]),
-			"errors_ournotes"	=> errmsg($errors->ournotes),
-			"frm_description"	=> ov($frm["description"]),
-			"errors_description"	=> errmsg($errors->brand_description),
-			"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
+		"page_number"		=> $page_number,
+		"frm_newmode"		=> $frm["newmode"],
+		"frm_old_email"		=> $frm["old_email"],
+		"frm_username"		=> ov($frm["username"]),
+		"errors_username"	=> errmsg($errors->username),
+		"frm_priv"		=> ov($frm["priv"]),
+		"errors_priv"		=> errmsg($errors->priv),
+		"frm_firstname"		=> ov($frm["firstname"]),
+		"errors_firstname"	=> errmsg($errors->firstname),
+		"frm_lastname"		=> ov($frm["lastname"]),
+		"errors_lastname"	=> errmsg($errors->lastname),
+		"frm_fiscalcode"	=> ov($frm["fiscalcode"]),
+		"errors_fiscalcode"	=> errmsg($errors->fiscalcode),
+		"frm_address"		=> ov($frm["address"]),
+		"errors_address"	=> errmsg($errors->address),
+		"frm_number"		=> ov($frm["number"]),
+		"errors_number"		=> errmsg($errors->number),
+		"frm_city"		=> ov($frm["city"]),
+		"errors_city"		=> errmsg($errors->city),
+		"frm_country"		=> ov($frm["country"]),
+		"errors_country"	=> errmsg($errors->country),
+		"frm_zip_code"		=> ov($frm["zip_code"]),
+		"errors_zip_code"	=> errmsg($errors->zip_code),
+		"frm_phone"		=> ov($frm["phone"]),
+		"errors_phone"		=> errmsg($errors->phone),
+		"frm_fax"		=> ov($frm["fax"]),
+		"errors_fax"		=> errmsg($errors->fax),
+		"frm_mobilephone"	=> ov($frm["mobilephone"]),
+		"errors_mobilephone"	=> errmsg($errors->mobilephone),
+		"frm_email"		=> ov($frm["email"]),
+		"errors_email"		=> errmsg($errors->email),
+		"frm_authdata"		=> $frm["authdata"] ? "checked" : "" ,
+		"frm_acceptadvert"	=> $frm["acceptadvert"] ? "checked" : "" ,
+		"frm_notes"		=> ov($frm["notes"]),
+		"errors_notes"		=> errmsg($errors->notes),
+		"frm_ournotes"		=> ov($frm["ournotes"]),
+		"errors_ournotes"	=> errmsg($errors->ournotes),
+		"frm_description"	=> ov($frm["description"]),
+		"errors_description"	=> errmsg($errors->brand_description),
+		"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
 	));
 	$t->set_block("page", "username_notok", "username_notok_blck");
 	$t->set_var("username_notok_blck", "");
@@ -275,48 +227,45 @@ function load_user_form_template($frm, $usertype, $page_number, $errors) {
 	else
 		$t->parse("username_ok_blck", "username_ok", true);
 	$t->pparse("out", "page");
-//	include("templates/user_form-".$HTTP_POST_VARS["usertype"].".ihtml");
 }
 
-function show_user_details($username) {
+function print_user_details($username) {
 
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	include ("$CFG->localedir" . $SESSION["lang"] . "/global-names.inc.php");
+	global $qid;
 
-	$qid = new DB_Sql;
-//	$qid = db_query("
 	$qid->Query("SELECT * FROM users WHERE username = '$username'");
-//	$frm = db_fetch_array($qid, 0);
 	$qid->next_record();
 
 	$t = new Template();
-	$t->set_file(array("page" => "templates/user_details-".$qid->f("usertype").".ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_file(array("page" => "templates/user_details-" . $qid->f("usertype") . ".ihtml"));
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var(array(
-			"frm_username"		=> ov($qid->f("username")),
-			"frm_priv"		=> ov($qid->f("priv")),
-			"frm_firstname"		=> ov($qid->f("firstname")),
-			"frm_lastname"		=> ov($qid->f("lastname")),
-			"frm_fiscalcode"	=> ov($qid->f("fiscalcode")),
-			"frm_address"		=> ovwbr($qid->f("address")),
-			"frm_number"		=> ov($qid->f("number")),
-			"frm_city"		=> ov($qid->f("city")),
-			"frm_country"		=> ov($qid->f("country")),
-			"frm_zip_code"		=> ov($qid->f("zip_code")),
-			"frm_phone"		=> ov($qid->f("phone")),
-			"frm_fax"		=> ov($qid->f("fax")),
-			"frm_mobilephone"	=> ov($qid->f("mobilephone")),
-			"frm_email"		=> ov($qid->f("email")),
-			"frm_authdata"		=> $qid->f("authdata") ? strtoupper($yes) : "" ,
-			"frm_acceptadvert"	=> $frm["acceptadvert"] ? strtoupper($yes) : "" ,
-			"frm_notes"		=> ovwbr($qid->f("notes")),
-			"frm_ournotes"		=> ovwbr($qid->f("ournotes")),
-			"frm_date"		=> ov($qid->f("date")),
+		"frm_username"		=> ov($qid->f("username")),
+		"frm_priv"		=> ov($qid->f("priv")),
+		"frm_firstname"		=> ov($qid->f("firstname")),
+		"frm_lastname"		=> ov($qid->f("lastname")),
+		"frm_fiscalcode"	=> ov($qid->f("fiscalcode")),
+		"frm_address"		=> ovwbr($qid->f("address")),
+		"frm_number"		=> ov($qid->f("number")),
+		"frm_city"		=> ov($qid->f("city")),
+		"frm_country"		=> ov($qid->f("country")),
+		"frm_zip_code"		=> ov($qid->f("zip_code")),
+		"frm_phone"		=> ov($qid->f("phone")),
+		"frm_fax"		=> ov($qid->f("fax")),
+		"frm_mobilephone"	=> ov($qid->f("mobilephone")),
+		"frm_email"		=> ov($qid->f("email")),
+		"frm_authdata"		=> $qid->f("authdata") ? strtoupper($yes) : "" ,
+		"frm_acceptadvert"	=> $frm["acceptadvert"] ? strtoupper($yes) : "" ,
+		"frm_notes"		=> ovwbr($qid->f("notes")),
+		"frm_ournotes"		=> ovwbr($qid->f("ournotes")),
+		"frm_date"		=> $userday[$qid->f("weekday")] . " " . $qid->f("day") . " " . $usermonth[$qid->f("month")] . " " . $qid->f("year")
 	));
 	$t->pparse("out", "page");
-//	include("templates/user_details-".$frm["usertype"].".ihtml");
 }
 
 function print_add_user_form($usertype) {
@@ -357,12 +306,10 @@ function print_edit_user_form($username) {
 	global $SESSION;
 	global $page_number, $dbchanged;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	/* load up the information for the user */
-	$qid = new DB_Sql;
-//	$qid = db_query("
 	$qid->Query("SELECT * FROM users WHERE username = '$username'");
-//	$frm = db_fetch_array($qid, 0);
 	$qid->next_record();
 	$frm["username"] = $qid->f("username");
 	$frm["password"] = $qid->f("password");
@@ -384,7 +331,11 @@ function print_edit_user_form($username) {
 	$frm["acceptadvert"] = $qid->f("acceptadvert");
 	$frm["notes"] = $qid->f("notes");
 	$frm["ournotes"] = $qid->f("ournotes");
-	$frm["date"] = $qid->f("date");
+	$frm["unixtime"] = $qid->f("unixtime");
+	$frm["year"] = $qid->f("year");
+	$frm["month"] = $qid->f("month");
+	$frm["day"] = $qid->f("day");
+	$frm["weekday"] = $qid->f("weekday");
 	$frm["fromip"] = $qid->f("fromip");
 
 	$frm["old_email"] = $frm["email"];
@@ -401,14 +352,11 @@ function delete_user($username) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
-	$qid = new DB_Sql;
-//	$qid = db_query("
 	$qid->Query("SELECT priv FROM users WHERE username = '$username'");
-//	$user = db_fetch_object($qid, 0);
 	$qid->next_record();
 	if ($qid->f("priv") != "admin") {
-//		$qid = db_query("
 		$qid->Query("DELETE FROM users WHERE username = '$username'");
 
 		if (empty($SESSION["goback"]["query_string"]))
@@ -418,16 +366,15 @@ function delete_user($username) {
 
 		$t = new Template();
 		$t->set_file(array("page" => "templates/user_deleted.ihtml"));
-		require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-		require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+		include ("$CFG->localelangdir" . "/global-common.inc.php");
+		include ("$CFG->localelangdir" . "/global-admin.inc.php");
 		$t->set_var(array(
-				"username"	=> ov($username),
-				"backurl"	=> $backurl
+			"username"	=> ov($username),
+			"backurl"	=> $backurl
 		));
 		$t->pparse("out", "page");
-//		include("templates/user_deleted.ihtml");
 	} else {
-		include("templates/".$SESSION["lang"]."/admin_not_deleted.ihtml");
+		include ("templates/" . $SESSION["lang"] . "/admin_not_deleted.ihtml");
 	}
 }
 
@@ -437,19 +384,19 @@ function insert_user($frm) {
  * of this tutorial it's left to the reader (you) to add them in :) */
 
 	global $CFG, $SESSION;
-	global $myday, $mymonth;
 //	include ($CFG->globalerror);
+	global $qid;
 
-	$date = $myday[date("w")] . date(" j") . "-" . date("n") . "-" . date("Y H:i:s");
+//	$date = $myday[date("w")] . date(" j") . "-" . date("n") . "-" . date("Y H:i:s");
+	$Dateusec = gettimeofday(); $unixtime = $Dateusec["sec"];
+	$year = date("Y"); $month = date("n"); $day = date("j"); $weekday = date("w");
 	$fromip = getenv("REMOTE_ADDR");
 
 	$password = generate_password();
 
-	$qid = new DB_Sql;
-//	$qid = db_query("
 	$qid->Query("
 		INSERT INTO users (
-			username
+			 username
 			,password
 			,usertype
 			,priv
@@ -469,7 +416,11 @@ function insert_user($frm) {
 			,acceptadvert
 			,notes
 			,ournotes
-			,date
+			,unixtime
+			,year
+			,month
+			,day
+			,weekday
 			,fromip
 		)
 		VALUES (
@@ -493,7 +444,11 @@ function insert_user($frm) {
 			,'$frm[acceptadvert]'
 			,'$frm[notes]'
 			,'$frm[ournotes]'
-			,'$date'
+			,'$unixtime'
+			,'$year'
+			,'$month'
+			,'$day'
+			,'$weekday'
 			,'$fromip'
 		)
 	");
@@ -505,14 +460,13 @@ function insert_user($frm) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/user_added.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var(array(
-			"frm_username"	=> ov($frm[username]),
-			"backurl"	=> $backurl
+		"frm_username"	=> ov($frm[username]),
+		"backurl"	=> $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/user_added.ihtml");
 }
 
 function update_user($frm) {
@@ -521,9 +475,8 @@ function update_user($frm) {
 	global $CFG, $SESSION;
 	global $username;
 //	include ($CFG->globalerror);
+	global $qid;
 
-	$qid = new DB_Sql;
-//	$qid = db_query("
 	$qid->Query("
 		UPDATE users SET
 			 priv = '$frm[priv]'
@@ -553,14 +506,13 @@ function update_user($frm) {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/user_updated.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var(array(
-			"username"	=> ov($username),
-			"backurl"	=> $backurl
+		"username"	=> ov($username),
+		"backurl"	=> $backurl
 	));
 	$t->pparse("out", "page");
-//	include("templates/user_updated.ihtml");
 }
 
 function print_user_list() {
@@ -572,22 +524,18 @@ function print_user_list() {
 	global $yes;
 	global $page_number, $dbchanged;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	if (!isset($page_number) || $dbchanged) {
-		$qid = new DB_Sql;
-//		$qid = db_query("
 		$qid->Query("
 			SELECT username, firstname, lastname, phone, email, authdata, acceptadvert
 			FROM users
 			WHERE username <> 'root'
 			ORDER BY username ASC
 		");
-
-//		$SESSION["numr"] = db_num_rows($qid);
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$SESSION["users"][$i] = db_fetch_array($qid, $i);
-			$qid->seek($i);
+//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["users"][$i]["username"] = $qid->f("username");
 			$SESSION["users"][$i]["firstname"] = $qid->f("firstname");
@@ -616,15 +564,15 @@ function print_user_list() {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/user_list.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_block("page", "pages_links_top", "pages_links_top_blck");
 	$t->set_var("pages_links_top_blck", "");
 	$t->set_block("page", "pages_links_bottom", "pages_links_bottom_blck");
 	$t->set_var("pages_links_bottom_blck", "");
 	if ($num_pages > 1) {
-		require("pages_links.php");
+		include ("pages_links.php");
 		$t->set_var("pages_links", $pages_links);
 		$t->parse("pages_links_top_blck", "pages_links_top", true);
 		$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
@@ -633,19 +581,18 @@ function print_user_list() {
 	$t->set_var("user_rows", "");
 	for ($i=$first; $i<=$last; $i++) {
 		$t->set_var(array(
-				"page_number"		=> $page_number,
-				"session_username"	=> ov($SESSION["users"][$i]["username"]),
-				"session_firstname"	=> ov($SESSION["users"][$i]["firstname"]),
-				"session_lastname"	=> $SESSION["users"][$i]["lastname"] == "" ? "&nbsp;" : ov($SESSION["users"][$i]["lastname"]),
-				"session_phone"		=> ov($SESSION["users"][$i]["phone"]),
-				"session_email"		=> ov($SESSION["users"][$i]["email"]),
-				"session_authdata"	=> $SESSION["users"][$i]["authdata"] ? strtoupper($yes) : "&nbsp;",
-				"session_acceptadvert"	=> $SESSION["users"][$i]["acceptadvert"] ? strtoupper($yes) : "&nbsp;"
+			"page_number"		=> $page_number,
+			"session_username"	=> ov($SESSION["users"][$i]["username"]),
+			"session_firstname"	=> ov($SESSION["users"][$i]["firstname"]),
+			"session_lastname"	=> $SESSION["users"][$i]["lastname"] == "" ? "&nbsp;" : ov($SESSION["users"][$i]["lastname"]),
+			"session_phone"		=> ov($SESSION["users"][$i]["phone"]),
+			"session_email"		=> ov($SESSION["users"][$i]["email"]),
+			"session_authdata"	=> $SESSION["users"][$i]["authdata"] ? strtoupper($yes) : "&nbsp;",
+			"session_acceptadvert"	=> $SESSION["users"][$i]["acceptadvert"] ? strtoupper($yes) : "&nbsp;"
 		));
 		$t->parse("user_rows", "user_row", true);
 	}
 	$t->pparse("out", "page");
-//	include("templates/user_list.ihtml");
 }
 
 function print_import_users_form() {
@@ -659,28 +606,26 @@ function print_import_users_form() {
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_form.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
-			"frm_newmode"			=> $frm["newmode"],
-			"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
-			"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
+		"frm_newmode"			=> $frm["newmode"],
+		"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
+		"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
 	));
 	$t->pparse("out", "page");
-//	include("templates/data_import_form.ihtml");
 }
 
-function import_users($userfile) {
+function import_users($HTTP_POST_FILES) {
 /* Import users from a text file */
 	global $CFG, $ME, $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
 	/* Let's open a transaction */
-	$qid = new DB_Sql;
-//	$qid = db_begin();
 	$qid->begin();
 
-	$fcontents = file ($userfile);
+	$fcontents = file ($HTTP_POST_FILES['userfile']['tmp_name']);
 	/* Traverse the file */
 	while (list ($line_num, $line) = each ($fcontents)) {
 		// Microsoft Stupidity Suppression
@@ -689,19 +634,16 @@ function import_users($userfile) {
 		$fldarr = split("\t",ereg_replace("\n$","",$line));
 //echo "<b>" . $line_num . "</b>:" . $line . "<br>";
 		/* dangerous characters quoting */
-		for ($i=0; $i<22; $i++)
+		for ($i=0; $i<26; $i++)
 			$fldarr[$i] = addslashes($fldarr[$i]);
 
 		/* Let's see if the user already exists ... */
-//		$qid = db_query("
 		$qid->Query("SELECT username FROM users WHERE username = '$fldarr[0]'");
-//		if (db_num_rows($qid) == 0) {
 		if ($qid->num_rows() == 0) {
 			/* ... if it doesn't exist let's create it in the users table ... */
-//			$qid = db_query("
 			$qid->Query("
 				INSERT INTO users (
-					username
+					 username
 					,password
 					,usertype
 					,priv
@@ -721,7 +663,11 @@ function import_users($userfile) {
 					,acceptadvert
 					,notes
 					,ournotes
-					,date
+					,unixtime
+					,year
+					,month
+					,day
+					,weekday
 					,fromip
 				)
 				VALUES (
@@ -747,11 +693,14 @@ function import_users($userfile) {
 					,'$fldarr[19]'
 					,'$fldarr[20]'
 					,'$fldarr[21]'
+					,'$fldarr[22]'
+					,'$fldarr[23]'
+					,'$fldarr[24]'
+					,'$fldarr[25]'
 				)
 			");
 		} else {
 			/* ... otherwise let's update it in the products table ... */
-//			$qid = db_query("
 			$qid->Query("
 				UPDATE users SET
 					usertype = '$fldarr[2]'
@@ -772,15 +721,18 @@ function import_users($userfile) {
 					,acceptadvert = '$fldarr[17]'
 					,notes = '$fldarr[18]'
 					,ournotes = '$fldarr[19]'
-					,date = '$fldarr[20]'
-					,fromip = '$fldarr[21]'
+					,unixtime = '$fldarr[20]'
+					,year = '$fldarr[21]'
+					,month = '$fldarr[22]'
+					,day = '$fldarr[23]'
+					,weekday = '$fldarr[24]'
+					,fromip = '$fldarr[25]'
 				WHERE username = '$fldarr[0]'
 			");
 		}
 	}
 
 	/* Let's close the transaction */
-//	$qid = db_commit();
 	$qid->commit();
 	
 	/* The End */
@@ -790,13 +742,11 @@ function import_users($userfile) {
 		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var("backurl", $backurl);
 	$t->pparse("out", "page");
-//	include("templates/data_import_end.ihtml");
-
 }
 
 ?>
