@@ -1,4 +1,4 @@
-<?
+<?php
 /* application.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -26,19 +26,19 @@ $CFG = new object;
 $CFG->dbms = "pgsql";	// PostgreSQL
 //$CFG->dbms = "mysql";	// MySQL
 
-$CFG->myname = "PgMarket 1.5.1 (development)";
+$CFG->myname = "PgMarket 1.5.2 (development)";
 
 $CFG->wwwroot     = "/~pratesi/pgmarket";	// without an ending "/"
 $CFG->dirroot     = "/home/pratesi/public_html/pgmarket";	// without an ending "/"
-$CFG->firstpage   = $CFG->wwwroot . "/firstpage.php";
-$CFG->templatedir = $CFG->dirroot . "/templates/";	// with an ending "/"
-$CFG->libdir      = $CFG->dirroot . "/lib";	// without an ending "/"
-$CFG->libwww      = $CFG->wwwroot . "/lib";	// without an ending "/"
-$CFG->localedir   = $CFG->dirroot . "/locale/";	// with an ending "/"
-$CFG->productswww = $CFG->wwwroot . "/products/";	// with an ending "/"
-$CFG->productsdir = $CFG->dirroot . "/products/";	// with an ending "/"
-$CFG->images      = $CFG->wwwroot . "/images/";	// with an ending "/"
-$CFG->wordlist    = $CFG->libdir . "/wordlist.txt";
+$CFG->firstpage   = "$CFG->wwwroot" . "/firstpage.php";
+$CFG->templatedir = "$CFG->dirroot" . "/templates/";	// with an ending "/"
+$CFG->libdir      = "$CFG->dirroot" . "/lib";	// without an ending "/"
+$CFG->libwww      = "$CFG->wwwroot" . "/lib";	// without an ending "/"
+$CFG->localedir   = "$CFG->dirroot" . "/locale/";	// with an ending "/"
+$CFG->productswww = "$CFG->wwwroot" . "/products/";	// with an ending "/"
+$CFG->productsdir = "$CFG->dirroot" . "/products/";	// with an ending "/"
+$CFG->images      = "$CFG->wwwroot" . "/images/";	// with an ending "/"
+$CFG->wordlist    = "$CFG->libdir" . "/wordlist.txt";
 
 $CFG->pnmpath     = "/usr/bin";	// without an ending "/"
 
@@ -55,12 +55,13 @@ $DB_DEBUG = true;
 $DB_DIE_ON_FAIL = true;
 
 /* load up standard libraries */
-require($CFG->libdir . "/stdlib.inc.php");
-require($CFG->libdir . "/db_" . $CFG->dbms . ".inc.php");	// PHPLib...
-require($CFG->libdir . "/" . $CFG->dbms . "_queries.inc.php");
-require($CFG->libdir . "/pgmarket.inc.php");
-require($CFG->libdir . "/cart.inc.php");
-require($CFG->libdir . "/template.inc.php");
+require ("$CFG->libdir" . "/stdlib.inc.php");
+require ("$CFG->libdir" . "/db_" . "$CFG->dbms" . ".inc.php");	// PHPLib...
+require ("$CFG->libdir" . "/" . "$CFG->dbms" . "_queries.inc.php");
+require ("$CFG->libdir" . "/pgmarket.inc.php");
+require ("$CFG->libdir" . "/cart.inc.php");
+require ("$CFG->libdir" . "/template.inc.php");
+require ("$CFG->libdir" . "/misc_settings.inc.php");
 
 /* setup some global variables */
 $ME = qualified_me();
@@ -108,7 +109,8 @@ if (! isset($SESSION["lang"])) {
 //	$SESSION["lang"] = "it";
 	$SESSION["lang"] = "us";
 }
-$CFG->globalerror = $CFG->localedir.$SESSION["lang"]."/global-error.inc.php";
+$CFG->globalerror = "$CFG->localedir" . $SESSION["lang"] . "/global-error.inc.php";
+$CFG->localelangdir = "$CFG->localedir" . $SESSION["lang"];
 
 //include ($CFG->global);
 
@@ -144,53 +146,6 @@ function formatted_weight($weight) {
 	return number_format ($weight, 2, ".", ",");
 }
 
-$SESSION["username_length"] = 16;
-$SESSION["username_length_min"] = 6;
-$SESSION["password_length"] = 32;
-$SESSION["priv_length"] = 5;
-$SESSION["firstname_length"] = 64;
-$SESSION["lastname_length"] = 64;
-$SESSION["name_length"] = 64;
-$SESSION["fiscalcode_length"] = 16;
-$SESSION["partitaiva_length"] = 11;
-$SESSION["address_length"] = 255;
-$SESSION["number_length"] = 5;
-$SESSION["city_length"] = 100;
-$SESSION["country_length"] = 100;
-$SESSION["zip_code_length"] = 5;
-$SESSION["phone_length"] = 32;
-$SESSION["phone_length_min"] = 5;
-$SESSION["fax_length"] = 32;
-$SESSION["fax_length_min"] = 5;
-$SESSION["mobilephone_length"] = 32;
-$SESSION["mobilephone_length_min"] = 5;
-$SESSION["email_length"] = 128;
-$SESSION["notes_length"] = 500;
-$SESSION["message_length"] = 5000;
-$SESSION["ournotes_length"] = 500;
-$SESSION["comments_length"] = 500;
-
-$SESSION["category_name_length"] = 100;
-$SESSION["category_description_length"] = 255;
-$SESSION["brand_name_length"] = 100;
-$SESSION["brand_description_length"] = 255;
-$SESSION["product_id_length"] = 25;
-$SESSION["product_name_length"] = 100;
-$SESSION["product_description_length"] = 500;
-$SESSION["product_extended_description_length"] = 2000;
-$SESSION["discqtymax"] = 1000;
-$SESSION["order_state_name_length"] = 100;
-$SESSION["order_state_description_length"] = 255;
-
-$SESSION["products_per_page"] = 10;	// max number of products to be shown per page (search results, admin products page)
-$SESSION["max_results"] = 100;		// max number of search results to accept the search request
-$SESSION["users_per_page"] = 10;	// max number of users to be shown per page (admin users page)
-$SESSION["orders_per_page"] = 10;	// max number of orders to be shown per page (admin orders page)
-$SESSION["categories_per_page"] = 10;	// max number of categories to be shown per page (admin orders page)
-$SESSION["brands_per_page"] = 10;	// max number of brands to be shown per page (admin brands page)
-$SESSION["iva_per_page"] = 10;		// max number of iva percentages to be shown per page (admin iva page)
-$SESSION["orders_states_per_page"] = 10; // max number of orders states to be shown per page (admin orders state page)
-
 $ordersdb["Customer"]	= "Customer      :";
 $ordersdb["Phone"]	= "Phone Contact :";
 $ordersdb["Address"]	= "Address       :";
@@ -215,25 +170,25 @@ $contact["AuthData"]		= "Authorization for data handling: ";
 $contact["AuthAdvert"]		= "Acceptance of advertising material: ";
 $contact["Message"]		= "Message:";
 
-$myday[1] = "Monday";
-$myday[2] = "Tuesday";
-$myday[3] = "Wednesday";
-$myday[4] = "Thursday";
-$myday[5] = "Friday";
-$myday[6] = "Saturday";
-$myday[0] = "Sunday";
+$adminday[1] = "Monday";
+$adminday[2] = "Tuesday";
+$adminday[3] = "Wednesday";
+$adminday[4] = "Thursday";
+$adminday[5] = "Friday";
+$adminday[6] = "Saturday";
+$adminday[0] = "Sunday";
 
-$mymonth[1] = "January";
-$mymonth[2] = "February";
-$mymonth[3] = "March";
-$mymonth[4] = "April";
-$mymonth[5] = "May";
-$mymonth[6] = "June";
-$mymonth[7] = "July";
-$mymonth[8] = "August";
-$mymonth[9] = "September";
-$mymonth[10] = "October";
-$mymonth[11] = "November";
-$mymonth[12] = "December";
+$adminmonth[1] = "January";
+$adminmonth[2] = "February";
+$adminmonth[3] = "March";
+$adminmonth[4] = "April";
+$adminmonth[5] = "May";
+$adminmonth[6] = "June";
+$adminmonth[7] = "July";
+$adminmonth[8] = "August";
+$adminmonth[9] = "September";
+$adminmonth[10] = "October";
+$adminmonth[11] = "November";
+$adminmonth[12] = "December";
 
 ?>
