@@ -1,4 +1,4 @@
-<?
+<?php
 /* application.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -23,30 +23,22 @@ class object {};
 /* setup the configuration object */
 $CFG = new object;
 
-$CFG->dbhost = "localhost";
 $CFG->dbms = "pgsql";	// PostgreSQL
-$CFG->port = "5432";	// PostgreSQL
 //$CFG->dbms = "mysql";	// MySQL
-//$CFG->port = "3306";	// MySQL
-$CFG->dbname = "pgmarket";
-$CFG->dbuser = "postgres";	// PostgreSQL
-$CFG->dbpass = "postgres";	// PostgreSQL
-//$CFG->dbuser = "mysql";	// MySQL
-//$CFG->dbpass = "mysql";	// MySQL
 
-$CFG->myname = "PgMarket 1.5.0 (development)";
+$CFG->myname = "PgMarket 1.5.2 (development)";
 
 $CFG->wwwroot     = "/~pratesi/pgmarket";	// without an ending "/"
 $CFG->dirroot     = "/home/pratesi/public_html/pgmarket";	// without an ending "/"
-$CFG->firstpage   = $CFG->wwwroot . "/firstpage.php";
-$CFG->templatedir = $CFG->dirroot . "/templates/";	// with an ending "/"
-$CFG->libdir      = $CFG->dirroot . "/lib";	// without an ending "/"
-$CFG->libwww      = $CFG->wwwroot . "/lib";	// without an ending "/"
-$CFG->localedir   = $CFG->dirroot . "/locale/";	// with an ending "/"
-$CFG->productswww = $CFG->wwwroot . "/products/";	// with an ending "/"
-$CFG->productsdir = $CFG->dirroot . "/products/";	// with an ending "/"
-$CFG->images      = $CFG->wwwroot . "/images/";	// with an ending "/"
-$CFG->wordlist    = $CFG->libdir . "/wordlist.txt";
+$CFG->firstpage   = "$CFG->wwwroot" . "/firstpage.php";
+$CFG->templatedir = "$CFG->dirroot" . "/templates/";	// with an ending "/"
+$CFG->libdir      = "$CFG->dirroot" . "/lib";	// without an ending "/"
+$CFG->libwww      = "$CFG->wwwroot" . "/lib";	// without an ending "/"
+$CFG->localedir   = "$CFG->dirroot" . "/locale/";	// with an ending "/"
+$CFG->productswww = "$CFG->wwwroot" . "/products/";	// with an ending "/"
+$CFG->productsdir = "$CFG->dirroot" . "/products/";	// with an ending "/"
+$CFG->images      = "$CFG->wwwroot" . "/images/";	// with an ending "/"
+$CFG->wordlist    = "$CFG->libdir" . "/wordlist.txt";
 
 $CFG->pnmpath     = "/usr/bin";	// without an ending "/"
 
@@ -63,11 +55,13 @@ $DB_DEBUG = true;
 $DB_DIE_ON_FAIL = true;
 
 /* load up standard libraries */
-require($CFG->libdir . "/stdlib.inc.php");
-require($CFG->libdir . "/" . $CFG->dbms . ".inc.php");
-require($CFG->libdir . "/pgmarket.inc.php");
-require($CFG->libdir . "/cart.inc.php");
-require($CFG->libdir . "/template.inc.php");
+require ("$CFG->libdir" . "/stdlib.inc.php");
+require ("$CFG->libdir" . "/db_" . "$CFG->dbms" . ".inc.php");	// PHPLib...
+require ("$CFG->libdir" . "/" . "$CFG->dbms" . "_queries.inc.php");
+require ("$CFG->libdir" . "/pgmarket.inc.php");
+require ("$CFG->libdir" . "/cart.inc.php");
+require ("$CFG->libdir" . "/template.inc.php");
+require ("$CFG->libdir" . "/misc_settings.inc.php");
 
 /* setup some global variables */
 $ME = qualified_me();
@@ -115,7 +109,8 @@ if (! isset($SESSION["lang"])) {
 	$SESSION["lang"] = "it";
 //	$SESSION["lang"] = "us";
 }
-$CFG->globalerror = $CFG->localedir.$SESSION["lang"]."/global-error.inc.php";
+$CFG->globalerror = "$CFG->localedir" . $SESSION["lang"] . "/global-error.inc.php";
+$CFG->localelangdir = "$CFG->localedir" . $SESSION["lang"];
 
 //include ($CFG->global);
 
@@ -155,53 +150,6 @@ function formatted_weight($weight) {
 //	return number_format ($weight, 2, ".", ",");
 }
 
-$SESSION["username_length"] = 16;
-$SESSION["username_length_min"] = 6;
-$SESSION["password_length"] = 32;
-$SESSION["priv_length"] = 5;
-$SESSION["firstname_length"] = 64;
-$SESSION["lastname_length"] = 64;
-$SESSION["name_length"] = 64;
-$SESSION["fiscalcode_length"] = 16;
-$SESSION["partitaiva_length"] = 11;
-$SESSION["address_length"] = 255;
-$SESSION["number_length"] = 5;
-$SESSION["city_length"] = 100;
-$SESSION["country_length"] = 100;
-$SESSION["zip_code_length"] = 5;
-$SESSION["phone_length"] = 32;
-$SESSION["phone_length_min"] = 5;
-$SESSION["fax_length"] = 32;
-$SESSION["fax_length_min"] = 5;
-$SESSION["mobilephone_length"] = 32;
-$SESSION["mobilephone_length_min"] = 5;
-$SESSION["email_length"] = 128;
-$SESSION["notes_length"] = 500;
-$SESSION["message_length"] = 5000;
-$SESSION["ournotes_length"] = 500;
-$SESSION["comments_length"] = 500;
-
-$SESSION["category_name_length"] = 100;
-$SESSION["category_description_length"] = 255;
-$SESSION["brand_name_length"] = 100;
-$SESSION["brand_description_length"] = 255;
-$SESSION["product_id_length"] = 25;
-$SESSION["product_name_length"] = 100;
-$SESSION["product_description_length"] = 500;
-$SESSION["product_extended_description_length"] = 2000;
-$SESSION["discqtymax"] = 1000;
-$SESSION["order_state_name_length"] = 100;
-$SESSION["order_state_description_length"] = 255;
-
-$SESSION["products_per_page"] = 10;	// max number of products to be shown per page (search results, admin products page)
-$SESSION["max_results"] = 100;		// max number of search results to accept the search request
-$SESSION["users_per_page"] = 10;	// max number of users to be shown per page (admin users page)
-$SESSION["orders_per_page"] = 10;	// max number of orders to be shown per page (admin orders page)
-$SESSION["categories_per_page"] = 10;	// max number of categories to be shown per page (admin categories page)
-$SESSION["brands_per_page"] = 10;	// max number of brands to be shown per page (admin brands page)
-$SESSION["iva_per_page"] = 10;		// max number of iva percentages to be shown per page (admin iva page)
-$SESSION["orders_states_per_page"] = 10; // max number of orders states to be shown per page (admin orders state page)
-
 $ordersdb["Customer"]	= "Cliente             :";
 $ordersdb["Phone"]	= "Recapito telefonico :";
 $ordersdb["Address"]	= "Indirizzo           :";
@@ -226,28 +174,25 @@ $contact["AuthData"]		= "Autorizzazione al trattamento dei dati personali:  ";
 $contact["AuthAdvert"]		= "Disponibilita` a ricevere materiale pubblicitario: " ;
 $contact["Message"]		= "Messaggio:";
 
-$myday[1] = "Lunedi";
-$myday[2] = "Martedi";
-$myday[3] = "Mercoledi";
-$myday[4] = "Giovedi";
-$myday[5] = "Venerdi";
-$myday[6] = "Sabato";
-$myday[0] = "Domenica";
+$adminday[1] = "Lunedi";
+$adminday[2] = "Martedi";
+$adminday[3] = "Mercoledi";
+$adminday[4] = "Giovedi";
+$adminday[5] = "Venerdi";
+$adminday[6] = "Sabato";
+$adminday[0] = "Domenica";
 
-$mymonth[1] = "Gennaio";
-$mymonth[2] = "Febbraio";
-$mymonth[3] = "Marzo";
-$mymonth[4] = "Aprile";
-$mymonth[5] = "Maggio";
-$mymonth[6] = "Giugno";
-$mymonth[7] = "Luglio";
-$mymonth[8] = "Agosto";
-$mymonth[9] = "Settembre";
-$mymonth[10] = "Ottobre";
-$mymonth[11] = "Novembre";
-$mymonth[12] = "Dicembre";
-
-/* connect to the database */
-db_connect($CFG->dbhost, $CFG->port, $CFG->dbname, $CFG->dbuser, $CFG->dbpass);
+$adminmonth[1] = "Gennaio";
+$adminmonth[2] = "Febbraio";
+$adminmonth[3] = "Marzo";
+$adminmonth[4] = "Aprile";
+$adminmonth[5] = "Maggio";
+$adminmonth[6] = "Giugno";
+$adminmonth[7] = "Luglio";
+$adminmonth[8] = "Agosto";
+$adminmonth[9] = "Settembre";
+$adminmonth[10] = "Ottobre";
+$adminmonth[11] = "Novembre";
+$adminmonth[12] = "Dicembre";
 
 ?>
