@@ -1,29 +1,25 @@
-<?
+<?php
 /* (c) 2000 Ying Zhang (ying@zippydesign.com) */
 /* (c) 2001 Marco Pratesi <pratesi@telug.it> */
-?>
 
-<?
 if (!empty($errormsg)) {
-	$t = new Template();
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-error.inc.php");
 	echo "<blockquote>";
-	echo "<h2><div style='color: #ff0000'>" . $t->get_var("Errors") . "</div></h2>";
-	echo "<div class=normal>";
+	echo "<h2><div style='color: #ff0000'>" . $Errors . "</div></h2>";
+	echo "<div class=\"normal\">";
 	echo $errormsg;
 	echo "</div>";
 	echo "</blockquote>";
 }
-?>
 
-<?
 if (!empty($noticemsg)) {
 	$t = new Template();
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
 	echo "<blockquote>";
-	echo "<div class=notice>";
+	echo "<div class=\"notice\">";
 	echo $t->get_var($noticemsg);
 	echo "</div>";
 	echo "</blockquote>";
 }
+
 ?>
