@@ -1,18 +1,16 @@
-<?
+<?php
 /* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
-
-   include("application.inc.php");
-   if ($SESSION["frames_used"]) {
+include ("application.inc.php");
+if ($SESSION["frames_used"]) {
 ?>
 
 <html>
 <frameset cols="180,*" framespacing=0 frameborder=no border=0>
 <frame name="categories" src="shopping/navigation.php?p=0" target="bodyframe">
-<frame name="bodyframe" src="<?=$CFG->firstpage?>">
+<frame name="bodyframe" src="<?php echo "$CFG->firstpage"; ?>">
 </frameset>
 </html>
 
-<? } else {
-   redirect("$CFG->firstpage");
-   }
+<?php
+} else redirect("$CFG->firstpage");
 ?>
