@@ -1,4 +1,4 @@
-<?
+<?php
 /* cart.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -87,6 +87,10 @@ class Cart {
 		return $count;
 	}
 
+	function productitemcount($productid) {
+		return $this->items[$productid];
+	}
+
 	function get_productid_list() {
 	/* return a comma delimited list of all the products in the cart, this will
 	 * be used for queries, eg. SELECT id, price FROM products WHERE id IN ....
@@ -121,17 +125,13 @@ class Cart {
 			return;
 		}
 
-//		$qid = new DB_Sql;
-//		$qid = db_query("
+//		$qid = new PGM_Sql;
 		$qid->Query("
 			SELECT p.id, p.price, p.discount, p.discqty, p.weight, i.iva
 			FROM products p, iva i
 			WHERE p.iva_id = i.id AND p.id IN ($in_clause)
 		");
-//		$numr = db_num_rows($qid);
-//		for ($i=0; $i<$numr; $i++) {
 		while ($qid->next_record()) {
-//			$product = db_fetch_object($qid, $i);
 			if ($this->items[$qid->f("id")] >= $qid->f("discqty")) {
 				$this->subtotals[$qid->f("id")] = $this->items[$qid->f("id")] * $qid->f("price") * (100 - $qid->f("discount")) / 100;
 			} else {
