@@ -1,4 +1,4 @@
-<?
+<?php
 /* mymarket.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -23,19 +23,19 @@ function is_logged_in() {
 
 	global $SESSION, $REMOTE_ADDR;
 	return isset($SESSION)
-		&& isset($SESSION["user"])
-		&& isset($SESSION["ip"])
-		&& $SESSION["ip"] == $REMOTE_ADDR;
+		&& isset($SESSION["user"]);
+// to avoid problems with proxies
+//		&& isset($SESSION["ip"])
+//		&& $SESSION["ip"] == $REMOTE_ADDR;
 }
 
-function load_user_profile() {
+function load_user_profile(&$qid) {
 /* load up the user's details */
 
 	global $SESSION;
 	
 	$username = $SESSION["user"]["username"];
-	$qid = new DB_Sql;
-//	$qid = db_query("
+//	$qid = new PGM_Sql;
 	$qid->Query("
 		SELECT firstname, lastname, usertype, priv,
 			fiscalcode, address, number, city, country, zip_code,
@@ -64,7 +64,6 @@ function load_user_profile() {
 	$arr["notes"] = $qid->f("notes");
 
 	return $arr;
-//	return db_fetch_array($qid, 0);
 }
 
 function require_login() {
@@ -74,7 +73,7 @@ function require_login() {
 	global $CFG, $SESSION;
 	if (! is_logged_in()) {
 		$SESSION["wantsurl"] = qualified_me();
-		redirect("$CFG->wwwroot/login.php");
+		redirect("$CFG->wwwroot" . "/login.php");
 	}
 }
 
@@ -86,11 +85,10 @@ function require_priv($priv) {
 
 	if ($SESSION["user"]["priv"] != $priv) {
 		$t = new Template();
-		$t->set_file(array("page" => "$CFG->templatedir"."insufficient_privileges.ihtml"));
-		require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+		$t->set_file(array("page" => "$CFG->templatedir" . "insufficient_privileges.ihtml"));
+		include ("$CFG->localelangdir" . "/global-admin.inc.php");
 		$t->set_var("wwwroot", $CFG->wwwroot);
 		$t->pparse("out", "page");
-//		include("$CFG->templatedir"."insufficient_privileges.ihtml");
 		die;
 	}
 }
@@ -103,154 +101,34 @@ function has_priv($priv) {
 }
 
 function build_category_path(&$qid, $id=1, &$category_path) {
-// puts recursively in $category_path the path of the product categories,
-// starting from the top to the category specified by $id
+// puts in $category_path the path of the product categories,
+// starting from the category specified by $id and ending with the top
 
 	global $CFG;
 
-//	$qid = new DB_Sql;
-//	$qid = db_query("
-	$qid->Query("
-		SELECT parent_id, name
-		FROM categories
-		WHERE id = '$id'
-	");
-//	if (db_num_rows($qid)) {
-	if ($qid->num_rows()) {
-//		list($parent, $name) = db_fetch_row($qid, 0);
-		$qid->next_record();
-		$parent = $qid->f("parent_id");
-		$name = $qid->f("name");
-		$name = "<a href='$CFG->wwwroot/shopping/?id=$id'>" . stripslashes($name) . "</a>";
-	} else {
-		$parent = 1;
-		$name = "";
+//	$qid = new PGM_Sql;
+
+	while ($id > 1) {
+		$qid->Query("
+			SELECT parent_id, name
+			FROM categories
+			WHERE id = '$id'
+		");
+		if ($qid->num_rows()) {
+			$qid->next_record();
+			$parent = $qid->f("parent_id");
+			$name = $qid->f("name");
+			$name = "<a href='$CFG->wwwroot/shopping/?id=$id'>" . stripslashes($name) . "</a>";
+			$category_path = " &gt; " . $name . $category_path;
+		} else {
+			$parent = 1;
+			$name = "";
+		}
+		$id = $parent;
 	}
+	$category_path = "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a>" . $category_path;
+
 //	$qid->close();
-
-	if ($parent > 1) {
-		$category_path = " &gt; " . $name . $category_path;
-		build_category_path(&$qid, $parent, &$category_path);
-	} elseif ($id > 1) {
-		$category_path = "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a> &gt; " . $name . $category_path;
-	} elseif ($id == 1) {
-		$category_path = "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a>" . $category_path;
-	}
-}
-
-function build_catbrowser(&$output, $parent=1, $indent="..") {
-/* recursively go through the category tree, starting at a parent, and
- * drill down, printing options for a selection list box.
- * this is not an efficient algorithm because it has to issue
- * one query per category!!  it's only used because it is easy to understand.
- */
-	global $CFG, $SESSION;
-
-	$qid = new DB_Sql;
-//	$qid = db_query("
-	$qid->Query("
-		SELECT id, name
-		FROM categories
-		WHERE parent_id = '$parent' AND id <> 1
-		ORDER BY special_level, name
-	");
-
-	$cat = array();
-	$numr = $qid->num_rows();
-	for ($i=0;$i<$numr;$i++) {
-		$qid->seek($i);
-		$qid->next_record();
-		$cat[$i]["id"] = $qid->f("id");
-		$cat[$i]["name"] = $qid->f("name");
-	}
-	$qid->close();
-
-//	$numr = db_num_rows($qid);
-	for ($i=0;$i<$numr;$i++) {
-//		$cat =  db_fetch_object($qid, $i);
-		$output .= $indent . stripslashes($cat[$i]["name"]) . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat[$i]["id"] . "^" . $SESSION["catbrowser_target"] . "\n";
-		if ($cat[$i]["id"] != $parent) {
-			build_catbrowser($output, $cat[$i]["id"], $indent.".");
-		}
-	}
-}
-
-function build_catbrowser_js(&$qid, &$output, $parent=1, $indent="..") {
-/* recursively go through the category tree, starting at a parent, and
- * drill down, printing options for a selection list box.
- * this is not an efficient algorithm because it has to issue
- * one query per category!!  it's only used because it is easy to understand.
- */
-	global $CFG;
-
-//	$qid = new DB_Sql;
-//	$qid = db_query("
-	$qid->Query("
-		SELECT id, name
-		FROM categories
-		WHERE parent_id = '$parent' AND id <> 1
-		ORDER BY special_level, name
-	");
-
-	$cat = array();
-	$numr = $qid->num_rows();
-	for ($i=0;$i<$numr;$i++) {
-		$qid->seek($i);
-		$qid->next_record();
-		$cat[$i]["id"] = $qid->f("id");
-		$cat[$i]["name"] = $qid->f("name");
-	}
-//	$qid->close();
-
-//	$numr = db_num_rows($qid);
-	for ($i=0;$i<$numr;$i++) {
-//		$cat =  db_fetch_object($qid, $i);
-//		if (getenv("QUERY_STRING") == "")
-			$output .= $indent . $cat[$i]["name"] . "^" . $CFG->wwwroot . "/shopping/?id=" . $cat[$i]["id"] . "\n";
-//		else
-//			$output .= $indent . $cat[$i]["name"] . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat[$i]["id"] . "\n";
-		if ($cat[$i]["id"] != $parent) {
-			build_catbrowser_js(&$qid, $output, $cat[$i]["id"], $indent.".");
-		}
-	}
-}
-
-function build_category_tree(&$output, &$preselected, $parent=1, $indent="") {
-/* recursively go through the category tree, starting at a parent, and
- * drill down, printing options for a selection list box.  preselected
- * items are marked as being selected.  this is not an efficient algorithm
- * because it has to issue one query per category!!  it's only used because it
- * is easy to understand.
- */
-
-	$qid = new DB_Sql;
-//	$qid = db_query("
-	$qid->Query("
-		SELECT id, name
-		FROM categories
-		WHERE parent_id = '$parent'
-		ORDER BY special_level, name
-	");
-
-	$cat = array();
-	$numr = $qid->num_rows();
-	for ($i=0;$i<$numr;$i++) {
-		$qid->seek($i);
-		$qid->next_record();
-		$cat[$i]["id"] = $qid->f("id");
-		$cat[$i]["name"] = $qid->f("name");
-	}
-	$qid->close();
-
-//	$numr = db_num_rows($qid);
-	for ($i=0;$i<$numr;$i++) {
-//		$cat =  db_fetch_object($qid, $i);
-		$selected = in_array($cat[$i]["id"], $preselected) ? "selected" : "";
-		$output .= "<option value=\"" . ov($cat[$i]["id"]) . "\" $selected>" . $indent . ov($cat[$i]["name"]);
-		if ($cat[$i]["id"] != $parent) {
-			build_category_tree($output, $preselected, $cat[$i]["id"], $indent."&nbsp;&nbsp;");
-		}
-	}
 }
 
 function generate_password($maxlen=10) {
@@ -270,41 +148,37 @@ function generate_password($maxlen=10) {
 	return substr($word1 . $filler1 . $word2, 0, $maxlen);
 }
 
-function errmsg(&$errorvar) {
+function errmsg($errorvar) {
 /* if $errorvar is set, then returns an error marker << */
-	if (isset($errorvar))
+	if ($errorvar)
 		return "<font color=#ff0000>&lt;&lt;</font>";
 }
 
-function errmsg2(&$errorvar) {
+function errmsg2($errorvar) {
 /* like errmsg(), but returns the marker >> */
-	if (isset($errorvar))
+	if ($errorvar)
 		return "<font color=#ff0000>&gt;&gt;</font>";
 }
 
-function username_exists($username) {
+function username_exists(&$qid, $username) {
 /* returns the true if the username exists */
 
-	$qid = db_query("SELECT 1 FROM users WHERE username = '$username'");
-	return db_num_rows($qid);
+//	$qid = new PGM_Sql;
+	$qid->begin();
+	$qid->Query("SELECT 1 FROM users WHERE username = '$username'");
+	$appoggio = $qid->num_rows();
+	$qid->commit();
+	return $appoggio;
 }
 
-//function email_exists($email) {
-///* returns true the email address exists */
-///*
-//	$qid = db_query("SELECT 1 FROM users WHERE email = '$email'");
-//	return db_num_rows($qid);
-//}
-
-function reset_user_password($username) {
+function reset_user_password(&$qid, $username) {
 /* resets the password for the user with the username $username, and sends it
  * to him/her via email */
 
 	global $CFG;
 	global $SESSION;
 
-	$qid = new DB_Sql;
-//	$qid = db_query("
+//	$qid = new PGM_Sql;
 	$qid->begin();
 
 	/* load up the user record */
@@ -313,7 +187,6 @@ function reset_user_password($username) {
 		FROM users
 		WHERE username = '$username'
 	");
-//	$user = db_fetch_object($qid, 0);
 	$qid->next_record();
 	if ($qid->f("priv") == "admin" || !has_priv("admin")) {
 		return 1;
@@ -327,13 +200,12 @@ function reset_user_password($username) {
 	$var->username = $qid->f("username");
 	$var->fullname = $qid->f("firstname") . " " . $qid->f("lastname");
 	$var->newpassword = $newpassword;
-	$var->support = $CFG->support;
-	$var->myname = $CFG->myname;
+	$var->support = "$CFG->support";
+	$var->myname = "$CFG->myname";
 
-	$emailbody = read_template($CFG->templatedir.$SESSION["lang"]."/reset_password.ihtml", $var);
+	$emailbody = read_template("$CFG->templatedir" . $SESSION["lang"] . "/reset_password.ihtml", $var);
 
 	$appoggio = $qid->f("email");
-//	$qid = db_query("
 	$qid->Query("
 		UPDATE users
 		SET password = '" . md5($newpassword) ."'
@@ -341,13 +213,13 @@ function reset_user_password($username) {
 	");
 	mail(
 		"$var->fullname <$appoggio>",
-		$CFG->myname . " Account Information",
+		"$CFG->myname" . " Account Information",
 		$emailbody,
 		"From: $var->support"
 	);
 
 	$qid->commit();
-	$qid->close();
+//	$qid->close();
 
 	return 0;
 }
@@ -435,7 +307,7 @@ function validate_username($username, &$errors, &$msg) {
 
 	$stripped_username = str_replace(" ", "", $username);
 
-	if (empty($username) || empty($stripped_username)) {
+	if ($username == "" || $stripped_username == "") {
 		$errors->username = true;
 		$msg .= "<li>".$empty_username;
 	} else if (strlen($username) > $SESSION["username_length"]) {
@@ -466,8 +338,8 @@ function validate_password($password, &$errors, &$msg) {
 		$errors->password = true;
 		$msg .= "<li>".$empty_password;
 	}
-	if (empty($password) || strlen($password) != 32
-		|| empty($stripped_password) || strlen($stripped_password) != 32
+	if ($password == "" || strlen($password) != 32
+		|| $stripped_password == "" || strlen($stripped_password) != 32
 		|| $password != $matched_password[0]) {
 		$errors->password = true;
 		$msg = $please_enable_javascript.$msg;
@@ -479,7 +351,7 @@ function validate_firstname($firstname, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($firstname)) {
+	if ($firstname == "") {
 		$errors->firstname = true;
 		$msg .= "<li>".$empty_firstname;
 	} else if (strlen($firstname) > $SESSION["firstname_length"]) {
@@ -493,7 +365,7 @@ function validate_ragionesociale($ragionesociale, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($ragionesociale)) {
+	if ($ragionesociale == "") {
 		$errors->firstname = true;
 		$msg .= "<li>".$empty_ragionesociale;
 	} else if (strlen($ragionesociale) > $SESSION["firstname_length"]) {
@@ -507,7 +379,7 @@ function validate_name($name, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($name)) {
+	if ($name == "") {
 		$errors->name = true;
 		$msg .= "<li>".$empty_name;
 	} else if (strlen($name) > $SESSION["name_length"]) {
@@ -521,7 +393,7 @@ function validate_lastname($lastname, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($lastname)) {
+	if ($lastname == "") {
 		$errors->lastname = true;
 		$msg .= "<li>".$empty_lastname;
 	} else if (strlen($lastname) > $SESSION["lastname_length"]) {
@@ -535,7 +407,7 @@ function validate_customer($customer, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($customer)) {
+	if ($customer == "") {
 		$errors->customer = true;
 		$msg .= "<li>".$empty_customer;
 	} else if (strlen($customer) > $SESSION["firstname_length"] + $SESSION["lastname_length"] + 1) {
@@ -623,7 +495,7 @@ function validate_fiscalcode($fiscalcode, &$errors, &$msg) {
 	$odd["Y"] = 24;
 	$odd["Z"] = 25;
 
-	if (empty($fiscalcode)) {
+	if ($fiscalcode == "") {
 		$errors->fiscalcode = true;
 		$msg .= "<li>".$empty_fiscalcode;
 	} else if (strlen($fiscalcode) != $SESSION["fiscalcode_length"]) {
@@ -658,7 +530,7 @@ function validate_partitaiva($partitaiva, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($partitaiva)) {
+	if ($partitaiva == "") {
 		$errors->fiscalcode = true;
 		$msg .= "<li>".$empty_partitaiva;
 	} else if (strlen($partitaiva) != $SESSION["partitaiva_length"]) {
@@ -678,7 +550,7 @@ function validate_address($address, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($address)) {
+	if ($address == "") {
 		$errors->address = true;
 		$msg .= "<li>".$empty_address;
 	} else if (strlen($address) > $SESSION["address_length"]) {
@@ -703,7 +575,7 @@ function validate_city($city, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($city)) {
+	if ($city == "") {
 		$errors->city = true;
 		$msg .= "<li>".$empty_city;
 	} else if (strlen($city) > $SESSION["city_length"]) {
@@ -717,7 +589,7 @@ function validate_country($country, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($country)) {
+	if ($country == "") {
 		$errors->country = true;
 		$msg .= "<li>".$empty_country;
 	} else if (strlen($country) > $SESSION["country_length"]) {
@@ -751,7 +623,7 @@ function validate_phone($phone, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($phone)) {
+	if ($phone == "") {
 		$errors->phone = true;
 		$msg .= "<li>".$empty_phone;
 	} else if (strlen($phone) > $SESSION["phone_length"]) {
@@ -780,7 +652,7 @@ function validate_contact($contact, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($contact)) {
+	if ($contact == "") {
 		$errors->contact = true;
 		$msg .= "<li>".$empty_contact;
 	} else if (strlen($contact) > $SESSION["phone_length"]) {
@@ -861,7 +733,7 @@ function validate_email($email, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($email)) {
+	if ($email == "") {
 		$errors->email = true;
 		$msg .= "<li>".$empty_email;
 	} else if (strlen($email) > $SESSION["email_length"]) {
@@ -892,7 +764,7 @@ function validate_message($message, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($message)) {
+	if ($message == "") {
 		$errors->message = true;
 		$msg .= "<li>".$empty_message;
 	} else if (strlen($message) > $SESSION["message_length"]) {
@@ -930,7 +802,7 @@ function validate_category_name($category_name, &$errors, &$msg) {
 
 	$stripped_category_name = str_replace(" ", "", $category_name);
 
-	if (empty($category_name) || empty($stripped_category_name)) {
+	if ($category_name == "" || $stripped_category_name == "") {
 		$errors->category_name = true;
 		$msg .= "<li>".$empty_category_name;
 	} else if (strlen($category_name) > $SESSION["category_name_length"]) {
@@ -957,7 +829,7 @@ function validate_brand_name($brand_name, &$errors, &$msg) {
 
 	$stripped_brand_name = str_replace(" ", "", $brand_name);
 
-	if (empty($brand_name) || empty($stripped_brand_name)) {
+	if ($brand_name == "" || $stripped_brand_name == "") {
 		$errors->brand_name = true;
 		$msg .= "<li>".$empty_brand_name;
 	} else if (strlen($brand_name) > $SESSION["brand_name_length"]) {
@@ -977,50 +849,50 @@ function validate_brand_description($brand_description, &$errors, &$msg) {
 	}
 }
 
-function validate_product_id($product_id, &$errors, &$msg) {
+function validate_product_code($product_code, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	if (empty($product_id)) {
-		$errors->product_id = true;
-		$msg .= "<li>".$product_id_is_empty;
+	if ($product_code == "") {
+		$errors->product_code = true;
+		$msg .= "<li>".$product_code_is_empty;
 	} else {
-		if ($product_id != str_replace(" ", "", $product_id)) {
-			$errors->product_id = true;
-			$msg .= "<li>".$product_id_wspace;
+/*
+		if ($product_code != str_replace(" ", "", $product_code)) {
+			$errors->product_code = true;
+			$msg .= "<li>".$product_code_wspace;
 		}
-		if ($product_id != str_replace("&", "", $product_id)) {
-			$errors->product_id = true;
-			$msg .= "<li>".$product_id_wampersand;
+		if ($product_code != str_replace("&", "", $product_code)) {
+			$errors->product_code = true;
+			$msg .= "<li>".$product_code_wampersand;
 		}
-		if ($product_id != str_replace("?", "", $product_id)) {
-			$errors->product_id = true;
-			$msg .= "<li>".$product_id_wquestionm;
+		if ($product_code != str_replace("?", "", $product_code)) {
+			$errors->product_code = true;
+			$msg .= "<li>".$product_code_wquestionm;
 		}
-		if (strlen($product_id) > $SESSION["product_id_length"]) {
-			$errors->product_id = true;
-			$msg .= "<li>".$product_id_too_long;
+*/
+		if (strlen($product_code) > $SESSION["product_code_length"]) {
+			$errors->product_code = true;
+			$msg .= "<li>".$product_code_too_long;
 		}
 	}
 }
 
-function product_id_exists($product_id, &$errors, &$msg) {
-
-	global $CFG, $SESSION;
-	include ($CFG->globalerror);
-
-	$qid = new DB_Sql;
-//	$qid = db_query("
-	$qid->Query("SELECT id FROM products WHERE id = '$product_id'");
-
-//	if (db_num_rows($qid) > 0) {
-	if ($qid->num_rows() > 0) {
-		$errors->product_exists = true;
-		$msg .= "<li>".$the_product_id.$product_id.$already_exists;
-	}
-	$qid->close();
-}
+//function product_id_exists(&$qid, $product_id, &$errors, &$msg) {
+//
+//	global $CFG, $SESSION;
+//	include ($CFG->globalerror);
+//
+////	$qid = new PGM_Sql;
+//	$qid->Query("SELECT id FROM products WHERE id = '$product_id'");
+//
+//	if ($qid->num_rows() > 0) {
+//		$errors->product_exists = true;
+//		$msg .= "<li>".$the_product_id.$product_id.$already_exists;
+//	}
+////	$qid->close();
+//}
 
 function validate_product_name($product_name, &$errors, &$msg) {
 
@@ -1029,7 +901,7 @@ function validate_product_name($product_name, &$errors, &$msg) {
 
 	$stripped_product_name = str_replace(" ", "", $product_name);
 
-	if (empty($product_name) || empty($stripped_product_name)) {
+	if ($product_name == "" || $stripped_product_name == "") {
 		$errors->product_name = true;
 		$msg .= "<li>".$empty_product_name;
 	} else if (strlen($product_name) > $SESSION["product_name_length"]) {
@@ -1116,7 +988,7 @@ function validate_order_state_name($order_state_name, &$errors, &$msg) {
 
 	$stripped_order_state_name = str_replace(" ", "", $order_state_name);
 
-	if (empty($order_state_name) || empty($stripped_order_state_name)) {
+	if ($order_state_name == "" || $stripped_order_state_name == "") {
 		$errors->order_state_name = true;
 		$msg .= "<li>".$empty_order_state_name;
 	} else if (strlen($order_state_name) > $SESSION["order_state_name_length"]) {
