@@ -1,4 +1,4 @@
-<?
+<?php
 
 /* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 /* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
@@ -8,7 +8,7 @@ $t->set_var(array(
 
 "Insufficient_Privileges" => "Diritti insufficienti",
 "Administration" => "Amministrazione",
-"admin_footer_message" => $CFG->myname . " \"<i>Commercio elettronico - Electronic Store</i>\"",
+"admin_footer_message" => "$CFG->myname" . " \"<i>Commercio elettronico - Electronic Store</i>\"",
 "Save_Changes" => "Salva modifiche",
 "Import_Button_Label" => "Importa",
 "Add_Subcategory" => "Aggiungi sottocategoria",
@@ -22,7 +22,7 @@ $t->set_var(array(
 "Edit_this_product" => "Modifica questo prodotto",
 "Special_Level" => "Livello",
 "Special_Flag" => "Prodotto Speciale",
-"Delete_Actual_Image" => "Elimina Immagine Attuale (lascia il prodotto senza immagine)",
+"Delete_Current_Image" => "Elimina Immagine Attuale (lascia il prodotto senza immagine)",
 "Import_Images_Button_Label" => "Importa Immagini",
 "Brands_Management" => "Amministrazione delle marche",
 "B_Add_Brand" => "[+M] Aggiungi marca",
@@ -56,9 +56,9 @@ $t->set_var(array(
 "The_order_state" => "Lo stato",
 "Order_State_reset_for_orders" => "Lo stato degli ordini &egrave; stato azzerato per tutti gli ordini in tale stato",
 "Add_a_product_under" => "Aggiungi un prodotto a",
-"actually_its_name_is_male_singular" => "attualmente si chiama",
-"actually_its_name_is_female_singular" => "attualmente si chiama",
-"actually_its_value_is_female_singular" => "attualmente vale",
+"currently_its_name_is_male_singular" => "attualmente si chiama",
+"currently_its_name_is_female_singular" => "attualmente si chiama",
+"currently_its_value_is_female_singular" => "attualmente vale",
 "Users_Management" => "Gestione degli utenti",
 "Users" => "Utenti",
 "USERS" => "UTENTI",
