@@ -1,9 +1,11 @@
-<?
+<?php
 
 /* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 /* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
 /* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */
 
+$Errors = "Errori";
+
 ////////////////////////////////////////////////////////////
 // Top level scripts
 ////////////////////////////////////////////////////////////
@@ -18,8 +20,8 @@ $the_username = "La Username";
 $already_exists = " &egrave; gi&agrave; in uso";
 
 $empty_username = "Non &egrave; stata specificata la Username";
-$username_too_long = "Username troppo lunga: ".$SESSION["username_length"]." caratteri max";
-$username_too_short = "Username troppo corta: ".$SESSION["username_length_min"]." caratteri min";
+$username_too_long = "Username troppo lunga: " . $SESSION["username_length"] . " caratteri max";
+$username_too_short = "Username troppo corta: " . $SESSION["username_length_min"] . " caratteri min";
 $not_valid_username = "Username non valida: usare solo caratteri alfanumerici";
 
 $passwords_do_not_match = "Le password fornite non coincidono";
@@ -35,45 +37,45 @@ permette di criptare le password e, quindi, di offrire molta sicurezza
 in pi&ugrave; a chi fa uso di questo negozio virtuale.
 <p>
 Perci&ograve; per acquistare nel nostro negozio virtuale &egrave; necessario
-un navigatore che supporti JavaScript, come ad esempio Netscape o Explorer.
+un navigatore che supporti JavaScript, come ad esempio Mozilla, Netscape o Explorer.
 Se si sta usando un navigatore che supporta JavaScript ma tale supporto
 &egrave; stato disabilitato, si prega di modificare le impostazioni
 in modo da abilitare JavaScript.
 <p>
-Nota: le impostazioni di default di Netscape ed Explorer
+Nota: le impostazioni di default di Mozilla, Netscape ed Explorer
 prevedono l'uso di JavaScript.
 </b><br><br>";
 
 $empty_firstname = "Non &egrave; stato specificato il Nome";
-$firstname_too_long = "Nome troppo lungo: ".$SESSION["firstname_length"]." caratteri max";
+$firstname_too_long = "Nome troppo lungo: " . $SESSION["firstname_length"] . " caratteri max";
 
 $empty_ragionesociale = "Non &egrave; stata specificata la Ragione Sociale";
-$ragionesociale_too_long = "Ragione Sociale troppo lunga: ".$SESSION["firstname_length"]." caratteri max";
+$ragionesociale_too_long = "Ragione Sociale troppo lunga: " . $SESSION["firstname_length"] . " caratteri max";
 
 $empty_lastname = "Non &egrave; stato specificato il Cognome";
-$lastname_too_long = "Cognome troppo lungo: ".$SESSION["lastname_length"]." caratteri max";
+$lastname_too_long = "Cognome troppo lungo: " . $SESSION["lastname_length"] . " caratteri max";
 
 $empty_name = "Non &egrave; stato specificato il Nome";
-$name_too_long = "Nome troppo lungo: ".$SESSION["name_length"]." caratteri max";
+$name_too_long = "Nome troppo lungo: " . $SESSION["name_length"] . " caratteri max";
 
 $empty_fiscalcode = "Non &egrave; stato specificato il Codice Fiscale";
-$bad_fiscalcode_length = "Il Codice Fiscale deve contenere ".$SESSION["fiscalcode_length"]." caratteri alfanumerici";
+$bad_fiscalcode_length = "Il Codice Fiscale deve contenere " . $SESSION["fiscalcode_length"] . " caratteri alfanumerici";
 $not_valid_fiscalcode = "Codice Fiscale non valido";
 
 $empty_partitaiva = "Non &egrave; stata specificata la Partita IVA";
-$bad_partitaiva_length = "La Partita IVA deve contenere ".$SESSION["partitaiva_length"]." cifre";
+$bad_partitaiva_length = "La Partita IVA deve contenere " . $SESSION["partitaiva_length"] . " cifre";
 $not_valid_partitaiva = "Partita IVA non valida";
 
 $empty_address = "Non &egrave; stato specificato l'indirizzo";
-$address_too_long = "Via/Piazza troppo lunga: ".$SESSION["address_length"]." caratteri max";
+$address_too_long = "Via/Piazza troppo lunga: " . $SESSION["address_length"] . " caratteri max";
 
-$number_too_long = "Numero troppo lungo: ".$SESSION["number_length"]." caratteri max";
+$number_too_long = "Numero troppo lungo: " . $SESSION["number_length"] . " caratteri max";
 
 $empty_city = "Non &egrave; stato specificato il comune";
-$city_too_long = "Comune troppo lungo: ".$SESSION["city_length"]." caratteri max";
+$city_too_long = "Comune troppo lungo: " . $SESSION["city_length"] . " caratteri max";
 
 $empty_country = "Non &egrave; stata specificata la citt&agrave;";
-$country_too_long = "Citt&agrave; troppo lunga: ".$SESSION["country_length"]." caratteri max";
+$country_too_long = "Citt&agrave; troppo lunga: " . $SESSION["country_length"] . " caratteri max";
 
 $empty_zip_code = "Riempire il campo del CAP";
 $zip_code_is_zero = "Il CAP deve essere maggiore di zero";
@@ -81,28 +83,28 @@ $zip_code_notint = "Il campo del CAP deve contenere un numero intero, quindi sol
 $zip_code_length_is_wrong = "Il CAP deve contenere esattamente " . $SESSION["zip_code_length"] . " cifre";
 
 $empty_phone = "Non &egrave; stato specificato il numero di telefono";
-$phone_too_long = "Numero di telefono troppo lungo: ".$SESSION["phone_length"]." caratteri max";
-$phone_too_short = "Numero di telefono troppo corto: ".$SESSION["phone_length_min"]." caratteri min";
+$phone_too_long = "Numero di telefono troppo lungo: " . $SESSION["phone_length"] . " caratteri max";
+$phone_too_short = "Numero di telefono troppo corto: " . $SESSION["phone_length_min"] . " caratteri min";
 $not_valid_phone = "Numero di telefono non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";
 
-$fax_too_long = "Numero di fax troppo lungo: ".$SESSION["fax_length"]." caratteri max";
-$fax_too_short = "Numero di fax troppo corto: ".$SESSION["fax_length_min"]." caratteri min";
+$fax_too_long = "Numero di fax troppo lungo: " . $SESSION["fax_length"] . " caratteri max";
+$fax_too_short = "Numero di fax troppo corto: " . $SESSION["fax_length_min"] . " caratteri min";
 $not_valid_fax = "Numero di fax non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";
 
-$mobilephone_too_long = "Numero di cellulare troppo lungo: ".$SESSION["mobilephone_length"]." caratteri max";
-$mobilephone_too_short = "Numero di cellulare troppo corto: ".$SESSION["mobilephone_length_min"]." caratteri min";
+$mobilephone_too_long = "Numero di cellulare troppo lungo: " . $SESSION["mobilephone_length"] . " caratteri max";
+$mobilephone_too_short = "Numero di cellulare troppo corto: " . $SESSION["mobilephone_length_min"] . " caratteri min";
 $not_valid_mobilephone = "Numero di cellulare non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";
 
 $empty_email = "Non &egrave; stato specificato l'indirizzo e-mail";
-$email_too_long = "Indirizzo e-mail troppo lungo: ".$SESSION["email_length"]." caratteri max";
+$email_too_long = "Indirizzo e-mail troppo lungo: " . $SESSION["email_length"] . " caratteri max";
 $not_valid_email = "Indirizzo E-mail non valido";
 //$the_email_address = "L'indirizzo E-mail";
 //$email_not_on_file = "L'indirizzo E-mail specificato non ci risulta noto";
 
-$notes_too_long = "Annotazioni troppo lunghe: ".$SESSION["notes_length"]." caratteri max";
-$ournotes_too_long = "Annotazioni troppo lunghe nel campo \"" . $Our_Notes . "\": ".$SESSION["ournotes_length"]." caratteri max";
+$notes_too_long = "Annotazioni troppo lunghe: " . $SESSION["notes_length"] . " caratteri max";
+$ournotes_too_long = "Annotazioni troppo lunghe nel campo \"" . $Our_Notes . "\": " . $SESSION["ournotes_length"] . " caratteri max";
 $empty_message = "Non &egrave; stato scritto nessun Messaggio";
-$message_too_long = "Messaggio troppo lungo: ".$SESSION["message_length"]." caratteri max";
+$message_too_long = "Messaggio troppo lungo: " . $SESSION["message_length"] . " caratteri max";
 
 ////////////////////////////////////////////////////////////
 // purchase now
@@ -112,10 +114,10 @@ $empty_customer = "Non &egrave; stato specificato il Cliente";
 $appoggio = $SESSION["firstname_length"] + $SESSION["lastname_length"] + 1;
 $customer_too_long = "Campo Cliente troppo lungo: " . $appoggio . " caratteri max";
 $empty_contact = "Non &egrave; stato specificato un recapito telefonico";
-$contact_too_long = "Recapito telefonico troppo lungo: ".$SESSION["phone_length"]." caratteri max";
-$contact_too_short = "Recapito telefonico troppo corto: ".$SESSION["phone_length_min"]." caratteri min";
+$contact_too_long = "Recapito telefonico troppo lungo: " . $SESSION["phone_length"] . " caratteri max";
+$contact_too_short = "Recapito telefonico troppo corto: " . $SESSION["phone_length_min"] . " caratteri min";
 $not_valid_contact = "Recapito telefonico non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";
-$comments_too_long = "Commenti troppo lunghi: ".$SESSION["comments_length"]." caratteri max";
+$comments_too_long = "Commenti troppo lunghi: " . $SESSION["comments_length"] . " caratteri max";
 
 ////////////////////////////////////////////////////////////
 // change password
@@ -132,10 +134,10 @@ $new_passwords_dont_match = "Le nuove password non coincidono";
 ////////////////////////////////////////////////////////////
 
 $empty_category_name = "Il campo del nome &egrave; stato lasciato vuoto, si prega di riempirlo";
-$category_name_too_long = "Il nome della categoria &egrave; troppo lungo: ".$SESSION["category_name_length"]." caratteri max";
-$category_description_too_long = "La descrizione della categoria &egrave; troppo lunga: ".$SESSION["category_description_length"]." caratteri max";
+$category_name_too_long = "Il nome della categoria &egrave; troppo lungo: " . $SESSION["category_name_length"] . " caratteri max";
+$category_description_too_long = "La descrizione della categoria &egrave; troppo lunga: " . $SESSION["category_description_length"] . " caratteri max";
 
-$priv_too_long = "Privilegio troppo lungo: ".$SESSION["priv_length"]." caratteri max";
+$priv_too_long = "Privilegio troppo lungo: " . $SESSION["priv_length"] . " caratteri max";
 $not_valid_priv = "Privilegio non valido: usare solo caratteri alfanumerici";
 
 $Err_ImpCat = ": la Categoria Padre non esiste - '";
@@ -145,8 +147,8 @@ $Err_ImpCat = ": la Categoria Padre non esiste - '";
 ////////////////////////////////////////////////////////////
 
 $empty_brand_name = "Il campo del nome &egrave; stato lasciato vuoto, si prega di riempirlo";
-$brand_name_too_long = "Il nome della marca &egrave; troppo lungo: ".$SESSION["brand_name_length"]." caratteri max";
-$brand_description_too_long = "La descrizione della marca &egrave; troppo lunga: ".$SESSION["brand_description_length"]." caratteri max";
+$brand_name_too_long = "Il nome della marca &egrave; troppo lungo: " . $SESSION["brand_name_length"] . " caratteri max";
+$brand_description_too_long = "La descrizione della marca &egrave; troppo lunga: " . $SESSION["brand_description_length"] . " caratteri max";
 
 $Err_ImpBrand = ": La Marca non esiste - '";
 $Err_ImpIVA = ": La " . $IVA . " non esiste - '";
@@ -155,15 +157,15 @@ $Err_ImpIVA = ": La " . $IVA . " non esiste - '";
 // add and update product
 ////////////////////////////////////////////////////////////
 
-$product_id_is_empty = "Il campo ID &egrave; stato lasciato vuoto, si prega di riempirlo";
-$product_id_wspace = "L'ID <b>" . ov($HTTP_POST_VARS[product_id]) . "</b> contiene almeno uno spazio. Si prega di non usare spazi negli ID dei prodotti.";
-$product_id_wampersand = "L'ID <b>" . ov($HTTP_POST_VARS[product_id]) . "</b> contiene il carattere \"&amp;\". Si prega di non usarlo negli ID dei prodotti.";
-$product_id_wquestionm = "L'ID <b>" . ov($HTTP_POST_VARS[product_id]) . "</b> contiene il carattere \"?\". Si prega di non usarlo negli ID dei prodotti.";
-$product_id_too_long = "L'ID del prodotto &egrave; troppo lungo: ".$SESSION["product_id_length"]." caratteri max";
-$the_product_id = "L'ID ";
+$product_code_is_empty = "Riempire il campo del Codice del prodotto";
+$product_code_wspace = "Il Codice <b>" . ov($HTTP_POST_VARS["product_code"]) . "</b> contiene almeno uno spazio. Si prega di non usare spazi nei Codici dei prodotti.";
+$product_code_wampersand = "Il Codice <b>" . ov($HTTP_POST_VARS["product_code"]) . "</b> contiene il carattere \"&amp;\". Si prega di non usarlo nei Codici dei prodotti.";
+$product_code_wquestionm = "Il Codice <b>" . ov($HTTP_POST_VARS["product_code"]) . "</b> contiene il carattere \"?\". Si prega di non usarlo nei Codici dei prodotti.";
+$product_code_too_long = "Il Codice del prodotto &egrave; troppo lungo: " . $SESSION["product_code_length"] . " caratteri max";
+$the_product_code = "Il Codice ";
 
 $empty_product_name = "Riempire il campo del Nome del prodotto";
-$product_name_too_long = "Il nome del prodotto &egrave; troppo lungo: ".$SESSION["product_name_length"]." caratteri max";
+$product_name_too_long = "Il nome del prodotto &egrave; troppo lungo: " . $SESSION["product_name_length"] . " caratteri max";
 
 $empty_price = "Riempire il campo del prezzo";
 $price_is_zero = "Il Prezzo deve essere maggiore di zero";
@@ -188,20 +190,21 @@ $weight_over_max = "Peso eccessivo: " . $SESSION["weightmax"] . " " . $weightuni
 $special_level_empty = "Riempire il campo \"" . $Special_Level . "\"";
 $special_level_notint = "Il campo \"" . $Special_Level . "\" deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
 
-$product_description_too_long = "La descrizione del prodotto &egrave; troppo lunga: ".$SESSION["product_description_length"]." caratteri max";
-$product_extended_description_too_long = "La descrizione estesa del prodotto &egrave; troppo lunga: ".$SESSION["product_extended_description_length"]." caratteri max";
+$product_description_too_long = "La descrizione del prodotto &egrave; troppo lunga: " . $SESSION["product_description_length"] . " caratteri max";
+$product_extended_description_too_long = "La descrizione estesa del prodotto &egrave; troppo lunga: " . $SESSION["product_extended_description_length"] . " caratteri max";
 
 $appoggio = floor ($SESSION["max_file_size_images"] / 1024);
 $no_product_image_chosen = "Non &egrave; stata scelta una nuova immagine per rappresentare il prodotto, oppure l'immagine scelta &egrave; troppo grande: " . $appoggio . " bytes max";
 $image_upload_failed = "Upload dell'immagine fallito";
 $unsupported_image_type = "Tipo di immagine non supportato";
+$no_products_with_such_code = "nessun prodotto con tale codice";
 
 ////////////////////////////////////////////////////////////
 // add and update order state
 ////////////////////////////////////////////////////////////
 
 $empty_order_state_name = "Il campo del nome &egrave; stato lasciato vuoto, si prega di riempirlo";
-$order_state_name_too_long = "Il nome dello stato dell'ordine &egrave; troppo lungo: ".$SESSION["order_state_name_length"]." caratteri max";
-$order_state_description_too_long = "La descrizione dello stato dell'ordine &egrave; troppo lunga: ".$SESSION["order_state_description_length"]." caratteri max";
+$order_state_name_too_long = "Il nome dello stato dell'ordine &egrave; troppo lungo: " . $SESSION["order_state_name_length"] . " caratteri max";
+$order_state_description_too_long = "La descrizione dello stato dell'ordine &egrave; troppo lunga: " . $SESSION["order_state_description_length"] . " caratteri max";
 
 ?>
