@@ -1,4 +1,4 @@
-<?
+<?php
 
 /* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 /* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
@@ -8,7 +8,7 @@ $t->set_var(array(
 
 "Insufficient_Privileges" => "Insufficient Privileges",
 "Administration" => "Administration",
-"admin_footer_message" => $CFG->myname . " \"<i>Electronic Store - Commercio elettronico</i>\"",
+"admin_footer_message" => "$CFG->myname" . " \"<i>Electronic Store - Commercio elettronico</i>\"",
 "Save_Changes" => "Save Changes",
 "Import_Button_Label" => "Import",
 "Add_Subcategory" => "Add Subcategory",
@@ -22,7 +22,7 @@ $t->set_var(array(
 "Edit_this_product" => "Edit this product",
 "Special_Level" => "Special Level",
 "Special_Flag" => "Special Product",
-"Delete_Actual_Image" => "Delete Actual Image (leave the product without any image)",
+"Delete_Current_Image" => "Delete Current Image (leave the product without any image)",
 "Import_Images_Button_Label" => "Import Images",
 "Brands_Management" => "Brands Management",
 "B_Add_Brand" => "[+B] Add Brand",
@@ -56,9 +56,9 @@ $t->set_var(array(
 "The_order_state" => "The order state",
 "Order_State_reset_for_orders" => "The Order State has been reset for all orders in the named state",
 "Add_a_product_under" => "Add a product under",
-"actually_its_name_is_male_singular" => "actually its name is",
-"actually_its_name_is_female_singular" => "actually its name is",
-"actually_its_value_is_female_singular" => "actually its value is",
+"currently_its_name_is_male_singular" => "currently its name is",
+"currently_its_name_is_female_singular" => "currently its name is",
+"currently_its_value_is_female_singular" => "currently its value is",
 "Users_Management" => "Users Management",
 "Users" => "Users",
 "USERS" => "USERS",
