@@ -1,4 +1,4 @@
-<?
+<?php
 /* login.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -18,7 +18,7 @@
  * MAIN
  *****************************************************************************/
 
-include("application.inc.php");
+include ("application.inc.php");
 include ($CFG->globalerror);
 
 /* form has been submitted, check if it the user login information is correct */
@@ -37,8 +37,8 @@ if (match_referer() && isset($HTTP_POST_VARS)) {
 
 		/* if wantsurl is set, that means we came from a page that required
 		 * log in, so let's go back there.  otherwise go back to the main page */
-		$goto = empty($SESSION["wantsurl"]) ? $CFG->firstpage : $SESSION["wantsurl"];
-		header("Location: $goto" . "?" . SID);
+		$goto = empty($SESSION["wantsurl"]) ? "$CFG->firstpage" : $SESSION["wantsurl"];
+		header("Location: $goto");
 		die;
 
 	} else {
@@ -54,16 +54,15 @@ if (match_referer() && isset($HTTP_POST_VARS)) {
 } */
 
 $t = new Template();
-$t->set_file(array("page" => "$CFG->templatedir"."login_form.ihtml"));
-require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+$t->set_file(array("page" => "$CFG->templatedir" . "login_form.ihtml"));
+include ("$CFG->localelangdir" . "/global-common.inc.php");
 $t->set_var(array(
-		"wwwroot"	=> $CFG->wwwroot,
-		"libwww"	=> $CFG->libwww,
-		"errormsg"	=> ov($errormsg),
-		"frm_username"	=> ov($frm["username"])
+	"wwwroot"	=> $CFG->wwwroot,
+	"libwww"	=> $CFG->libwww,
+	"errormsg"	=> ov($errormsg),
+	"frm_username"	=> ov($frm["username"])
 ));
 $t->pparse("out", "page");
-//include("$CFG->templatedir"."login_form.ihtml");
 
 /******************************************************************************
  * FUNCTIONS
@@ -73,18 +72,14 @@ function verify_login($username, $password) {
 /* verify the username and password.  if it is a valid login, return an array
  * with the username, firstname, lastname, and email address of the user */
 
-	$qid = new DB_Sql;
-//	$qid = db_query("
+	$qid = new PGM_Sql;
 	$qid->Query("
 		SELECT username, usertype, firstname, lastname, fiscalcode, email, priv
 		FROM users
 		WHERE username = '$username' AND password = '$password'
 	");
 
-//	$numr = db_num_rows($qid);
-//	if ( $numr > 0 ) {
 	if ($qid->num_rows() > 0) {
-//		return db_fetch_array($qid, 0);
 		$qid->next_record();
 		$user["username"] = $qid->f("username");
 		$user["usertype"] = $qid->f("usertype");
