@@ -1,4 +1,4 @@
-<?
+<?php
 /* logout.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -18,11 +18,12 @@
  * MAIN
  *****************************************************************************/
 
-include("application.inc.php");
+include ("application.inc.php");
 
 /* unset the SESSION["user"] variable to log out the user */
 unset($SESSION["user"]);
 unset($SESSION["wantsurl"]);
+unset($SESSION["orderinfo"]);
 
 header("Location: $CFG->firstpage");
 ?>
