@@ -1,4 +1,4 @@
-<?
+<?php
 
 /*
  * (c) 2000 Fabio Molinari <fabio.m@mclink.it>
@@ -11,13 +11,13 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 global $CFG, $ME;
 global $SESSION;
 //include ($CFG->globalerror);
 
 $DOC_TITLE = "AdvancedSearch";
-include("$CFG->dirroot"."/header.php");
+include ("$CFG->dirroot" . "/header.php");
 
 /* Form has been submitted, let's go searching. */
 
@@ -63,15 +63,15 @@ if (match_referer() && !isset($from_menu)) {
 			$errormsg = validate_form($SESSION, $errors);
 		}
 		if (empty($errormsg)) {
-//			$qid_p = advanced_find_products(&$SESSION);
+			$qid_p = new PGM_Sql;
 			advanced_find_products(&$qid_p, &$SESSION);
-//			$SESSION["numr"] = db_num_rows($qid_p);
+			$qid_p->close();
 			$SESSION["numr"] = $qid_p->num_rows();
 			for ($i=0; $i<$SESSION["numr"]; $i++) {
-//				$SESSION["searchres"][$i] = db_fetch_array($qid_p, $i);
-				$qid_p->seek($i);
+//				$qid_p->seek($i);
 				$qid_p->next_record();
 				$SESSION["searchres"][$i]["id"] = $qid_p->f("id");
+				$SESSION["searchres"][$i]["code"] = $qid_p->f("code");
 				$SESSION["searchres"][$i]["name"] = $qid_p->f("name");
 				$SESSION["searchres"][$i]["price"] = $qid_p->f("price");
 				$SESSION["searchres"][$i]["description"] = $qid_p->f("description");
@@ -90,7 +90,7 @@ if (match_referer() && !isset($from_menu)) {
 		$SESSION["goback"]["request_uri"] = $REQUEST_URI;
 		$SESSION["goback"]["query_string"] = $QUERY_STRING;
 		if ($SESSION["numr"] > $SESSION["max_results"]) {
-			include("templates/".$SESSION["lang"]."/too_many_results.ihtml");
+			include ("templates/" . $SESSION["lang"] . "/too_many_results.ihtml");
 		} else if ($SESSION["numr"] > $SESSION["products_per_page"]) {
 			$first = ($page_number-1)*$SESSION["products_per_page"];
 			$last = $SESSION["numr"] < $page_number*$SESSION["products_per_page"] ? $SESSION["numr"]-1 : $page_number*$SESSION["products_per_page"]-1;
@@ -98,67 +98,61 @@ if (match_referer() && !isset($from_menu)) {
 			if (!($num_pages == (integer) $num_pages)) {
 				$num_pages = (integer) $num_pages + 1;
 			}
-//			include("templates/search_results.ihtml");
 		} else {
 			$first = 0;
 			$last = $SESSION["numr"] - 1;
-//			include("templates/search_results.ihtml");
 		}
-		require("search_results.php");
-		include("$CFG->dirroot"."/footer.php");
+		include ("search_results.php");
+		include ("$CFG->dirroot" . "/footer.php");
 		die;
 	}
 }
 
 $t = new Template();
 $t->set_file(array("page" => "templates/advanced_search_form.ihtml"));
-require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-require($CFG->localedir . $SESSION["lang"] . "/global-shopping.inc.php");
-$t->set_var("wwwroot", $CFG->wwwroot);
-$t->set_var("productswww", $CFG->productswww);
+include ("$CFG->localelangdir" . "/global-common.inc.php");
+include ("$CFG->localelangdir" . "/global-shopping.inc.php");
+$t->set_var("wwwroot", "$CFG->wwwroot");
+$t->set_var("productswww", "$CFG->productswww");
 $t->set_var("ME", $ME);
 $t->set_var("id", $id);
 if (empty($errors))
 	$t->set_var("there_are_errors", "");
 $t->set_var(array(
-		"session_product_name_in"	=> ov($SESSION["product_name_in"]),
-		"session_prod_concatenation_or"	=> $SESSION["prod_concatenation"] == "AND" ? "" : "checked",
-		"session_prod_concatenation_and"=> $SESSION["prod_concatenation"] == "AND" ? "checked" : "",
-		"session_prod_case_sensitive"	=> $SESSION["prod_case_sensitive"] ? "checked" : "",
-		"session_name_in"		=> ov($SESSION["name_in"]),
-		"session_desc_concatenation_or"	=> $SESSION["desc_concatenation"] == "AND" ? "" : "checked",
-		"session_desc_concatenation_and"=> $SESSION["desc_concatenation"] == "AND" ? "checked" : "",
-		"session_desc_case_sensitive"	=> $SESSION["desc_case_sensitive"] ? "checked" : "",
-		"session_price_min"		=> ov($SESSION["price_min"]),
-		"errors_price_min"		=> errmsg($errors->price_min),
-		"session_price_max"		=> ov($SESSION["price_max"]),
-		"errors_price_max"		=> errmsg($errors->price_max),
-		"session_discount_min"		=> ov($SESSION["discount_min"]),
-		"errors_discount_min"		=> errmsg($errors->discount_min),
-		"session_discount_max"		=> ov($SESSION["discount_max"]),
-		"errors_discount_max"		=> errmsg($errors->discount_max),
-		"session_discqty_min"		=> ov($SESSION["discqty_min"]),
-		"errors_discqty_min"		=> errmsg($errors->discqty_min),
-		"session_discqty_max"		=> ov($SESSION["discqty_max"]),
-		"errors_discqty_max"		=> errmsg($errors->discqty_max)
+	"session_product_name_in"	=> ov($SESSION["product_name_in"]),
+	"session_prod_concatenation_or"	=> $SESSION["prod_concatenation"] == "AND" ? "" : "checked",
+	"session_prod_concatenation_and"=> $SESSION["prod_concatenation"] == "AND" ? "checked" : "",
+	"session_prod_case_sensitive"	=> $SESSION["prod_case_sensitive"] ? "checked" : "",
+	"session_name_in"		=> ov($SESSION["name_in"]),
+	"session_desc_concatenation_or"	=> $SESSION["desc_concatenation"] == "AND" ? "" : "checked",
+	"session_desc_concatenation_and"=> $SESSION["desc_concatenation"] == "AND" ? "checked" : "",
+	"session_desc_case_sensitive"	=> $SESSION["desc_case_sensitive"] ? "checked" : "",
+	"session_price_min"		=> ov($SESSION["price_min"]),
+	"errors_price_min"		=> errmsg($errors->price_min),
+	"session_price_max"		=> ov($SESSION["price_max"]),
+	"errors_price_max"		=> errmsg($errors->price_max),
+	"session_discount_min"		=> ov($SESSION["discount_min"]),
+	"errors_discount_min"		=> errmsg($errors->discount_min),
+	"session_discount_max"		=> ov($SESSION["discount_max"]),
+	"errors_discount_max"		=> errmsg($errors->discount_max),
+	"session_discqty_min"		=> ov($SESSION["discqty_min"]),
+	"errors_discqty_min"		=> errmsg($errors->discqty_min),
+	"session_discqty_max"		=> ov($SESSION["discqty_max"]),
+	"errors_discqty_max"		=> errmsg($errors->discqty_max)
 ));
 $t->set_block("page", "brand_used", "brand_used_blck");
 $t->set_var("brand_used_blck", "");
 if ($SESSION["brand_used"]) {
 	$t->set_block("brand_used", "brand_row", "brand_rows");
 	$t->set_var("brand_rows", "");
-	$qid = new DB_Sql;
-//	$qid = db_query("SELECT id, name FROM brands");
+	$qid = new PGM_Sql;
 	$qid->Query("SELECT id, name FROM brands");
 	$SESSION["brands"] = array();
-//	$numr = db_num_rows($qid);
-//	for ($i=0; $i<$numr; $i++) {
 	while ($qid->next_record()) {
-//		$brand = db_fetch_object($qid, $i);
 		$t->set_var(array(
-				"session_brand_id"	=> $qid->f("id"),
-				"session_brand_selected"=> ($SESSION["brand_id"] == $qid->f("id")) ? "selected" : "",
-				"session_brand_name"	=> $qid->f("name")
+			"session_brand_id"	=> $qid->f("id"),
+			"session_brand_selected"=> ($SESSION["brand_id"] == $qid->f("id")) ? "selected" : "",
+			"session_brand_name"	=> $qid->f("name")
 		));
 		$t->parse("brand_rows", "brand_row", true);
 	}
@@ -168,17 +162,16 @@ $t->set_block("page", "weight_used", "weight_used_blck");
 $t->set_var("weight_used_blck", "");
 if($SESSION["weight_used"]) {
 	$t->set_var(array(
-			"session_weight_min"	=> ov($SESSION["weight_min"]),
-			"errors_weight_min"	=> errmsg($errors->weight_min),
-			"session_weight_max"	=> ov($SESSION["weight_max"]),
-			"errors_weight_max"	=> errmsg($errors->weight_max)
+		"session_weight_min"	=> ov($SESSION["weight_min"]),
+		"errors_weight_min"	=> errmsg($errors->weight_min),
+		"session_weight_max"	=> ov($SESSION["weight_max"]),
+		"errors_weight_max"	=> errmsg($errors->weight_max)
 	));
 	$t->parse("weight_used_blck", "weight_used", true);
 }
 $t->pparse("out", "page");
-//include("templates/advanced_search_form.ihtml");
 
-include("$CFG->dirroot"."/footer.php");
+include ("$CFG->dirroot" . "/footer.php");
 
 
 /******************************************************************************
