@@ -1,4 +1,4 @@
-<?
+<?php
 /* index.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -18,20 +18,20 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 
 $DOC_TITLE = "Shopping_Catalog";
 $SESSION["goback"]["request_uri"] = $REQUEST_URI;
 $SESSION["goback"]["query_string"] = $QUERY_STRING;
-include("$CFG->dirroot"."/header.php");
+include ("$CFG->dirroot" . "/header.php");
 
-setdefault($id, 1);
-$qid_bcp = new DB_Sql;
+setdefault(&$id, 1);
+$qid_bcp = new PGM_Sql;
 build_category_path(&$qid_bcp, $id, $category_path);
 $qid_bcp->close();
 
 /* get the name and description of all the sub-categories under this one */
-$qid_c = new DB_Sql;
+$qid_c = new PGM_Sql;
 $qid_c->Query("
 	SELECT id, name, special_level, description
 	FROM categories
@@ -39,10 +39,11 @@ $qid_c->Query("
 	ORDER BY special_level, name
 ");
 /* get all the products under this category */
-$qid_p = new DB_Sql;
+$qid_p = new PGM_Sql;
 $qid_p->Query("
 	SELECT
 		 p.id
+		,p.code
 		,p.name AS name
 		,p.price
 		,p.discount
@@ -63,9 +64,9 @@ $qid_p->Query("
 
 $t = new Template();
 $t->set_file(array("page" => "templates/index.ihtml"));
-require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-require($CFG->localedir . $SESSION["lang"] . "/global-shopping.inc.php");
-require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+include ("$CFG->localelangdir" . "/global-common.inc.php");
+include ("$CFG->localelangdir" . "/global-shopping.inc.php");
+include ("$CFG->localelangdir" . "/global-admin.inc.php");
 $t->set_var("wwwroot", $CFG->wwwroot);
 $t->set_var("productswww", $CFG->productswww);
 $t->set_var("ME", $ME);
@@ -84,13 +85,10 @@ if (!$SESSION["frames_used"] || has_priv("admin")){
 	$t->set_block("noframes2", "adminnoframes2", "adminnoframes2_blck");
 	$t->set_var("no_sub_categories_blck", "");
 	$t->set_var("category_rows", "");
-//	if (($numr = db_num_rows($qid_c)) == 0)
 	if ($qid_c->num_rows() == 0)
 		$t->parse("no_sub_categories_blck", "no_sub_categories", true);
 	else {
-//		for ($i=0; $i<$numr; $i++) {
 		while ($qid_c->next_record()) {
-//			$cat = db_fetch_object($qid_c, $i);
 			if (has_priv("admin")) {
 				$t->set_var(array(
 					"c_special_level"	=> $qid_c->f("special_level") . " - ",
@@ -117,7 +115,6 @@ $t->set_block("page", "products", "products_blck");
 $t->set_var("products_blck", "");
 $t->set_block("page", "no_products", "no_products_blck");
 $t->set_var("no_products_blck", "");
-//if (($numr = db_num_rows($qid_p)) == 0)
 if ($qid_p->num_rows() == 0)
 	$t->parse("no_products_blck", "no_products", true);
 else {
@@ -151,19 +148,21 @@ else {
 			$t->set_var("discqty_block_blck", "");
 		$t->set_var("weight_used_blck", "");
 // ... now we have reset all nested blocks :)
-//		$prod = db_fetch_object($qid_p, $i);
+		$appoggio = $CART->productitemcount($qid_p->f("id"));
 		$t->set_var(array(
 			"id"		=> $id,
 			"product_id"	=> $qid_p->f("id"),
+			"product_code"	=> $qid_p->f("code"),
 			"pname"		=> ov($qid_p->f("name")),
 			"price"		=> price,
 			"fprice"	=> formatted_price($qid_p->f("price")),
-			"description"	=> ovwbr($qid_p->f("description"))
+			"description"	=> ovwbr($qid_p->f("description")),
+			"productitemcount"	=> $appoggio
 		));
 		if (has_priv("admin")) {
-			if (file_exists($CFG->productsdir.string_cleanup($qid_p->f("id")).".thumb.jpg")) {
+			if (file_exists("$CFG->productsdir" . $qid_p->f("id") . ".thumb.jpg")) {
 				$t->set_var(array(
-					"imagefilename"	=> string_cleanup($qid_p->f("id")),
+					"imagefilename"	=> $qid_p->f("id"),
 					"thumbwidth"	=> $qid_p->f("thumbwidth"),
 					"thumbheight"	=> $qid_p->f("thumbheight")
 				));
@@ -174,9 +173,9 @@ else {
 				$t->parse("special_flag_blck", "special_flag", true);
 			$t->parse("adminprod_blck", "adminprod", true);
 		} else {
-			if (file_exists($CFG->productsdir.string_cleanup($qid_p->f("id")).".thumb.jpg")) {
+			if (file_exists("$CFG->productsdir" . $qid_p->f("id") . ".thumb.jpg")) {
 				$t->set_var(array(
-					"imagefilename"	=> string_cleanup($qid_p->f("id")),
+					"imagefilename"	=> $qid_p->f("id"),
 					"thumbwidth"	=> $qid_p->f("thumbwidth"),
 					"thumbheight"	=> $qid_p->f("thumbheight")
 				));
@@ -213,8 +212,7 @@ else {
 }
 
 $t->pparse("out", "page");
-//include("templates/index.ihtml");
 
-include("$CFG->dirroot"."/footer.php");
+include ("$CFG->dirroot" . "/footer.php");
 
 ?>
