@@ -1,4 +1,4 @@
-<?
+<?php
 /* product_details.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -18,17 +18,14 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 
-$qid = new DB_Sql;
+$qid = new PGM_Sql;
 
 if (!empty($product_id)) {
 	if (empty($id)) {	// category not specified
-//		$qid = db_query("SELECT category_id FROM products_categories WHERE product_id = '$product_id'");
 		$qid->Query("SELECT category_id FROM products_categories WHERE product_id = '$product_id'");
-//		if (db_num_rows($qid)) {
 		if ($qid->num_rows()) {
-//			list($id) = db_fetch_row($qid, 0);
 			$qid->next_record();
 			$id = $qid->f("category_id");
 		} else {
@@ -36,9 +33,7 @@ if (!empty($product_id)) {
 			die;
 		}
 	} else {
-//		$qid = db_query("SELECT category_id FROM products_categories WHERE product_id = '$product_id' AND category_id = '$id'");
 		$qid->Query("SELECT category_id FROM products_categories WHERE product_id = '$product_id' AND category_id = '$id'");
-//		if (!db_num_rows($qid)) {
 		if (!($qid->num_rows())) {
 			header("Location: $CFG->firstpage");
 			die;
@@ -49,10 +44,10 @@ if (!empty($product_id)) {
 	die;
 }
 
-//$qid = db_query("
 $qid->Query("
 	SELECT
 		 p.id AS product_id
+		,p.code
 		,p.name AS name
 		,p.price
 		,p.discount
@@ -68,9 +63,7 @@ $qid->Query("
 	WHERE p.brand_id = b.id AND p.iva_id = i.id AND p.id = '$product_id'
 ");
 
-//if (db_num_rows($qid) > 0) {
 if ($qid->num_rows() > 0) {
-//	$prod = db_fetch_object($qid, 0);
 	$qid->next_record();
 	$prod = true;
 } else {
@@ -79,18 +72,18 @@ if ($qid->num_rows() > 0) {
 
 $DOC_TITLE = $prod ? "Product_Details" : "Product_Not_Found";
 
-include("$CFG->dirroot"."/header.php");
+include ("$CFG->dirroot" . "/header.php");
 
 $t = new Template();
 $t->set_file(array("page" => "templates/product_details.ihtml"));
-require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-require($CFG->localedir . $SESSION["lang"] . "/global-shopping.inc.php");
+include ("$CFG->localelangdir" . "/global-common.inc.php");
+include ("$CFG->localelangdir" . "/global-shopping.inc.php");
 $t->set_block("page", "product", "product_blck");
 $t->set_var(array("product_blck" => ""));
 $t->set_block("page", "noproduct", "noproduct_blck");
 $t->set_var(array("noproduct_blck" => ""));
 if ($prod) {
-	$qid_bcp = new DB_Sql;
+	$qid_bcp = new PGM_Sql;
 	build_category_path(&$qid_bcp, $id, $category_path);
 	$qid_bcp->close();
 	$t->set_var("category_path", $category_path);
@@ -109,14 +102,17 @@ if ($prod) {
 	$t->set_var("adminprodimage_blck", "");
 	$t->set_block("product", "notadminprodimage", "notadminprodimage_blck");
 	$t->set_var("notadminprodimage_blck", "");
+	$appoggio = $CART->productitemcount($qid->f("product_id"));
 	$t->set_var(array(
 		"category_id"		=> $id,
 		"product_id"		=> $qid->f("product_id"),
+		"product_code"		=> $qid->f("code"),
 		"name"			=> ov($qid->f("name")),
 		"price"			=> $qid->f("price"),
 		"fprice"		=> formatted_price($qid->f("price")),
 		"extended_description"	=> ovwbr($qid->f("extended_description")),
 		"imagetype"		=> $qid->f("imagetype"),
+		"productitemcount"	=> $appoggio
 	));
 	if ($SESSION["brand_used"] && $qid->f("bname") != "") {
 		$t->set_var("bname", ov($qid->f("bname")));
@@ -141,9 +137,9 @@ if ($prod) {
 		));
 		$t->parse("weight_used_blck", "weight_used", true);
 	}
-	if (file_exists($CFG->productsdir.string_cleanup($qid->f("product_id")).".".$qid->f("imagetype"))) {
+	if (file_exists("$CFG->productsdir" . $qid->f("product_id") . "." . $qid->f("imagetype"))) {
 		$t->set_var(array(
-			"imagefilename" => string_cleanup($qid->f("product_id")),
+			"imagefilename" => $qid->f("product_id"),
 			"imagewidth"    => $qid->f("imagewidth"),
 			"imageheight"   => $qid->f("imageheight")
 		));
@@ -151,7 +147,7 @@ if ($prod) {
 			$t->set_var("wwwroot", $CFG->wwwroot);
 			$t->parse("adminprodimage_blck", "adminprodimage", true);
 		} else {
-			$t->set_var("productswww", $CFG->productswww);
+			$t->set_var("productswww", "$CFG->productswww");
 			$t->parse("notadminprodimage_blck", "notadminprodimage", true);
 		}
 	}
@@ -160,8 +156,7 @@ if ($prod) {
 	$t->parse("noproduct_blck", "noproduct", true);
 
 $t->pparse("out", "page");
-//include("templates/product_details.ihtml");
 
-include("$CFG->dirroot"."/footer.php");
+include ("$CFG->dirroot" . "/footer.php");
 
 ?>
