@@ -1,9 +1,9 @@
-<?
+<?php
 
 /* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 /* (c) 2000 Oleg V. Kalashnikov <oleg@ok.gnu.zp.ua> */
 
-include("../application.inc.php");
+include ("../application.inc.php");
 
 $stringtsf_stripped = ereg_replace ("\+", "", $stringtsf);
 
@@ -12,15 +12,15 @@ if (empty($stringtsf_stripped)) {
 }
 
 if (!isset($page_number) || $dbchanged) {
-//	$qid_p = find_products(&$stringtsf_stripped, $case_sensitive, $concatenation);
+	$qid_p = new PGM_Sql;
 	find_products(&$qid_p, &$stringtsf_stripped, $case_sensitive, $concatenation);
-//	$SESSION["numr"] = db_num_rows($qid_p);
+	$qid_p->close();
 	$SESSION["numr"] = $qid_p->num_rows();
 	for ($i=0; $i<$SESSION["numr"]; $i++) {
-//		$SESSION["searchres"][$i] = db_fetch_array($qid_p, $i);
-		$qid_p->seek($i);
+//		$qid_p->seek($i);
 		$qid_p->next_record();
 		$SESSION["searchres"][$i]["id"] = $qid_p->f("id");
+		$SESSION["searchres"][$i]["code"] = $qid_p->f("code");
 		$SESSION["searchres"][$i]["name"] = $qid_p->f("name");
 		$SESSION["searchres"][$i]["price"] = $qid_p->f("price");
 		$SESSION["searchres"][$i]["description"] = $qid_p->f("description");
@@ -41,12 +41,11 @@ if (!isset($page_number) || $dbchanged) {
 $DOC_TITLE = "Search_Results";
 $SESSION["goback"]["request_uri"] = $REQUEST_URI;
 $SESSION["goback"]["query_string"] = $QUERY_STRING;
-include("$CFG->dirroot"."/header.php");
+include ("$CFG->dirroot" . "/header.php");
 if ($SESSION["numr"] > $SESSION["max_results"]) {
 	$t->set_file(array("page" => "templates/".$SESSION["lang"]."/too_many_results.ihtml"));
 	$t->set_var("numresults", $SESSION["numr"]);
 	$t->pparse("out", "page");
-//	include("templates/".$SESSION["lang"]."/too_many_results.ihtml");
 } else {
 	if ($SESSION["numr"] > $SESSION["products_per_page"]) {
 		$first = ($page_number-1)*$SESSION["products_per_page"];
@@ -61,8 +60,8 @@ if ($SESSION["numr"] > $SESSION["max_results"]) {
 	}
 }
 
-include("search_results.php");
+include ("search_results.php");
 
-include("$CFG->dirroot"."/footer.php");
+include ("$CFG->dirroot" . "/footer.php");
 
 ?>
