@@ -1,4 +1,4 @@
-<?
+<?php
 /* cart_view.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -18,14 +18,14 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 
 if (isset($func)) {
 	switch ($func) {
 		case "remove" :
 			$CART->remove($product_id);
 			$CART->cleanup();
-			$qid_crt = new DB_Sql;
+			$qid_crt = new PGM_Sql;
 			$CART->recalc_total(&$qid_crt);
 			$qid_crt->close();
 			break;
@@ -37,7 +37,7 @@ if (isset($func)) {
 		case "recalc" :
 			update_qty($HTTP_POST_VARS);
 			$CART->cleanup();
-			$qid_crt = new DB_Sql;
+			$qid_crt = new PGM_Sql;
 			$CART->recalc_total(&$qid_crt);
 			$qid_crt->close();
 			break;
@@ -45,17 +45,16 @@ if (isset($func)) {
 }
 
 $DOC_TITLE = "Shopping_Cart";
-include("$CFG->dirroot"."/header.php");
+include ("$CFG->dirroot" . "/header.php");
 
-//$qid = get_cart_items();
-$qid = new DB_Sql;
+$qid = new PGM_Sql;
 get_cart_items(&$qid);
 
 $t = new Template();
 $t->set_file(array("page" => "templates/shopping_cart.ihtml"));
-require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-require($CFG->localedir . $SESSION["lang"] . "/global-shopping.inc.php");
-require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+include ("$CFG->localelangdir" . "/global-common.inc.php");
+include ("$CFG->localelangdir" . "/global-shopping.inc.php");
+include ("$CFG->localelangdir" . "/global-admin.inc.php");
 $t->set_var("wwwroot", $CFG->wwwroot);
 $t->set_var("ME", $ME);
 
@@ -75,31 +74,29 @@ else {
 		$t->set_block("cart_row", "image_exists", "image_exists_blck");
 		$t->set_block("cart_row", "iva_used", "iva_used_blck");
 		$t->set_block("cart_row", "weight_used", "weight_used_blck");
-//	$numr = db_num_rows($qid);
 	$t->set_var("cart_rows", "");
-//	for ($i=0; $i<$numr; $i++) {
 	while ($qid->next_record()) {
 		$t->set_var("image_exists_blck", "");
 		$t->set_var("iva_used_blck", "");
 		$t->set_var("weight_used_blck", "");
-//		$prod = db_fetch_object($qid, $i);
 		$qty = $CART->items[$qid->f("id")];
 		$t->set_var(array(
-				"product_id"	=> $qid->f("id"),
-				"pname"		=> ov($qid->f("name")),
-				"price"		=> $qid->f("price"),
-				"fprice"	=> formatted_price($qid->f("price")),
-				"qty"		=> $qty,
-				"subtotal"	=> $CART->subtotals[$qid->f("id")],
-				"fsubtotal"	=> formatted_price($CART->subtotals[$qid->f("id")]),
-				"colspan5"	=> 5,
-				"colspan7"	=> 7
-			));
-		if (file_exists($CFG->productsdir.string_cleanup($qid->f("id")).".thumb.jpg")) {
+			"product_id"	=> $qid->f("id"),
+			"pname"		=> ov($qid->f("name")),
+			"price"		=> $qid->f("price"),
+			"fprice"	=> formatted_price($qid->f("price")),
+			"qty"		=> $qty,
+			"subtotal"	=> $CART->subtotals[$qid->f("id")],
+			"fsubtotal"	=> formatted_price($CART->subtotals[$qid->f("id")]),
+			"colspan5"	=> 5,
+			"colspan7"	=> 7
+		));
+		if (file_exists("$CFG->productsdir" . $qid->f("id") . ".thumb.jpg")) {
 			$t->set_var(array(
-					"imagefilename"	=> string_cleanup($qid->f("id")),
-					"thumbwidth"	=> $qid->f("thumbwidth"),
-					"thumbheight"	=> $qid->f("thumbheight")
+				"productswww"	=> $CFG->productswww,
+				"imagefilename"	=> $qid->f("id"),
+				"thumbwidth"	=> $qid->f("thumbwidth"),
+				"thumbheight"	=> $qid->f("thumbheight")
 			));
 			$t->parse("image_exists_blck", "image_exists", true);
 		}
@@ -122,23 +119,22 @@ else {
 	$t->set_var("delivery_used_blck", "");
 	if ($SESSION["delivery_used"]) {
 		$t->set_var(array(
-				"total"		=> $CART->total,
-				"ftotal"	=> formatted_price($CART->total),
-				"delivery"	=> $CART->delivery,
-				"fdelivery"	=> formatted_price($CART->delivery)
+			"total"		=> $CART->total,
+			"ftotal"	=> formatted_price($CART->total),
+			"delivery"	=> $CART->delivery,
+			"fdelivery"	=> formatted_price($CART->delivery)
 		));
 		$t->parse("delivery_used_blck", "delivery_used", true);
 	}
 	$t->set_var(array(
-			"grandtotal"	=> $CART->grandtotal,
-			"fgrandtotal"	=> formatted_price($CART->grandtotal)
+		"grandtotal"	=> $CART->grandtotal,
+		"fgrandtotal"	=> formatted_price($CART->grandtotal)
 	));
 	$t->parse("shopping_cart_notempty_blck", "shopping_cart_notempty", true);
 }
 $t->pparse("out", "page");
-//include("templates/shopping_cart.ihtml");
 
-include("$CFG->dirroot"."/footer.php");
+include ("$CFG->dirroot" . "/footer.php");
 
 /******************************************************************************
  * FUNCTIONS
