@@ -1,4 +1,4 @@
-<?
+<?php
 /* cart_add.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -18,17 +18,17 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 
 $CART->add($product_id, 1);
 $CART->cleanup();
-$qid_crt = new DB_Sql;
+$qid_crt = new PGM_Sql;
 $CART->recalc_total(&$qid_crt);
 $qid_crt->close();
 
-if (! empty($HTTP_REFERER)) {
+if (! empty($HTTP_REFERER))
 	header("Location: $HTTP_REFERER");
-} else {
+else
 	header("Location: $CFG->firstpage");
-}
+
 ?>
