@@ -1,4 +1,4 @@
-<?
+<?php
 /* change_settings.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -18,7 +18,7 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 require_login();
 
 /* form has been submitted, check if it the user login information is correct */
@@ -31,45 +31,47 @@ if (match_referer() && isset($HTTP_POST_VARS) && !isset($from_menu)) {
 		$noticemsg = "Settings_Change_Successful";
 	}
 } else {
-	$frm = load_user_profile();
+	$qid = new PGM_Sql;
+	$frm = load_user_profile(&$qid);
+	$qid->close();
 }
 
 $DOC_TITLE = "Change_Settings";
 
-include("$CFG->dirroot"."/header.php");
+include ("$CFG->dirroot" . "/header.php");
 
-include("$CFG->dirroot"."/form_header.php");
+include ("$CFG->dirroot" . "/form_header.php");
 
 $t = new Template();
-$t->set_file(array("page" => "templates/change_settings_form-".$SESSION["user"]["usertype"].".ihtml"));
-require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+$t->set_file(array("page" => "templates/change_settings_form-" . $SESSION["user"]["usertype"] . ".ihtml"));
+include ("$CFG->localelangdir" . "/global-common.inc.php");
 $t->set_var("ME", $ME);
 $t->set_var(array(
-		"session_user_username"		=> ov($SESSION["user"]["username"]),
-		"session_user_firstname"	=> ov($SESSION["user"]["firstname"]),
-		"frm_fiscalcode"		=> ov($frm["fiscalcode"]),
-		"errors_fiscalcode"		=> errmsg($errors->fiscalcode),
-		"frm_address"			=> ov($frm["address"]),
-		"errors_address"		=> errmsg($errors->address),
-		"frm_number"			=> ov($frm["number"]),
-		"errors_number"			=> errmsg($errors->number),
-		"frm_city"			=> ov($frm["city"]),
-		"errors_city"			=> errmsg($errors->city),
-		"frm_country"			=> ov($frm["country"]),
-		"errors_country"		=> errmsg($errors->country),
-		"frm_zip_code"			=> ov($frm["zip_code"]),
-		"errors_zip_code"		=> errmsg($errors->zip_code),
-		"frm_phone"			=> ov($frm["phone"]),
-		"errors_phone"			=> errmsg($errors->phone),
-		"frm_fax"			=> ov($frm["fax"]),
-		"errors_fax"			=> errmsg($errors->fax),
-		"frm_mobilephone"		=> ov($frm["mobilephone"]),
-		"errors_mobilephone"		=> errmsg($errors->mobilephone),
-		"frm_email"			=> ov($frm["email"]),
-		"errors_email"			=> errmsg($errors->email),
-		"frm_authdata"			=> $frm["authdata"] ? "checked" : "",
-		"frm_acceptadvert"		=> $frm["acceptadvert"] ? "checked" : "",
-		"frm_notes"			=> ov($frm["notes"]),
+	"session_user_username"		=> ov($SESSION["user"]["username"]),
+	"session_user_firstname"	=> ov($SESSION["user"]["firstname"]),
+	"frm_fiscalcode"		=> ov($frm["fiscalcode"]),
+	"errors_fiscalcode"		=> errmsg($errors->fiscalcode),
+	"frm_address"			=> ov($frm["address"]),
+	"errors_address"		=> errmsg($errors->address),
+	"frm_number"			=> ov($frm["number"]),
+	"errors_number"			=> errmsg($errors->number),
+	"frm_city"			=> ov($frm["city"]),
+	"errors_city"			=> errmsg($errors->city),
+	"frm_country"			=> ov($frm["country"]),
+	"errors_country"		=> errmsg($errors->country),
+	"frm_zip_code"			=> ov($frm["zip_code"]),
+	"errors_zip_code"		=> errmsg($errors->zip_code),
+	"frm_phone"			=> ov($frm["phone"]),
+	"errors_phone"			=> errmsg($errors->phone),
+	"frm_fax"			=> ov($frm["fax"]),
+	"errors_fax"			=> errmsg($errors->fax),
+	"frm_mobilephone"		=> ov($frm["mobilephone"]),
+	"errors_mobilephone"		=> errmsg($errors->mobilephone),
+	"frm_email"			=> ov($frm["email"]),
+	"errors_email"			=> errmsg($errors->email),
+	"frm_authdata"			=> $frm["authdata"] ? "checked" : "",
+	"frm_acceptadvert"		=> $frm["acceptadvert"] ? "checked" : "",
+	"frm_notes"			=> ov($frm["notes"]),
 ));
 if ($SESSION["user"]["usertype"] == "pf") {
 	$t->set_var("session_user_lastname", ov($SESSION["user"]["lastname"]));
@@ -80,9 +82,8 @@ if ($SESSION["user"]["usertype"] == "pf") {
 	}
 }
 $t->pparse("out", "page");
-//include("templates/change_settings_form-".$SESSION["user"]["usertype"].".ihtml");
 
-include("$CFG->dirroot"."/footer.php");
+include ("$CFG->dirroot" . "/footer.php");
 
 /******************************************************************************
  * FUNCTIONS
@@ -128,8 +129,7 @@ function update_settings(&$frm) {
 	
 	$username = $SESSION["user"]["username"];
 
-	$qid = new DB_Sql;
-//	$qid = db_query("
+	$qid = new PGM_Sql;
 	$qid->Query("
 		UPDATE users SET
 			 fiscalcode = '$frm[fiscalcode]'
