@@ -1,4 +1,4 @@
-<?
+<?php
 
 /* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
@@ -6,7 +6,7 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 
 /* form has been submitted, try to send the message */
 if (match_referer() && isset($HTTP_POST_VARS) && !isset($from_menu)) {
@@ -17,63 +17,63 @@ if (match_referer() && isset($HTTP_POST_VARS) && !isset($from_menu)) {
 		send_form($frm);
 
 		$DOC_TITLE = "Contact_Successful";
-		include("$CFG->dirroot"."/header.php");
+		include ("$CFG->dirroot" . "/header.php");
 		$t = new Template();
-		$t->set_file(array("page" => "templates/".$SESSION["lang"]."/contact_success.ihtml"));
-		$t->set_var("firstpage", $CFG->firstpage);
+		$t->set_file(array("page" => "templates/" . $SESSION["lang"] . "/contact_success.ihtml"));
+		$t->set_var("firstpage", "$CFG->firstpage");
 		$t->pparse("out", "page");
-//		include("templates/".$SESSION["lang"]."/contact_success.ihtml");
-		include("$CFG->dirroot"."/footer.php");
+		include ("$CFG->dirroot" . "/footer.php");
 		die;
 	}
 } else if (is_logged_in()) {
-	$frm = load_user_profile();
+	$qid = new PGM_Sql;
+	$frm = load_user_profile(&$qid);
+	$qid->close();
 	$frm["name"] = $frm["firstname"] . " " . $frm["lastname"];
 }
 
 $DOC_TITLE = "Contact_Us";
-include("$CFG->dirroot"."/header.php");
-include("$CFG->dirroot"."/form_header.php");
+include ("$CFG->dirroot" . "/header.php");
+include ("$CFG->dirroot" . "/form_header.php");
 if (empty($errormsg)) {	// we are loading the form for the first time
 	$frm["acceptadvert"] = 1;
 }
 
 $t = new Template();
 $t->set_file(array("page" => "templates/contact_form.ihtml"));
-require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-require($CFG->localedir . $SESSION["lang"] . "/global-users.inc.php");
+include ("$CFG->localelangdir" . "/global-common.inc.php");
+include ("$CFG->localelangdir" . "/global-users.inc.php");
 $t->set_var("ME", $ME);
 $t->set_var("star", return_star());
 $t->set_var(array(
-		"frm_name"		=> ov($frm["name"]),
-		"errors_name"		=> errmsg($errors->name),
-		"frm_address"		=> ov($frm["address"]),
-		"errors_address"	=> errmsg($errors->address),
-		"frm_number"		=> ov($frm["number"]),
-		"errors_number"		=> errmsg($errors->number),
-		"frm_city"		=> ov($frm["city"]),
-		"errors_city"		=> errmsg($errors->city),
-		"frm_country"		=> ov($frm["country"]),
-		"errors_country"	=> errmsg($errors->country),
-		"frm_zip_code"		=> ov($frm["zip_code"]),
-		"errors_zip_code"	=> errmsg($errors->zip_code),
-		"frm_phone"		=> ov($frm["phone"]),
-		"errors_phone"		=> errmsg($errors->phone),
-		"frm_fax"		=> ov($frm["fax"]),
-		"errors_fax"		=> errmsg($errors->fax),
-		"frm_mobilephone"	=> ov($frm["mobilephone"]),
-		"errors_mobilephone"	=> errmsg($errors->mobilephone),
-		"frm_email"		=> ov($frm["email"]),
-		"errors_email"		=> errmsg($errors->email),
-		"frm_authdata"		=> $frm["authdata"] ? "checked" : "",
-		"frm_acceptadvert"	=> $frm["acceptadvert"] ? "checked" : "",
-		"frm_message"		=> ov($frm["message"]),
-		"errors_message"	=> errmsg($errors->message),
+	"frm_name"		=> ov($frm["name"]),
+	"errors_name"		=> errmsg($errors->name),
+	"frm_address"		=> ov($frm["address"]),
+	"errors_address"	=> errmsg($errors->address),
+	"frm_number"		=> ov($frm["number"]),
+	"errors_number"		=> errmsg($errors->number),
+	"frm_city"		=> ov($frm["city"]),
+	"errors_city"		=> errmsg($errors->city),
+	"frm_country"		=> ov($frm["country"]),
+	"errors_country"	=> errmsg($errors->country),
+	"frm_zip_code"		=> ov($frm["zip_code"]),
+	"errors_zip_code"	=> errmsg($errors->zip_code),
+	"frm_phone"		=> ov($frm["phone"]),
+	"errors_phone"		=> errmsg($errors->phone),
+	"frm_fax"		=> ov($frm["fax"]),
+	"errors_fax"		=> errmsg($errors->fax),
+	"frm_mobilephone"	=> ov($frm["mobilephone"]),
+	"errors_mobilephone"	=> errmsg($errors->mobilephone),
+	"frm_email"		=> ov($frm["email"]),
+	"errors_email"		=> errmsg($errors->email),
+	"frm_authdata"		=> $frm["authdata"] ? "checked" : "",
+	"frm_acceptadvert"	=> $frm["acceptadvert"] ? "checked" : "",
+	"frm_message"		=> ov($frm["message"]),
+	"errors_message"	=> errmsg($errors->message),
 ));
 $t->pparse("out", "page");
-//include("templates/contact_form.ihtml");
 
-include("$CFG->dirroot"."/footer.php");
+include ("$CFG->dirroot" . "/footer.php");
 
 /******************************************************************************
  * FUNCTIONS
