@@ -1,4 +1,4 @@
-<?
+<?php
 
 /* orders.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
@@ -19,15 +19,15 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 require_login();
 
 $DOC_TITLE = "Orders_Log_ca";
-include("$CFG->dirroot"."/header.php");
+include ("$CFG->dirroot" . "/header.php");
 
 switch (nvl($mode)) {
 	case "details" :
-		show_order_details($id, $SESSION["user"]["username"]);
+		print_order_details($id, $SESSION["user"]["username"]);
 		break;
 
 	default :
@@ -35,13 +35,13 @@ switch (nvl($mode)) {
 		break;
 }
 
-include("$CFG->dirroot"."/footer.php");
+include ("$CFG->dirroot" . "/footer.php");
 
 /******************************************************************************
  * FUNCTIONS
  *****************************************************************************/
 
-function show_order_details($id, $username) {
+function print_order_details($id, $username) {
 /* loads up the details for an order and displays it */
 
 	global $CFG, $ME;
@@ -49,67 +49,60 @@ function show_order_details($id, $username) {
 	global $weightunity;
 	global $page_number;
 //	include ($CFG->globalerror);
+	include ("$CFG->localedir" . $SESSION["lang"] . "/global-names.inc.php");
 
-	$qid_order = new DB_Sql;
-//	$qid_order = db_query("
+	$qid_order = new PGM_Sql;
 	$qid_order->Query("
 		SELECT o.*, os.name AS state_name
 		FROM ordersca o, orders_states os
 		WHERE o.state_id = os.id AND o.id = '$id'
 	");
-//	if (db_num_rows($qid_order) < 1) {
 	if ($qid_order->num_rows() < 1) {
 		$t = new Template();
 		$t->set_file(array("page" => "templates/no_such_order.ihtml"));
-		require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+		include ("$CFG->localelangdir" . "/global-common.inc.php");
 		$t->pparse("out", "page");
-//		include("templates/no_such_order.ihtml");
 		return;
 	} else {
 		$qid_order->next_record();
 	}
 
-	$qid_items = new DB_Sql;
+	$qid_items = new PGM_Sql;
 	get_order_items(&$qid_items, $id);
 
-//	$order = db_fetch_object($qid_order, 0);
-
-	$qid_user = new DB_Sql;
-//	$qid_user = db_query("
+	$qid_user = new PGM_Sql;
 	$appoggio = $qid_order->f("username");
 	$qid_user->Query("
 		SELECT usertype, fiscalcode, email
 		FROM users
 		WHERE username = '$appoggio'
 	");
-//	$user = db_fetch_object($qid_user, 0);
 	$qid_user->next_record();
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_details.ihtml"));
-	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	require($CFG->localedir . $SESSION["lang"] . "/global-users.inc.php");
+	include ("$CFG->localelangdir" . "/global-common.inc.php");
+	include ("$CFG->localelangdir" . "/global-users.inc.php");
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
-			"order_id"		=> ov($id),
-			"order_state_name"	=> $qid_order->f("state_name"),
-			"order_date"		=> ov($qid_order->f("date")),
-			"order_amount"		=> $qid_order->f("amount"),
-			"order_famount"		=> formatted_price($qid_order->f("amount")),
-			"order_custinfo"	=> nl2br(ov($qid_order->f("custinfo"))),
-			"user_fiscalcode"	=> $qid_user->f("fiscalcode"),
-			"user_email"		=> $qid_user->f("email"),
-			"order_notes"		=> nl2br(ov($qid_order->f("notes")))
+		"order_id"		=> ov($id),
+		"order_state_name"	=> $qid_order->f("state_name"),
+		"order_date"		=> $userday[$qid_order->f("weekday")] . " " . $qid_order->f("day") . " " . $usermonth[$qid_order->f("month")] . " " . $qid_order->f("year"),
+		"order_amount"		=> $qid_order->f("amount"),
+		"order_famount"		=> formatted_price($qid_order->f("amount")),
+		"order_custinfo"	=> nl2br(ov($qid_order->f("custinfo"))),
+		"user_fiscalcode"	=> $qid_user->f("fiscalcode"),
+		"user_email"		=> $qid_user->f("email"),
+		"order_notes"		=> nl2br(ov($qid_order->f("notes")))
 	));
-	if ($qid_user->f("usertype") == "pf") {
-		$t->set_block("page", "usertype_pf", "usertype_pf_blck");
-		$t->set_var(array("usertype_pf_blck", ""));
+	$t->set_block("page", "usertype_pf", "usertype_pf_blck");
+	$t->set_var("usertype_pf_blck", "");
+	$t->set_block("page", "usertype_az", "usertype_az_blck");
+	$t->set_var("usertype_az_blck", "");
+	if ($qid_user->f("usertype") == "pf")
 		$t->parse("usertype_pf_blck", "usertype_pf", true);
-	} else {
-		$t->set_block("page", "usertype_az", "usertype_az_blck");
-		$t->set_var(array("usertype_az_blck", ""));
+	else
 		$t->parse("usertype_az_blck", "usertype_az", true);
-	}
 	$t->set_block("page", "weight_used", "weight_used_blck");
 	$t->set_var(array("weight_used_blck" => ""));
 	if ($SESSION["weight_used"])
@@ -122,27 +115,28 @@ function show_order_details($id, $username) {
 	$t->set_var("item_rows", "");
 		$t->set_block("item_row", "weight_used_row", "weight_used_row_blck");
 		$t->set_block("item_row", "iva_used_row", "iva_used_row_blck");
-//	$numr = db_num_rows($qid_items);
-//	for ($i=0; $i<$numr; $i++) {
 	while ($qid_items->next_record()) {
 		$t->set_var("weight_used_row_blck", "");
 		$t->set_var("iva_used_row_blck", "");
-//		$prod = db_fetch_object($qid_items, $i);
 		$t->set_var(array(
-				"prod_product_id"	=> ov($qid_items->f("product_id")),
-				"prod_name"		=> ov($qid_items->f("name")),
-				"prod_curr_price"	=> $qid_items->f("curr_price"),
-				"prod_fcurr_price"	=> formatted_price($qid_items->f("curr_price")),
-				"prod_purchase_price"	=> $qid_items->f("purchase_price"),
-				"prod_fpurchase_price"	=> formatted_price($qid_items->f("purchase_price")),
-				"prod_qty"		=> $qid_items->f("qty"),
-				"prod_total"		=> $qid_items->f("total"),
-				"prod_ftotal"		=> formatted_price($qid_items->f("total"))
+			"prod_curr_price"	=> $qid_items->f("curr_price"),
+			"prod_fcurr_price"	=> formatted_price($qid_items->f("curr_price")),
+			"prod_purchase_price"	=> $qid_items->f("purchase_price"),
+			"prod_fpurchase_price"	=> formatted_price($qid_items->f("purchase_price")),
+			"prod_qty"		=> $qid_items->f("qty"),
+			"prod_total"		=> $qid_items->f("total"),
+			"prod_ftotal"		=> formatted_price($qid_items->f("total"))
 		));
+		$appoggio = ov($qid_items->f("oiname"));
+		if ($qid_items->f("name") != $appoggio)
+			$appoggio = "<div class=\"warning\">" . $appoggio . "</div>";
+		if ($qid_items->f("name") != "")
+			$appoggio = "<a href=\"" . "$CFG->wwwroot" . "/admin/products.php?mode=details&product_id=" . $qid_items->f("product_id") . "\">" . $appoggio . "</a>";
+		$t->set_var("prod_name", $appoggio);
 		if ($SESSION["weight_used"]) {
 			$t->set_var(array(
-					"prod_purchase_weight"	=> $qid_items->f("purchase_weight"),
-					"prod_fpurchase_weight"	=> formatted_weight ($qid_items->f("purchase_weight"))
+				"prod_purchase_weight"	=> $qid_items->f("purchase_weight"),
+				"prod_fpurchase_weight"	=> formatted_weight ($qid_items->f("purchase_weight"))
 			));
 			$t->parse("weight_used_row_blck", "weight_used_row", true);
 		}
@@ -156,13 +150,12 @@ function show_order_details($id, $username) {
 	$t->set_var(array("delivery_used_blck" => ""));
 	if ($SESSION["delivery_used"]) {
 		$t->set_var(array(
-				"order_delivery"	=> $qid_order->f("delivery"),
-				"order_fdelivery"	=> formatted_price($qid_order->f("delivery"))
+			"order_delivery"	=> $qid_order->f("delivery"),
+			"order_fdelivery"	=> formatted_price($qid_order->f("delivery"))
 		));
 		$t->parse("delivery_used_blck", "delivery_used", true);
 	}
 	$t->pparse("out", "page");
-//	include("templates/order_details.ihtml");
 }
 
 function print_order_list($username) {
@@ -172,37 +165,35 @@ function print_order_list($username) {
 	global $CFG, $ME;
 	global $SESSION;
 	global $weightunity;
-	global $page_number, $dbchanged;
+//	global $page_number, $dbchanged;
+	global $HTTP_GET_VARS;
 //	include ($CFG->globalerror);
+	include ("$CFG->localedir" . $SESSION["lang"] . "/global-names.inc.php");
 
-	if (!isset($page_number) || $dbchanged) {
-		$qid = new DB_Sql;
-//		$qid = db_query("
+	if (!isset($HTTP_GET_VARS["page_number"]) || $HTTP_GET_VARS["dbchanged"]) {
+		$qid = new PGM_Sql;
 		$qid->Query("
-			SELECT o.id, o.username, o.date, o.custinfo, o.amount, o.notes, os.name AS state_name
+			SELECT o.*, os.name AS state_name
 			FROM ordersca o, orders_states os
 			WHERE o.state_id = os.id AND username = '$username'
 			ORDER BY os.name, o.id ASC
   		");
 
-//		$SESSION["numr"] = db_num_rows($qid);
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$SESSION["ordersca"][$i] = db_fetch_array($qid, $i);
-			$qid->seek($i);
+//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["ordersca"][$i]["id"] = $qid->f("id");
-			$SESSION["ordersca"][$i]["username"] = $qid->f("username");
-			$SESSION["ordersca"][$i]["date"] = $qid->f("date");
+			$SESSION["ordersca"][$i]["date"] = $userday[$qid->f("weekday")] . " " . $qid->f("day") . " " . $usermonth[$qid->f("month")] . " " . $qid->f("year");
 			$SESSION["ordersca"][$i]["custinfo"] = $qid->f("custinfo");
 			$SESSION["ordersca"][$i]["amount"] = $qid->f("amount");
 			$SESSION["ordersca"][$i]["notes"] = $qid->f("notes");
 			$SESSION["ordersca"][$i]["state_name"] = $qid->f("state_name");
 		}
-		if (!isset($page_number)) {
+		if (!isset($HTTP_GET_VARS["page_number"])) {
 			$page_number = 1;
-		}
-	}
+		} else $page_number = $HTTP_GET_VARS["page_number"];
+	} else $page_number = $HTTP_GET_VARS["page_number"];
 
 	if ($SESSION["numr"] > $SESSION["orders_per_page"]) {
 		$first = ($page_number-1)*$SESSION["orders_per_page"];
@@ -219,13 +210,12 @@ function print_order_list($username) {
 	if ($SESSION["numr"] == 0) {
 		$t = new Template();
 		$t->set_file(array("page" => "templates/no_orders.ihtml"));
-		require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+		include ("$CFG->localelangdir" . "/global-common.inc.php");
 		$t->pparse("out", "page");
-//		include("templates/no_orders.ihtml");
 	} else {
 		$t = new Template();
 		$t->set_file(array("page" => "templates/orderca_list.ihtml"));
-		require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+		include ("$CFG->localelangdir" . "/global-common.inc.php");
 		$t->set_var("ME", $ME);
 		$t->set_block("page", "pages_links_top", "pages_links_top_blck");
 		$t->set_var("pages_links_top_blck", "");
@@ -233,7 +223,7 @@ function print_order_list($username) {
 		$t->set_var("pages_links_bottom_blck", "");
 		if ($num_pages > 1) {
 			$summary_report .= " " . $on . " " . $num_pages . " " . $pages;
-			require("pages_links.php");
+			include ("pages_links.php");
 			$t->set_var("pages_links", $pages_links);
 			$t->parse("pages_links_top_blck", "pages_links_top", true);
 			$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
@@ -243,16 +233,15 @@ function print_order_list($username) {
 		$t->set_var("item_rows", "");
 		for ($i=$first; $i<=$last; $i++) {
 			$t->set_var(array(
-					"session_order_id"		=> ov($SESSION["ordersca"][$i]["id"]),
-					"session_order_state_name"	=> ov($SESSION["ordersca"][$i]["state_name"]),
-					"session_order_date"		=> ov($SESSION["ordersca"][$i]["date"]),
-					"session_order_amount"		=> $SESSION["ordersca"][$i]["amount"],
-					"session_order_famount"		=> formatted_price($SESSION["ordersca"][$i]["amount"])
+				"session_order_id"		=> ov($SESSION["ordersca"][$i]["id"]),
+				"session_order_state_name"	=> ov($SESSION["ordersca"][$i]["state_name"]),
+				"session_order_date"		=> $SESSION["ordersca"][$i]["date"],
+				"session_order_amount"		=> $SESSION["ordersca"][$i]["amount"],
+				"session_order_famount"		=> formatted_price($SESSION["ordersca"][$i]["amount"])
 			));
 			$t->parse("item_rows", "item_row", true);
 		}
 		$t->pparse("out", "page");
-//		include("templates/orderca_list.ihtml");
 	}
 }
 
