@@ -1,4 +1,4 @@
-<?
+<?php
 /* signup.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -18,9 +18,11 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 if (!isset($usertype)) { $usertype = "pf"; }
 
+$qid = new PGM_Sql;
+
 /* form has been submitted, try to create the new user account */
 if (match_referer() && isset($HTTP_POST_VARS) && !isset($from_menu)) {
 	$frm = $HTTP_POST_VARS;
@@ -30,81 +32,81 @@ if (match_referer() && isset($HTTP_POST_VARS) && !isset($from_menu)) {
 		insert_user($frm, $usertype);
 
 		$DOC_TITLE = "Signup_Successful";
-		include("$CFG->dirroot"."/header.php");
+		include ("$CFG->dirroot" . "/header.php");
 		$t = new Template();
-		$t->set_file(array("page" => "templates/".$SESSION["lang"]."/signup_success.ihtml"));
+		$t->set_file(array("page" => "templates/" . $SESSION["lang"] . "/signup_success.ihtml"));
 		$t->set_var(array(
-				"frm_firstname"	=> ov($frm["firstname"]),
-				"frm_username"	=> ov($frm["username"]),
-				"frm_password"	=> ov($frm["password"]),
-				"wwwroot"	=> $CFG->wwwroot
+			"frm_firstname"	=> ov($frm["firstname"]),
+			"frm_username"	=> ov($frm["username"]),
+			"frm_password"	=> ov($frm["password"]),
+			"wwwroot"	=> $CFG->wwwroot
 		));
 		$t->pparse("out", "page");
-//		include("templates/".$SESSION["lang"]."/signup_success.ihtml");
-		include("$CFG->dirroot"."/footer.php");
+		include ("$CFG->dirroot" . "/footer.php");
 		die;
 	}
 }
 
+$qid->close();
+
 $DOC_TITLE = "Signup";
-include("$CFG->dirroot"."/header.php");
-include("$CFG->dirroot"."/form_header.php");
+include ("$CFG->dirroot" . "/header.php");
+include ("$CFG->dirroot" . "/form_header.php");
 
 if (empty($errormsg)) {	// we are loading the form for the first time
 	$frm["acceptadvert"] = 1;
 }
 
 $t = new Template();
-$t->set_file(array("page" => "templates/signup_form-".$usertype.".ihtml"));
-require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-require($CFG->localedir . $SESSION["lang"] . "/global-users.inc.php");
+$t->set_file(array("page" => "templates/signup_form-" . $usertype . ".ihtml"));
+include ("$CFG->localelangdir" . "/global-common.inc.php");
+include ("$CFG->localelangdir" . "/global-users.inc.php");
 $t->set_var("ME", $ME);
-$t->set_var("md5dotjs", $CFG->libwww . "/md5.js");
+$t->set_var("md5dotjs", "$CFG->libwww" . "/md5.js");
 $t->set_var("star", return_star());
 $t->set_var(array(
-		"frm_username"		=> ov($frm["username"]),
-		"errors_username"	=> errmsg($errors->username),
-		"errors_password"	=> errmsg($errors->password),
-		"frm_firstname"		=> ov($frm["firstname"]),
-		"errors_firstname"	=> errmsg($errors->firstname),
-		"frm_lastname"		=> ov($frm["lastname"]),
-		"errors_lastname"	=> errmsg($errors->lastname),
-		"frm_address"		=> ov($frm["address"]),
-		"errors_address"	=> errmsg($errors->address),
-		"frm_number"		=> ov($frm["number"]),
-		"errors_number"		=> errmsg($errors->number),
-		"frm_city"		=> ov($frm["city"]),
-		"errors_city"		=> errmsg($errors->city),
-		"frm_country"		=> ov($frm["country"]),
-		"errors_country"	=> errmsg($errors->country),
-		"frm_zip_code"		=> ov($frm["zip_code"]),
-		"errors_zip_code"	=> errmsg($errors->zip_code),
-		"frm_phone"		=> ov($frm["phone"]),
-		"errors_phone"		=> errmsg($errors->phone),
-		"frm_fax"		=> ov($frm["fax"]),
-		"errors_fax"		=> errmsg($errors->fax),
-		"frm_mobilephone"	=> ov($frm["mobilephone"]),
-		"errors_mobilephone"	=> errmsg($errors->mobilephone),
-		"frm_email"		=> ov($frm["email"]),
-		"errors_email"		=> errmsg($errors->email),
-		"frm_authdata"		=> $frm["authdata"] ? "checked" : "",
-		"frm_acceptadvert"	=> $frm["acceptadvert"] ? "checked" : "",
-		"frm_notes"		=> ov($frm["notes"]),
-		"errors_notes"		=> errmsg($errors->notes),
+	"frm_username"		=> ov($frm["username"]),
+	"errors_username"	=> errmsg($errors->username),
+	"errors_password"	=> errmsg($errors->password),
+	"frm_firstname"		=> ov($frm["firstname"]),
+	"errors_firstname"	=> errmsg($errors->firstname),
+	"frm_lastname"		=> ov($frm["lastname"]),
+	"errors_lastname"	=> errmsg($errors->lastname),
+	"frm_address"		=> ov($frm["address"]),
+	"errors_address"	=> errmsg($errors->address),
+	"frm_number"		=> ov($frm["number"]),
+	"errors_number"		=> errmsg($errors->number),
+	"frm_city"		=> ov($frm["city"]),
+	"errors_city"		=> errmsg($errors->city),
+	"frm_country"		=> ov($frm["country"]),
+	"errors_country"	=> errmsg($errors->country),
+	"frm_zip_code"		=> ov($frm["zip_code"]),
+	"errors_zip_code"	=> errmsg($errors->zip_code),
+	"frm_phone"		=> ov($frm["phone"]),
+	"errors_phone"		=> errmsg($errors->phone),
+	"frm_fax"		=> ov($frm["fax"]),
+	"errors_fax"		=> errmsg($errors->fax),
+	"frm_mobilephone"	=> ov($frm["mobilephone"]),
+	"errors_mobilephone"	=> errmsg($errors->mobilephone),
+	"frm_email"		=> ov($frm["email"]),
+	"errors_email"		=> errmsg($errors->email),
+	"frm_authdata"		=> $frm["authdata"] ? "checked" : "",
+	"frm_acceptadvert"	=> $frm["acceptadvert"] ? "checked" : "",
+	"frm_notes"		=> ov($frm["notes"]),
+	"errors_notes"		=> errmsg($errors->notes),
 ));
 $t->set_block("page", "fiscalcode", "fiscalcode_blck");
 $t->set_var("fiscalcode_blck", "");
 if ($country == "it" || $HTTP_POST_VARS["hiddencountry"] == "it" || $usertype == "az") {
 	$t->set_var(array(
-			"frm_fiscalcode"	=> ov($frm["fiscalcode"]),
-			"errors_fiscalcode"	=> errmsg($errors->fiscalcode)
+		"frm_fiscalcode"	=> ov($frm["fiscalcode"]),
+		"errors_fiscalcode"	=> errmsg($errors->fiscalcode)
 	));
 	$t->parse("fiscalcode_blck", "fiscalcode", true);
 }
 $t->pparse("out", "page");
-//include("templates/signup_form-".$usertype.".ihtml");
 
-include("$CFG->dirroot"."/footer.php");
+include ("$CFG->dirroot" . "/footer.php");
 
 /******************************************************************************
  * FUNCTIONS
@@ -116,6 +118,7 @@ function validate_form(&$frm, &$errors, $usertype) {
 
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
+	global $qid;
 
 	$errors = new Object;
 	$msg = "";
@@ -125,7 +128,7 @@ function validate_form(&$frm, &$errors, $usertype) {
 		validate_password($frm["password"], &$errors, &$msg);
 	} else {
 		$errors->password = true;
-		$msg .= "<li>".$passwords_do_not_match;
+		$msg .= "<li>" . $passwords_do_not_match;
 	}
 	if ($usertype == "pf") {
 		validate_firstname($frm["firstname"], &$errors, &$msg);
@@ -147,7 +150,7 @@ function validate_form(&$frm, &$errors, $usertype) {
 	validate_email($frm["email"], &$errors, &$msg);
 	validate_notes($frm["notes"], &$errors, &$msg);
 
-	if (username_exists($frm["username"])) {
+	if (username_exists(&$qid, $frm["username"])) {
 		$errors->username = true;
 		$msg = "<li>" . $the_username . " <b>" . ov($frm["username"]) ."</b> " . $already_exists . $msg;
 
@@ -162,16 +165,18 @@ function validate_form(&$frm, &$errors, $usertype) {
 function insert_user(&$frm, $usertype) {
 /* add the new user into the database */
 
-	global $CFG, $SESSION, $myday, $mymonth;
+	global $CFG, $SESSION;
+	global $qid;
 
-	$date = $myday[date("w")] . date(" j") . "-" . date("n") . "-" . date("Y H:i:s");
+//	$date = $myday[date("w")] . date(" j") . "-" . date("n") . "-" . date("Y H:i:s");
+	$Dateusec = gettimeofday(); $unixtime = $Dateusec["sec"];
+	$year = date("Y"); $month = date("n"); $day = date("j"); $weekday = date("w");
 	$fromip = getenv("REMOTE_ADDR");
 
-	$qid = new DB_Sql;
-//	$qid = db_query("
+//	$qid = new PGM_Sql;
 	$qid->Query("
 		INSERT INTO users (
-			username
+			 username
 			,password
 			,usertype
 			,firstname
@@ -189,7 +194,11 @@ function insert_user(&$frm, $usertype) {
 			,authdata
 			,acceptadvert
 			,notes
-			,date
+			,unixtime
+			,year
+			,month
+			,day
+			,weekday
 			,fromip
 		) VALUES (
 			 '$frm[username]'
@@ -210,7 +219,11 @@ function insert_user(&$frm, $usertype) {
 			,'$frm[authdata]'
 			,'$frm[acceptadvert]'
 			,'$frm[notes]'
-			,'$date'
+			,'$unixtime'
+			,'$year'
+			,'$month'
+			,'$day'
+			,'$weekday'
 			,'$fromip'
 		)
 	");
